(in-package :cl-info)
(let (
(deffn-defvr-pairs '(
; CONTENT: (<INDEX TOPIC> . (<FILENAME> <BYTE OFFSET> <LENGTH IN CHARACTERS> <NODE NAME>))
("!" . ("maxima.info-1" 389109 3450 "Combinatorial Functions"))
("!!" . ("maxima.info-1" 386494 698 "Combinatorial Functions"))
("#" . ("maxima.info-1" 268336 756 "Operators for Equations"))
("$" . ("maxima.info-1" 45928 406 "Functions and Variables for Command Line"))
("%" . ("maxima.info-1" 41743 567 "Functions and Variables for Command Line"))
("%%" . ("maxima.info-1" 42311 1594 "Functions and Variables for Command Line"))
("%and" . ("maxima.info-3" 350417 2856 "Functions and Variables for to_poly_solve"))
("%c" . ("maxima.info-2" 532603 78 "Functions and Variables for contrib_ode"))
("%e" . ("maxima.info-1" 113197 207 "Functions and Variables for Constants"))
("%e_to_numlog" . ("maxima.info-1" 395016 404 "Root Exponential and Logarithmic Functions"))
("%edispflag" . ("maxima.info-1" 63826 599 "Functions and Variables for Display"))
("%emode" . ("maxima.info-1" 395421 1591 "Root Exponential and Logarithmic Functions"))
("%enumer" . ("maxima.info-1" 397013 1041 "Root Exponential and Logarithmic Functions"))
("%f" . ("maxima.info-1" 684776 170 "Hypergeometric Functions"))
("%gamma" . ("maxima.info-1" 113621 82 "Functions and Variables for Constants"))
("%i" . ("maxima.info-1" 113405 70 "Functions and Variables for Constants"))
("%iargs" . ("maxima.info-1" 412504 1031 "Functions and Variables for Trigonometric"))
("%if" . ("maxima.info-3" 353274 1592 "Functions and Variables for to_poly_solve"))
("%k1" . ("maxima.info-2" 532682 87 "Functions and Variables for contrib_ode"))
("%k2" . ("maxima.info-2" 532770 88 "Functions and Variables for contrib_ode"))
("%m" . ("maxima.info-1" 684566 133 "Hypergeometric Functions"))
("%or" . ("maxima.info-3" 354867 2805 "Functions and Variables for to_poly_solve"))
("%phi" . ("maxima.info-1" 114119 2415 "Functions and Variables for Constants"))
("%pi" . ("maxima.info-1" 116535 201 "Functions and Variables for Constants"))
("%piargs" . ("maxima.info-1" 410523 1980 "Functions and Variables for Trigonometric"))
("%rnum" . ("maxima.info-1" 792688 239 "Functions and Variables for Equations"))
("%rnum_list" . ("maxima.info-1" 792928 1041 "Functions and Variables for Equations"))
("%s" . ("maxima.info-1" 646136 120 "Bessel Functions"))
("%th" . ("maxima.info-1" 43906 1148 "Functions and Variables for Command Line"))
("%union" . ("maxima.info-3" 397699 1834 "Functions and Variables for to_poly_solve"))
("%union <1>" . ("maxima.info-3" 397700 1833 "Functions and Variables for to_poly_solve"))
("%unitexpand" . ("maxima.info-3" 422769 149 "Functions and Variables for Units"))
("%w" . ("maxima.info-1" 684700 75 "Hypergeometric Functions"))
("'" . ("maxima.info-1" 296926 4611 "Functions and Variables for Evaluation"))
("''" . ("maxima.info-1" 301538 5472 "Functions and Variables for Evaluation"))
("*" . ("maxima.info-1" 253834 6979 "Arithmetic operators"))
("**" . ("maxima.info-1" 260814 772 "Arithmetic operators"))
("+" . ("maxima.info-1" 253817 6996 "Arithmetic operators"))
("-" . ("maxima.info-1" 253818 6995 "Arithmetic operators"))
("." . ("maxima.info-1" 262333 429 "Arithmetic operators"))
("/" . ("maxima.info-1" 253850 6963 "Arithmetic operators"))
(":" . ("maxima.info-1" 273323 2788 "Assignment operators"))
("::" . ("maxima.info-1" 276112 747 "Assignment operators"))
("::=" . ("maxima.info-1" 276860 2940 "Assignment operators"))
(":=" . ("maxima.info-1" 279801 5702 "Assignment operators"))
(";" . ("maxima.info-1" 46335 230 "Functions and Variables for Command Line"))
("<" . ("maxima.info-1" 262933 2519 "Relational operators"))
("<=" . ("maxima.info-1" 262934 2518 "Relational operators"))
("=" . ("maxima.info-1" 269093 4051 "Operators for Equations"))
(">" . ("maxima.info-1" 262967 2485 "Relational operators"))
(">=" . ("maxima.info-1" 262950 2502 "Relational operators"))
("?" . ("maxima.info-1" 45055 555 "Functions and Variables for Command Line"))
("??" . ("maxima.info-1" 45611 316 "Functions and Variables for Command Line"))
("@" . ("maxima.info-1" 187814 1625 "Functions and Variables for Structures"))
("Addition" . ("maxima.info-1" 253817 6996 "Arithmetic operators"))
("AntiDifference" . ("maxima.info-3" 433959 176 "Functions and Variables for zeilberger"))
("Assignment operator" . ("maxima.info-1" 273324 2787 "Assignment operators"))
("Assignment operator (evaluates left-hand side)" . ("maxima.info-1" 276113 746 "Assignment operators"))
("Base of natural logarithm" . ("maxima.info-1" 113198 206 "Functions and Variables for Constants"))
("Complex infinity" . ("maxima.info-1" 113968 68 "Functions and Variables for Constants"))
("Contraction with a vector" . ("maxima.info-1" 1015751 1385 "Functions and Variables for itensor"))
("Current input expression" . ("maxima.info-1" 38548 1739 "Functions and Variables for Command Line"))
("Division" . ("maxima.info-1" 253817 6996 "Arithmetic operators"))
("Double factorial" . ("maxima.info-1" 386495 697 "Combinatorial Functions"))
("Equal (syntactic equality)" . ("maxima.info-1" 269094 4050 "Operators for Equations"))
("Equation operator" . ("maxima.info-1" 269094 4050 "Operators for Equations"))
("Euler's number" . ("maxima.info-1" 113198 206 "Functions and Variables for Constants"))
("Euler-Mascheroni constant" . ("maxima.info-1" 113622 81 "Functions and Variables for Constants"))
("Exponentiation" . ("maxima.info-1" 253817 6996 "Arithmetic operators"))
("Fetch documentation" . ("maxima.info-1" 45056 554 "Functions and Variables for Command Line"))
("Fetch documentation (inexact search)" . ("maxima.info-1" 45612 315 "Functions and Variables for Command Line"))
("Function definition operator" . ("maxima.info-1" 279802 5701 "Assignment operators"))
("GGFCFMAX" . ("maxima.info-2" 951178 523 "Functions and Variables for ggf"))
("GGFINFINITY" . ("maxima.info-2" 950586 591 "Functions and Variables for ggf"))
("Golden mean" . ("maxima.info-1" 114120 2414 "Functions and Variables for Constants"))
("Gosper" . ("maxima.info-3" 434136 222 "Functions and Variables for zeilberger"))
("GosperSum" . ("maxima.info-3" 434359 2031 "Functions and Variables for zeilberger"))
("Gosper_in_Zeilberger" . ("maxima.info-3" 438143 251 "Functions and Variables for zeilberger"))
("Greater than" . ("maxima.info-1" 262933 2519 "Relational operators"))
("Greater than or equal" . ("maxima.info-1" 262933 2519 "Relational operators"))
("Help" . ("maxima.info-1" 33374 2860 "Functions and Variables for Help"))
("Imaginary unit" . ("maxima.info-1" 113406 69 "Functions and Variables for Constants"))
("Indeterminate" . ("maxima.info-1" 113705 195 "Functions and Variables for Constants"))
("Input terminator (with display)" . ("maxima.info-1" 46336 229 "Functions and Variables for Command Line"))
("Input terminator (without display)" . ("maxima.info-1" 45929 405 "Functions and Variables for Command Line"))
("JF" . ("maxima.info-2" 617091 815 "Functions and Variables for diag"))
("Less than" . ("maxima.info-1" 262933 2519 "Relational operators"))
("Less than or equal" . ("maxima.info-1" 262933 2519 "Relational operators"))
("Lindstedt" . ("maxima.info-3" 69057 1333 "Functions and Variables for lindstedt"))
("List delimiters" . ("maxima.info-1" 119064 1507 "Functions and Variables for Lists"))
("Logical conjunction" . ("maxima.info-1" 265621 999 "Logical operators"))
("Logical conjunction <1>" . ("maxima.info-3" 350418 2855 "Functions and Variables for to_poly_solve"))
("Logical disjunction" . ("maxima.info-1" 267166 990 "Logical operators"))
("Logical disjunction <1>" . ("maxima.info-3" 354868 2804 "Functions and Variables for to_poly_solve"))
("Logical negation" . ("maxima.info-1" 266622 542 "Logical operators"))
("MAX_ORD" . ("maxima.info-3" 437450 131 "Functions and Variables for zeilberger"))
("Macro function definition operator" . ("maxima.info-1" 276861 2939 "Assignment operators"))
("Minus infinity" . ("maxima.info-1" 114038 80 "Functions and Variables for Constants"))
("ModeMatrix" . ("maxima.info-2" 622233 1725 "Functions and Variables for diag"))
("Multiplication" . ("maxima.info-1" 253817 6996 "Arithmetic operators"))
("N'th previous output" . ("maxima.info-1" 43907 1147 "Functions and Variables for Command Line"))
("Negative infinity" . ("maxima.info-1" 114038 80 "Functions and Variables for Constants"))
("Noncommutative exponentiation" . ("maxima.info-1" 261588 744 "Arithmetic operators"))
("Noncommutative multiplication" . ("maxima.info-1" 262334 428 "Arithmetic operators"))
("Not equal (syntactic inequality)" . ("maxima.info-1" 268337 755 "Operators for Equations"))
("Previous input" . ("maxima.info-1" 40289 1453 "Functions and Variables for Command Line"))
("Previous output" . ("maxima.info-1" 41744 566 "Functions and Variables for Command Line"))
("Previous result in compound expression" . ("maxima.info-1" 42312 1593 "Functions and Variables for Command Line"))
("Quote operator" . ("maxima.info-1" 296927 4610 "Functions and Variables for Evaluation"))
("Quote-quote operator" . ("maxima.info-1" 301539 5471 "Functions and Variables for Evaluation"))
("Real infinity" . ("maxima.info-1" 113902 64 "Functions and Variables for Constants"))
("Subscript operator" . ("maxima.info-1" 119064 1507 "Functions and Variables for Lists"))
("Subtraction" . ("maxima.info-1" 253817 6996 "Arithmetic operators"))
("Undefined" . ("maxima.info-1" 116878 188 "Functions and Variables for Constants"))
("Wedge product" . ("maxima.info-1" 1014185 1564 "Functions and Variables for itensor"))
("Zeilberger" . ("maxima.info-3" 436712 677 "Functions and Variables for zeilberger"))
("[" . ("maxima.info-1" 119064 1507 "Functions and Variables for Lists"))
("]" . ("maxima.info-1" 119065 1506 "Functions and Variables for Lists"))
("^" . ("maxima.info-1" 253866 6947 "Arithmetic operators"))
("^^" . ("maxima.info-1" 261587 745 "Arithmetic operators"))
("_" . ("maxima.info-1" 40288 1454 "Functions and Variables for Command Line"))
("__" . ("maxima.info-1" 38547 1740 "Functions and Variables for Command Line"))
("`" . ("maxima.info-2" 900170 3244 "Functions and Variables for ezunits"))
("` <1>" . ("maxima.info-2" 903415 7581 "Functions and Variables for ezunits"))
("abasep" . ("maxima.info-2" 73768 257 "Functions and Variables for atensor"))
("abs" . ("maxima.info-1" 365428 3401 "Functions for Numbers"))
("absboxchar" . ("maxima.info-1" 64426 325 "Functions and Variables for Display"))
("absint" . ("maxima.info-2" 115676 621 "Functions and Variables for Fourier series"))
("absolute_real_time" . ("maxima.info-2" 233038 429 "Functions and Variables for Runtime Environment"))
("acos" . ("maxima.info-1" 413536 45 "Functions and Variables for Trigonometric"))
("acosh" . ("maxima.info-1" 413582 57 "Functions and Variables for Trigonometric"))
("acot" . ("maxima.info-1" 413640 48 "Functions and Variables for Trigonometric"))
("acoth" . ("maxima.info-1" 413689 60 "Functions and Variables for Trigonometric"))
("acsc" . ("maxima.info-1" 413750 47 "Functions and Variables for Trigonometric"))
("acsch" . ("maxima.info-1" 413798 59 "Functions and Variables for Trigonometric"))
("activate" . ("maxima.info-1" 448400 399 "Functions and Variables for Facts"))
("activecontexts" . ("maxima.info-1" 448800 252 "Functions and Variables for Facts"))
("adapt_depth" . ("maxima.info-1" 502145 161 "Plotting Options"))
("adapt_depth <1>" . ("maxima.info-2" 717807 243 "Functions and Variables for draw"))
("add_edge" . ("maxima.info-2" 989851 398 "Functions and Variables for graphs"))
("add_edges" . ("maxima.info-2" 990250 389 "Functions and Variables for graphs"))
("add_vertex" . ("maxima.info-2" 990640 351 "Functions and Variables for graphs"))
("add_vertices" . ("maxima.info-2" 990992 107 "Functions and Variables for graphs"))
("addcol" . ("maxima.info-1" 882259 189 "Functions and Variables for Matrices and Linear Algebra"))
("additive" . ("maxima.info-1" 333287 902 "Functions and Variables for Simplification"))
("addmatrices" . ("maxima.info-3" 75375 511 "Functions and Variables for linearalgebra"))
("addrow" . ("maxima.info-1" 882449 186 "Functions and Variables for Matrices and Linear Algebra"))
("adim" . ("maxima.info-2" 71709 200 "Functions and Variables for atensor"))
("adjacency_matrix" . ("maxima.info-2" 962997 564 "Functions and Variables for graphs"))
("adjoin" . ("maxima.info-2" 291707 476 "Functions and Variables for Sets"))
("adjoint" . ("maxima.info-1" 882636 150 "Functions and Variables for Matrices and Linear Algebra"))
("adjust_external_format" . ("maxima.info-3" 314286 2238 "Characters"))
("af" . ("maxima.info-2" 72450 292 "Functions and Variables for atensor"))
("aform" . ("maxima.info-2" 71910 170 "Functions and Variables for atensor"))
("agd" . ("maxima.info-3" 234080 158 "Package functs"))
("airy_ai" . ("maxima.info-1" 646807 184 "Airy Functions"))
("airy_bi" . ("maxima.info-1" 647101 167 "Airy Functions"))
("airy_dai" . ("maxima.info-1" 646992 108 "Airy Functions"))
("airy_dbi" . ("maxima.info-1" 647269 124 "Airy Functions"))
("alg_type" . ("maxima.info-2" 71556 152 "Functions and Variables for atensor"))
("algebraic" . ("maxima.info-1" 572155 174 "Functions and Variables for Polynomials"))
("algepsilon" . ("maxima.info-1" 793970 97 "Functions and Variables for Equations"))
("algexact" . ("maxima.info-1" 794068 580 "Functions and Variables for Equations"))
("algsys" . ("maxima.info-1" 794649 4789 "Functions and Variables for Equations"))
("alias" . ("maxima.info-1" 196301 228 "Functions and Variables for Expressions"))
("aliases" . ("maxima.info-1" 196530 245 "Functions and Variables for Expressions"))
("all_dotsimp_denoms" . ("maxima.info-1" 940749 343 "Functions and Variables for Affine"))
("allbut" . ("maxima.info-1" 196776 995 "Functions and Variables for Expressions"))
("allocation" . ("maxima.info-2" 718051 1383 "Functions and Variables for draw"))
("allroots" . ("maxima.info-1" 799439 2362 "Functions and Variables for Equations"))
("allsym" . ("maxima.info-1" 978085 357 "Functions and Variables for itensor"))
("alphabetic" . ("maxima.info-1" 427699 641 "Functions and Variables for Properties"))
("alphacharp" . ("maxima.info-3" 316525 996 "Characters"))
("alphanumericp" . ("maxima.info-3" 317522 223 "Characters"))
("amortization" . ("maxima.info-2" 936105 1384 "Functions and Variables for finance"))
("and" . ("maxima.info-1" 265620 1000 "Logical operators"))
("animation" . ("maxima.info-2" 880201 594 "Visualization with VTK"))
("annuity_fv" . ("maxima.info-2" 934765 408 "Functions and Variables for finance"))
("annuity_pv" . ("maxima.info-2" 934354 410 "Functions and Variables for finance"))
("antid" . ("maxima.info-1" 708475 2401 "Functions and Variables for Differentiation"))
("antidiff" . ("maxima.info-1" 710877 2235 "Functions and Variables for Differentiation"))
("antisymmetric" . ("maxima.info-1" 334190 1032 "Functions and Variables for Simplification"))
("append" . ("maxima.info-1" 120572 352 "Functions and Variables for Lists"))
("appendfile" . ("maxima.info-1" 533371 296 "Functions and Variables for File Input and Output"))
("apply" . ("maxima.info-2" 352464 2615 "Functions and Variables for Function Definition"))
("apply1" . ("maxima.info-2" 243744 647 "Functions and Variables for Rules and Patterns"))
("apply2" . ("maxima.info-2" 244392 534 "Functions and Variables for Rules and Patterns"))
("apply_cycles" . ("maxima.info-2" 513048 748 "Functions and Variables for Combinatorics"))
("applyb1" . ("maxima.info-2" 244927 710 "Functions and Variables for Rules and Patterns"))
("apropos" . ("maxima.info-1" 31060 1116 "Functions and Variables for Help"))
("args" . ("maxima.info-1" 197772 1125 "Functions and Variables for Expressions"))
("arit_amortization" . ("maxima.info-2" 937490 1695 "Functions and Variables for finance"))
("arithmetic" . ("maxima.info-3" 232699 212 "Package functs"))
("arithsum" . ("maxima.info-3" 233353 155 "Package functs"))
("array" . ("maxima.info-1" 163794 811 "Functions and Variables for Arrays"))
("arrayapply" . ("maxima.info-1" 164606 262 "Functions and Variables for Arrays"))
("arrayinfo" . ("maxima.info-1" 164869 4413 "Functions and Variables for Arrays"))
("arraymake" . ("maxima.info-1" 169283 1792 "Functions and Variables for Arrays"))
("arrays" . ("maxima.info-1" 171076 1128 "Functions and Variables for Arrays"))
("arraysetapply" . ("maxima.info-1" 172205 217 "Functions and Variables for Arrays"))
("ascii" . ("maxima.info-3" 317746 525 "Characters"))
("asec" . ("maxima.info-1" 413858 45 "Functions and Variables for Trigonometric"))
("asech" . ("maxima.info-1" 413904 57 "Functions and Variables for Trigonometric"))
("asin" . ("maxima.info-1" 413962 43 "Functions and Variables for Trigonometric"))
("asinh" . ("maxima.info-1" 414006 55 "Functions and Variables for Trigonometric"))
("askexp" . ("maxima.info-2" 236152 229 "Functions and Variables for Miscellaneous Options"))
("askinteger" . ("maxima.info-1" 449053 665 "Functions and Variables for Facts"))
("asksign" . ("maxima.info-1" 449719 397 "Functions and Variables for Facts"))
("assoc" . ("maxima.info-1" 120925 1590 "Functions and Variables for Lists"))
("assoc_legendre_p" . ("maxima.info-3" 184760 267 "Functions and Variables for orthogonal polynomials"))
("assoc_legendre_q" . ("maxima.info-3" 185028 204 "Functions and Variables for orthogonal polynomials"))
("assume" . ("maxima.info-1" 450117 2403 "Functions and Variables for Facts"))
("assume_external_byte_order" . ("maxima.info-3" 149424 494 "Functions and Variables for binary input and output"))
("assume_pos" . ("maxima.info-1" 453422 1142 "Functions and Variables for Facts"))
("assume_pos_pred" . ("maxima.info-1" 454565 2231 "Functions and Variables for Facts"))
("assumescalar" . ("maxima.info-1" 452521 900 "Functions and Variables for Facts"))
("asymbol" . ("maxima.info-2" 72081 81 "Functions and Variables for atensor"))
("asympa" . ("maxima.info-2" 478762 321 "Introduction to asympa"))
("at" . ("maxima.info-1" 713113 3069 "Functions and Variables for Differentiation"))
("atan" . ("maxima.info-1" 414062 70 "Functions and Variables for Trigonometric"))
("atan2" . ("maxima.info-1" 414133 136 "Functions and Variables for Trigonometric"))
("atanh" . ("maxima.info-1" 414270 58 "Functions and Variables for Trigonometric"))
("atensimp" . ("maxima.info-2" 71148 407 "Functions and Variables for atensor"))
("atom" . ("maxima.info-1" 198898 241 "Functions and Variables for Expressions"))
("atomgrad" . ("maxima.info-1" 716183 135 "Functions and Variables for Differentiation"))
("atrig1" . ("maxima.info-1" 414329 398 "Functions and Variables for Trigonometric"))
("atvalue" . ("maxima.info-1" 716319 2590 "Functions and Variables for Differentiation"))
("augcoefmatrix" . ("maxima.info-1" 882787 663 "Functions and Variables for Matrices and Linear Algebra"))
("augmented_lagrangian_method" . ("maxima.info-2" 479743 3659 "Functions and Variables for augmented_lagrangian"))
("av" . ("maxima.info-2" 72743 1024 "Functions and Variables for atensor"))
("average_degree" . ("maxima.info-2" 963562 328 "Functions and Variables for graphs"))
("axes" . ("maxima.info-1" 502307 461 "Plotting Options"))
("axis_3d" . ("maxima.info-2" 719435 484 "Functions and Variables for draw"))
("axis_bottom" . ("maxima.info-2" 719920 443 "Functions and Variables for draw"))
("axis_left" . ("maxima.info-2" 720364 406 "Functions and Variables for draw"))
("axis_right" . ("maxima.info-2" 720771 409 "Functions and Variables for draw"))
("axis_top" . ("maxima.info-2" 721181 404 "Functions and Variables for draw"))
("azimuth" . ("maxima.info-1" 502769 514 "Plotting Options"))
("azimuth <1>" . ("maxima.info-2" 876008 298 "Visualization with VTK"))
("background" . ("maxima.info-2" 876307 240 "Visualization with VTK"))
("background_color" . ("maxima.info-2" 721586 371 "Functions and Variables for draw"))
("backslash" . ("maxima.info-1" 107638 1870 "Introduction to Strings"))
("backsubst" . ("maxima.info-1" 802205 713 "Functions and Variables for Equations"))
("backtrace" . ("maxima.info-2" 420084 1629 "Functions and Variables for Program Flow"))
("bars" . ("maxima.info-2" 805867 887 "Functions and Variables for draw"))
("barsplot" . ("maxima.info-2" 594215 4517 "Functions and Variables for statistical graphs"))
("barsplot_description" . ("maxima.info-2" 598733 895 "Functions and Variables for statistical graphs"))
("base64" . ("maxima.info-3" 338488 990 "Octets and Utilities for Cryptography"))
("base64_decode" . ("maxima.info-3" 339479 451 "Octets and Utilities for Cryptography"))
("bashindices" . ("maxima.info-2" 74715 428 "Functions and Variables for Sums and Products"))
("batch" . ("maxima.info-1" 533668 2607 "Functions and Variables for File Input and Output"))
("batchload" . ("maxima.info-1" 536276 644 "Functions and Variables for File Input and Output"))
("bc2" . ("maxima.info-1" 835268 607 "Functions and Variables for Differential Equations"))
("bdvac" . ("maxima.info-2" 39081 395 "Functions and Variables for ctensor"))
("belln" . ("maxima.info-2" 292184 982 "Functions and Variables for Sets"))
("benefit_cost" . ("maxima.info-2" 942955 629 "Functions and Variables for finance"))
("berlefact" . ("maxima.info-1" 572330 225 "Functions and Variables for Polynomials"))
("bern" . ("maxima.info-2" 121828 757 "Functions and Variables for Number Theory"))
("bernpoly" . ("maxima.info-2" 122586 101 "Functions and Variables for Number Theory"))
("bernstein_approx" . ("maxima.info-2" 486708 1251 "Functions and Variables for Bernstein"))
("bernstein_expand" . ("maxima.info-2" 487960 496 "Functions and Variables for Bernstein"))
("bernstein_explicit" . ("maxima.info-2" 485648 628 "Functions and Variables for Bernstein"))
("bernstein_poly" . ("maxima.info-2" 483782 1865 "Functions and Variables for Bernstein"))
("bessel_i" . ("maxima.info-1" 641209 537 "Bessel Functions"))
("bessel_j" . ("maxima.info-1" 640264 520 "Bessel Functions"))
("bessel_k" . ("maxima.info-1" 641747 442 "Bessel Functions"))
("bessel_simplify" . ("maxima.info-2" 534530 1148 "Functions and Variables for contrib_ode"))
("bessel_y" . ("maxima.info-1" 640785 423 "Bessel Functions"))
("besselexpand" . ("maxima.info-1" 644498 989 "Bessel Functions"))
("beta" . ("maxima.info-1" 656373 4291 "Gamma and factorial Functions"))
("beta_args_sum_to_integer" . ("maxima.info-1" 676681 207 "Gamma and factorial Functions"))
("beta_expand" . ("maxima.info-1" 676479 201 "Gamma and factorial Functions"))
("beta_incomplete" . ("maxima.info-1" 660665 6083 "Gamma and factorial Functions"))
("beta_incomplete_generalized" . ("maxima.info-1" 671188 5290 "Gamma and factorial Functions"))
("beta_incomplete_regularized" . ("maxima.info-1" 666749 4438 "Gamma and factorial Functions"))
("bezout" . ("maxima.info-1" 572556 650 "Functions and Variables for Polynomials"))
("bf_fft" . ("maxima.info-1" 853894 203 "Functions and Variables for fast Fourier transform"))
("bf_find_root" . ("maxima.info-1" 856002 3968 "Functions for numerical solution of equations"))
("bf_find_root <1>" . ("maxima.info-1" 856064 3906 "Functions for numerical solution of equations"))
("bf_fmin_cobyla" . ("maxima.info-2" 509500 384 "Functions and Variables for cobyla"))
("bf_inverse_fft" . ("maxima.info-1" 853674 219 "Functions and Variables for fast Fourier transform"))
("bf_inverse_real_fft" . ("maxima.info-1" 854288 190 "Functions and Variables for fast Fourier transform"))
("bf_real_fft" . ("maxima.info-1" 854098 189 "Functions and Variables for fast Fourier transform"))
("bfallroots" . ("maxima.info-1" 801802 402 "Functions and Variables for Equations"))
("bffac" . ("maxima.info-1" 647761 219 "Gamma and factorial Functions"))
("bfhzeta" . ("maxima.info-2" 122885 609 "Functions and Variables for Number Theory"))
("bfloat" . ("maxima.info-1" 96164 411 "Functions and Variables for Numbers"))
("bfloatp" . ("maxima.info-1" 96576 103 "Functions and Variables for Numbers"))
("bfpsi" . ("maxima.info-1" 647981 386 "Gamma and factorial Functions"))
("bfpsi0" . ("maxima.info-1" 647982 385 "Gamma and factorial Functions"))
("bftorat" . ("maxima.info-1" 96680 1105 "Functions and Variables for Numbers"))
("bftrunc" . ("maxima.info-1" 97786 282 "Functions and Variables for Numbers"))
("bfzeta" . ("maxima.info-2" 122688 196 "Functions and Variables for Number Theory"))
("biconnected_components" . ("maxima.info-2" 963891 496 "Functions and Variables for graphs"))
("bimetric" . ("maxima.info-2" 39941 197 "Functions and Variables for ctensor"))
("bindtest" . ("maxima.info-1" 428341 575 "Functions and Variables for Properties"))
("binomial" . ("maxima.info-1" 387193 1000 "Combinatorial Functions"))
("bipartition" . ("maxima.info-2" 964388 400 "Functions and Variables for graphs"))
("bit_and" . ("maxima.info-2" 489627 852 "Functions and Variables for bitwise"))
("bit_length" . ("maxima.info-2" 493704 522 "Functions and Variables for bitwise"))
("bit_lsh" . ("maxima.info-2" 492184 751 "Functions and Variables for bitwise"))
("bit_not" . ("maxima.info-2" 489086 540 "Functions and Variables for bitwise"))
("bit_onep" . ("maxima.info-2" 494227 1567 "Functions and Variables for bitwise"))
("bit_or" . ("maxima.info-2" 490480 846 "Functions and Variables for bitwise"))
("bit_rsh" . ("maxima.info-2" 492936 767 "Functions and Variables for bitwise"))
("bit_xor" . ("maxima.info-2" 491327 856 "Functions and Variables for bitwise"))
("block" . ("maxima.info-2" 355080 3191 "Functions and Variables for Function Definition"))
("blockmatrixp" . ("maxima.info-3" 75887 123 "Functions and Variables for linearalgebra"))
("bode_gain" . ("maxima.info-2" 496115 1403 "Functions and Variables for bode"))
("bode_phase" . ("maxima.info-2" 497519 1653 "Functions and Variables for bode"))
("border" . ("maxima.info-2" 721958 598 "Functions and Variables for draw"))
("bothcoef" . ("maxima.info-1" 573207 565 "Functions and Variables for Polynomials"))
("boundaries_array" . ("maxima.info-2" 843078 338 "Functions and Variables for worldmap"))
("box" . ("maxima.info-1" 199140 2124 "Functions and Variables for Expressions"))
("box <1>" . ("maxima.info-1" 503284 177 "Plotting Options"))
("boxchar" . ("maxima.info-1" 201265 318 "Functions and Variables for Expressions"))
("boxplot" . ("maxima.info-2" 599629 3708 "Functions and Variables for statistical graphs"))
("boxplot_description" . ("maxima.info-2" 603338 182 "Functions and Variables for statistical graphs"))
("break" . ("maxima.info-2" 358272 248 "Functions and Variables for Function Definition"))
("breakup" . ("maxima.info-1" 802919 3273 "Functions and Variables for Equations"))
("bug_report" . ("maxima.info-1" 26918 381 "Functions and Variables for Bug Detection and Reporting"))
("build_info" . ("maxima.info-1" 27300 2386 "Functions and Variables for Bug Detection and Reporting"))
("build_sample" . ("maxima.info-2" 545062 2352 "Functions and Variables for data manipulation"))
("buildq" . ("maxima.info-2" 343625 4296 "Macros"))
("burn" . ("maxima.info-2" 123495 902 "Functions and Variables for Number Theory"))
("cabs" . ("maxima.info-1" 377726 3853 "Functions for Complex Numbers"))
("canform" . ("maxima.info-1" 981140 946 "Functions and Variables for itensor"))
("canten" . ("maxima.info-1" 977364 576 "Functions and Variables for itensor"))
("capping" . ("maxima.info-2" 722557 597 "Functions and Variables for draw"))
("capping <1>" . ("maxima.info-2" 880796 253 "Visualization with VTK"))
("cardinality" . ("maxima.info-2" 293167 531 "Functions and Variables for Sets"))
("carg" . ("maxima.info-1" 381580 1888 "Functions for Complex Numbers"))
("cartan" . ("maxima.info-1" 718910 572 "Functions and Variables for Differentiation"))
("cartesian_product" . ("maxima.info-2" 293699 754 "Functions and Variables for Sets"))
("cartesian_product_list" . ("maxima.info-2" 294454 3679 "Functions and Variables for Sets"))
("catch" . ("maxima.info-2" 358521 1106 "Functions and Variables for Function Definition"))
("cauchy_matrix" . ("maxima.info-1" 883451 1398 "Functions and Variables for Matrices and Linear Algebra"))
("cauchysum" . ("maxima.info-2" 86597 1280 "Functions and Variables for Series"))
("cbffac" . ("maxima.info-1" 648368 114 "Gamma and factorial Functions"))
("cbrange" . ("maxima.info-2" 723155 889 "Functions and Variables for draw"))
("cbtics" . ("maxima.info-2" 724045 667 "Functions and Variables for draw"))
("cdf_bernoulli" . ("maxima.info-2" 693136 226 "Functions and Variables for discrete distributions"))
("cdf_beta" . ("maxima.info-2" 663071 424 "Functions and Variables for continuous distributions"))
("cdf_binomial" . ("maxima.info-2" 687994 470 "Functions and Variables for discrete distributions"))
("cdf_cauchy" . ("maxima.info-2" 680416 214 "Functions and Variables for continuous distributions"))
("cdf_chi2" . ("maxima.info-2" 645991 467 "Functions and Variables for continuous distributions"))
("cdf_continuous_uniform" . ("maxima.info-2" 665407 238 "Functions and Variables for continuous distributions"))
("cdf_discrete_uniform" . ("maxima.info-2" 699711 254 "Functions and Variables for discrete distributions"))
("cdf_empirical" . ("maxima.info-2" 578971 1019 "Functions and Variables for descriptive statistics"))
("cdf_exp" . ("maxima.info-2" 654294 385 "Functions and Variables for continuous distributions"))
("cdf_f" . ("maxima.info-2" 651583 463 "Functions and Variables for continuous distributions"))
("cdf_gamma" . ("maxima.info-2" 660457 468 "Functions and Variables for continuous distributions"))
("cdf_general_finite_discrete" . ("maxima.info-2" 684904 867 "Functions and Variables for discrete distributions"))
("cdf_geometric" . ("maxima.info-2" 696327 386 "Functions and Variables for discrete distributions"))
("cdf_gumbel" . ("maxima.info-2" 681512 214 "Functions and Variables for continuous distributions"))
("cdf_hypergeometric" . ("maxima.info-2" 702447 359 "Functions and Variables for discrete distributions"))
("cdf_laplace" . ("maxima.info-2" 678382 216 "Functions and Variables for continuous distributions"))
("cdf_logistic" . ("maxima.info-2" 667701 219 "Functions and Variables for continuous distributions"))
("cdf_lognormal" . ("maxima.info-2" 657735 587 "Functions and Variables for continuous distributions"))
("cdf_negative_binomial" . ("maxima.info-2" 705423 421 "Functions and Variables for discrete distributions"))
("cdf_noncentral_chi2" . ("maxima.info-2" 649331 291 "Functions and Variables for continuous distributions"))
("cdf_noncentral_student_t" . ("maxima.info-2" 641873 438 "Functions and Variables for continuous distributions"))
("cdf_normal" . ("maxima.info-2" 634985 606 "Functions and Variables for continuous distributions"))
("cdf_pareto" . ("maxima.info-2" 669763 216 "Functions and Variables for continuous distributions"))
("cdf_poisson" . ("maxima.info-2" 690708 343 "Functions and Variables for discrete distributions"))
("cdf_rank_sum" . ("maxima.info-3" 292995 248 "Functions and Variables for special distributions"))
("cdf_rayleigh" . ("maxima.info-2" 674091 437 "Functions and Variables for continuous distributions"))
("cdf_signed_rank" . ("maxima.info-3" 292512 234 "Functions and Variables for special distributions"))
("cdf_student_t" . ("maxima.info-2" 637932 602 "Functions and Variables for continuous distributions"))
("cdf_weibull" . ("maxima.info-2" 671815 218 "Functions and Variables for continuous distributions"))
("cdisplay" . ("maxima.info-2" 41041 13542 "Functions and Variables for ctensor"))
("ceiling" . ("maxima.info-1" 368830 3704 "Functions for Numbers"))
("center" . ("maxima.info-2" 881050 352 "Visualization with VTK"))
("central_moment" . ("maxima.info-2" 564541 954 "Functions and Variables for descriptive statistics"))
("cequal" . ("maxima.info-3" 318272 112 "Characters"))
("cequalignore" . ("maxima.info-3" 318385 273 "Characters"))
("cf" . ("maxima.info-2" 125349 2891 "Functions and Variables for Number Theory"))
("cfdisrep" . ("maxima.info-2" 128241 684 "Functions and Variables for Number Theory"))
("cfexpand" . ("maxima.info-2" 128926 640 "Functions and Variables for Number Theory"))
("cflength" . ("maxima.info-2" 129567 614 "Functions and Variables for Number Theory"))
("cframe_flag" . ("maxima.info-2" 55675 431 "Functions and Variables for ctensor"))
("cgeodesic" . ("maxima.info-2" 38788 292 "Functions and Variables for ctensor"))
("cgreaterp" . ("maxima.info-3" 318659 145 "Characters"))
("cgreaterpignore" . ("maxima.info-3" 318805 279 "Characters"))
("changename" . ("maxima.info-1" 954834 354 "Functions and Variables for itensor"))
("changevar" . ("maxima.info-1" 740345 2300 "Functions and Variables for Integration"))
("chaosgame" . ("maxima.info-2" 867039 761 "Graphical analysis of discrete dynamical systems"))
("charat" . ("maxima.info-3" 325760 309 "String Processing"))
("charfun" . ("maxima.info-1" 464559 609 "Functions and Variables for Predicates"))
("charfun2" . ("maxima.info-3" 21864 1272 "Functions and Variables for interpol"))
("charlist" . ("maxima.info-3" 326070 172 "String Processing"))
("charp" . ("maxima.info-3" 319085 117 "Characters"))
("charpoly" . ("maxima.info-1" 884850 1629 "Functions and Variables for Matrices and Linear Algebra"))
("chdir" . ("maxima.info-3" 162578 59 "Directory operations"))
("chebyshev_t" . ("maxima.info-3" 185233 168 "Functions and Variables for orthogonal polynomials"))
("chebyshev_u" . ("maxima.info-3" 185402 169 "Functions and Variables for orthogonal polynomials"))
("check_overlaps" . ("maxima.info-1" 939031 627 "Functions and Variables for Affine"))
("checkdiv" . ("maxima.info-2" 38345 442 "Functions and Variables for ctensor"))
("chinese" . ("maxima.info-2" 124398 950 "Functions and Variables for Number Theory"))
("cholesky" . ("maxima.info-3" 76685 310 "Functions and Variables for linearalgebra"))
("christof" . ("maxima.info-2" 13636 894 "Functions and Variables for ctensor"))
("chromatic_index" . ("maxima.info-2" 964789 255 "Functions and Variables for graphs"))
("chromatic_number" . ("maxima.info-2" 965045 327 "Functions and Variables for graphs"))
("cint" . ("maxima.info-3" 319203 917 "Characters"))
("circulant_graph" . ("maxima.info-2" 955643 580 "Functions and Variables for graphs"))
("clear_edge_weight" . ("maxima.info-2" 965373 439 "Functions and Variables for graphs"))
("clear_rules" . ("maxima.info-2" 283984 170 "Functions and Variables for Rules and Patterns"))
("clear_vertex_label" . ("maxima.info-2" 965813 480 "Functions and Variables for graphs"))
("clebsch_gordan" . ("maxima.info-2" 503567 134 "Functions and Variables for clebsch_gordan"))
("clebsch_graph" . ("maxima.info-2" 956224 63 "Functions and Variables for graphs"))
("clessp" . ("maxima.info-3" 320121 139 "Characters"))
("clesspignore" . ("maxima.info-3" 320261 273 "Characters"))
("close" . ("maxima.info-3" 300631 99 "Input and Output"))
("closefile" . ("maxima.info-1" 536921 99 "Functions and Variables for File Input and Output"))
("cmetric" . ("maxima.info-2" 5122 922 "Functions and Variables for ctensor"))
("cnonmet_flag" . ("maxima.info-2" 56348 282 "Functions and Variables for ctensor"))
("coeff" . ("maxima.info-1" 573773 3800 "Functions and Variables for Polynomials"))
("coefmatrix" . ("maxima.info-1" 886480 447 "Functions and Variables for Matrices and Linear Algebra"))
("cograd" . ("maxima.info-2" 36106 197 "Functions and Variables for ctensor"))
("col" . ("maxima.info-1" 886928 116 "Functions and Variables for Matrices and Linear Algebra"))
("collapse" . ("maxima.info-1" 201584 534 "Functions and Variables for Expressions"))
("collectterms" . ("maxima.info-3" 227295 1236 "Package facexp"))
("color" . ("maxima.info-1" 503462 749 "Plotting Options"))
("color <1>" . ("maxima.info-2" 724713 3844 "Functions and Variables for draw"))
("color <2>" . ("maxima.info-2" 881403 208 "Visualization with VTK"))
("color_bar" . ("maxima.info-1" 504212 375 "Plotting Options"))
("color_bar_tics" . ("maxima.info-1" 504588 469 "Plotting Options"))
("colorbox" . ("maxima.info-2" 728558 1008 "Functions and Variables for draw"))
("columnop" . ("maxima.info-3" 76011 233 "Functions and Variables for linearalgebra"))
("columns" . ("maxima.info-2" 729567 631 "Functions and Variables for draw"))
("columnspace" . ("maxima.info-3" 76403 281 "Functions and Variables for linearalgebra"))
("columnswap" . ("maxima.info-3" 76245 157 "Functions and Variables for linearalgebra"))
("columnvector" . ("maxima.info-1" 887045 947 "Functions and Variables for Matrices and Linear Algebra"))
("combination" . ("maxima.info-3" 234745 173 "Package functs"))
("combine" . ("maxima.info-1" 335223 581 "Functions and Variables for Simplification"))
("commutative" . ("maxima.info-1" 335805 736 "Functions and Variables for Simplification"))
("comp2pui" . ("maxima.info-2" 178324 598 "Functions and Variables for Symmetries"))
("compare" . ("maxima.info-1" 465169 1133 "Functions and Variables for Predicates"))
("compfile" . ("maxima.info-2" 359628 780 "Functions and Variables for Function Definition"))
("compile" . ("maxima.info-2" 360409 1536 "Functions and Variables for Function Definition"))
("compile_file" . ("maxima.info-2" 412359 1319 "Functions and Variables for Function Definition"))
("complement_graph" . ("maxima.info-2" 956288 83 "Functions and Variables for graphs"))
("complete_bipartite_graph" . ("maxima.info-2" 956372 111 "Functions and Variables for graphs"))
("complete_graph" . ("maxima.info-2" 956484 84 "Functions and Variables for graphs"))
("complex" . ("maxima.info-1" 445681 195 "Functions and Variables for Properties"))
("complex_number_p" . ("maxima.info-3" 357673 885 "Functions and Variables for to_poly_solve"))
("components" . ("maxima.info-1" 963155 4125 "Functions and Variables for itensor"))
("compose_functions" . ("maxima.info-3" 358559 2005 "Functions and Variables for to_poly_solve"))
("concan" . ("maxima.info-1" 977941 93 "Functions and Variables for itensor"))
("concat" . ("maxima.info-1" 109703 1444 "Functions and Variables for Strings"))
("conditional evaluation" . ("maxima.info-3" 353275 1591 "Functions and Variables for to_poly_solve"))
("cone" . ("maxima.info-2" 878201 860 "Visualization with VTK"))
("conjugate" . ("maxima.info-1" 383469 521 "Functions for Complex Numbers"))
("conmetderiv" . ("maxima.info-1" 990034 873 "Functions and Variables for itensor"))
("connect_vertices" . ("maxima.info-2" 991100 558 "Functions and Variables for graphs"))
("connected_components" . ("maxima.info-2" 966294 332 "Functions and Variables for graphs"))
("cons" . ("maxima.info-1" 122516 1442 "Functions and Variables for Lists"))
("constant" . ("maxima.info-1" 428917 563 "Functions and Variables for Properties"))
("constantp" . ("maxima.info-1" 429481 1251 "Functions and Variables for Properties"))
("constituent" . ("maxima.info-3" 320535 625 "Characters"))
("constvalue" . ("maxima.info-2" 910997 867 "Functions and Variables for ezunits"))
("cont2part" . ("maxima.info-2" 187478 441 "Functions and Variables for Symmetries"))
("content" . ("maxima.info-1" 577574 474 "Functions and Variables for Polynomials"))
("context" . ("maxima.info-1" 456797 565 "Functions and Variables for Facts"))
("contexts" . ("maxima.info-1" 457363 1354 "Functions and Variables for Facts"))
("continuous_freq" . ("maxima.info-2" 547415 2740 "Functions and Variables for data manipulation"))
("contortion" . ("maxima.info-2" 33106 165 "Functions and Variables for ctensor"))
("contour" . ("maxima.info-2" 730199 1113 "Functions and Variables for draw"))
("contour_levels" . ("maxima.info-2" 731313 1908 "Functions and Variables for draw"))
("contour_plot" . ("maxima.info-1" 478884 1113 "Functions and Variables for Plotting"))
("contract" . ("maxima.info-1" 962427 492 "Functions and Variables for itensor"))
("contract <1>" . ("maxima.info-2" 187920 836 "Functions and Variables for Symmetries"))
("contract_edge" . ("maxima.info-2" 991659 790 "Functions and Variables for graphs"))
("contragrad" . ("maxima.info-2" 36304 1137 "Functions and Variables for ctensor"))
("contrib_ode" . ("maxima.info-2" 530416 158 "Functions and Variables for contrib_ode"))
("convert" . ("maxima.info-3" 409833 3430 "Functions and Variables for Units"))
("coord" . ("maxima.info-1" 989083 395 "Functions and Variables for itensor"))
("copy" . ("maxima.info-1" 202119 823 "Functions and Variables for Expressions"))
("copy_file" . ("maxima.info-3" 163216 79 "File operations"))
("copy_graph" . ("maxima.info-2" 955573 69 "Functions and Variables for graphs"))
("copylist" . ("maxima.info-1" 123959 73 "Functions and Variables for Lists"))
("copymatrix" . ("maxima.info-1" 887993 445 "Functions and Variables for Matrices and Linear Algebra"))
("cor" . ("maxima.info-2" 584325 2175 "Functions and Variables for descriptive statistics"))
("cos" . ("maxima.info-1" 414728 40 "Functions and Variables for Trigonometric"))
("cosh" . ("maxima.info-1" 414769 52 "Functions and Variables for Trigonometric"))
("cosnpiflag" . ("maxima.info-2" 116676 81 "Functions and Variables for Fourier series"))
("cot" . ("maxima.info-1" 414822 43 "Functions and Variables for Trigonometric"))
("coth" . ("maxima.info-1" 414866 55 "Functions and Variables for Trigonometric"))
("cov" . ("maxima.info-2" 579991 1265 "Functions and Variables for descriptive statistics"))
("cov1" . ("maxima.info-2" 581257 1265 "Functions and Variables for descriptive statistics"))
("covdiff" . ("maxima.info-1" 996022 1935 "Functions and Variables for itensor"))
("covect" . ("maxima.info-1" 887046 946 "Functions and Variables for Matrices and Linear Algebra"))
("covers" . ("maxima.info-3" 234364 130 "Package functs"))
("crc24sum" . ("maxima.info-3" 339931 1768 "Octets and Utilities for Cryptography"))
("create_graph" . ("maxima.info-2" 953703 1869 "Functions and Variables for graphs"))
("create_list" . ("maxima.info-1" 124033 1235 "Functions and Variables for Lists"))
("csc" . ("maxima.info-1" 414922 42 "Functions and Variables for Trigonometric"))
("csch" . ("maxima.info-1" 414965 54 "Functions and Variables for Trigonometric"))
("csetup" . ("maxima.info-2" 4911 210 "Functions and Variables for ctensor"))
("cspline" . ("maxima.info-3" 25776 4565 "Functions and Variables for interpol"))
("ct_coords" . ("maxima.info-2" 60921 393 "Functions and Variables for ctensor"))
("ct_coordsys" . ("maxima.info-2" 6045 6222 "Functions and Variables for ctensor"))
("ctaylor" . ("maxima.info-2" 19695 5374 "Functions and Variables for ctensor"))
("ctaypov" . ("maxima.info-2" 57003 122 "Functions and Variables for ctensor"))
("ctaypt" . ("maxima.info-2" 57126 133 "Functions and Variables for ctensor"))
("ctayswitch" . ("maxima.info-2" 56631 254 "Functions and Variables for ctensor"))
("ctayvar" . ("maxima.info-2" 56886 116 "Functions and Variables for ctensor"))
("ctorsion_flag" . ("maxima.info-2" 56107 240 "Functions and Variables for ctensor"))
("ctransform" . ("maxima.info-2" 33459 300 "Functions and Variables for ctensor"))
("ctranspose" . ("maxima.info-3" 76996 198 "Functions and Variables for linearalgebra"))
("ctrgsimp" . ("maxima.info-2" 55478 196 "Functions and Variables for ctensor"))
("cube" . ("maxima.info-2" 879062 324 "Visualization with VTK"))
("cube_graph" . ("maxima.info-2" 956805 70 "Functions and Variables for graphs"))
("cuboctahedron_graph" . ("maxima.info-2" 956726 78 "Functions and Variables for graphs"))
("current_let_rule_package" . ("maxima.info-2" 245638 574 "Functions and Variables for Rules and Patterns"))
("cv" . ("maxima.info-2" 565496 645 "Functions and Variables for descriptive statistics"))
("cycle_digraph" . ("maxima.info-2" 956569 83 "Functions and Variables for graphs"))
("cycle_graph" . ("maxima.info-2" 956653 72 "Functions and Variables for graphs"))
("cyclep" . ("maxima.info-2" 513797 617 "Functions and Variables for Combinatorics"))
("cylinder" . ("maxima.info-2" 879387 632 "Visualization with VTK"))
("cylindrical" . ("maxima.info-2" 806755 722 "Functions and Variables for draw"))
("data_file_name" . ("maxima.info-2" 733222 390 "Functions and Variables for draw"))
("days360" . ("maxima.info-2" 932951 304 "Functions and Variables for finance"))
("dblint" . ("maxima.info-1" 742646 2472 "Functions and Variables for Integration"))
("deactivate" . ("maxima.info-1" 458718 129 "Functions and Variables for Facts"))
("debugmode" . ("maxima.info-2" 459028 379 "Functions and Variables for Debugging"))
("declare" . ("maxima.info-1" 430733 5142 "Functions and Variables for Properties"))
("declare_constvalue" . ("maxima.info-2" 911865 595 "Functions and Variables for ezunits"))
("declare_dimensions" . ("maxima.info-2" 919396 979 "Functions and Variables for ezunits"))
("declare_fundamental_dimensions" . ("maxima.info-2" 920541 1369 "Functions and Variables for ezunits"))
("declare_fundamental_units" . ("maxima.info-2" 921911 1678 "Functions and Variables for ezunits"))
("declare_index_properties" . ("maxima.info-1" 64752 3517 "Functions and Variables for Display"))
("declare_index_properties <1>" . ("maxima.info-1" 64753 3516 "Functions and Variables for Display"))
("declare_qty" . ("maxima.info-2" 915677 680 "Functions and Variables for ezunits"))
("declare_translated" . ("maxima.info-2" 413679 619 "Functions and Variables for Function Definition"))
("declare_unit_conversion" . ("maxima.info-2" 917549 1846 "Functions and Variables for ezunits"))
("declare_units" . ("maxima.info-2" 913958 747 "Functions and Variables for ezunits"))
("declare_weights" . ("maxima.info-1" 937963 242 "Functions and Variables for Affine"))
("decode_time" . ("maxima.info-2" 231296 1741 "Functions and Variables for Runtime Environment"))
("decreasing" . ("maxima.info-1" 435876 602 "Functions and Variables for Properties"))
("decsym" . ("maxima.info-1" 978443 2534 "Functions and Variables for itensor"))
("default_let_rule_package" . ("maxima.info-2" 246213 283 "Functions and Variables for Rules and Patterns"))
("defcon" . ("maxima.info-1" 961151 1012 "Functions and Variables for itensor"))
("define" . ("maxima.info-2" 361946 4114 "Functions and Variables for Function Definition"))
("define_alt_display" . ("maxima.info-2" 471325 1579 "Functions and Variables for alt-display"))
("define_opproperty" . ("maxima.info-1" 356309 1557 "Functions and Variables for Simplification"))
("define_variable" . ("maxima.info-2" 366061 4166 "Functions and Variables for Function Definition"))
("defint" . ("maxima.info-1" 745119 550 "Functions and Variables for Integration"))
("defmatch" . ("maxima.info-2" 246497 4532 "Functions and Variables for Rules and Patterns"))
("defrule" . ("maxima.info-2" 251030 695 "Functions and Variables for Rules and Patterns"))
("defstruct" . ("maxima.info-1" 185485 1556 "Functions and Variables for Structures"))
("deftaylor" . ("maxima.info-2" 87878 1329 "Functions and Variables for Series"))
("degree_sequence" . ("maxima.info-2" 967598 258 "Functions and Variables for graphs"))
("del" . ("maxima.info-1" 719483 687 "Functions and Variables for Differentiation"))
("delay" . ("maxima.info-2" 733613 831 "Functions and Variables for draw"))
("delete" . ("maxima.info-1" 125269 2401 "Functions and Variables for Lists"))
("delete_file" . ("maxima.info-3" 163379 64 "File operations"))
("deleten" . ("maxima.info-2" 54584 114 "Functions and Variables for ctensor"))
("delta" . ("maxima.info-1" 720171 354 "Functions and Variables for Differentiation"))
("demo" . ("maxima.info-1" 32177 1196 "Functions and Variables for Help"))
("demoivre" . ("maxima.info-1" 336542 666 "Functions and Variables for Simplification"))
("demoivre <1>" . ("maxima.info-1" 336543 665 "Functions and Variables for Simplification"))
("denom" . ("maxima.info-1" 578049 729 "Functions and Variables for Polynomials"))
("dependencies" . ("maxima.info-1" 720526 1654 "Functions and Variables for Differentiation"))
("dependencies <1>" . ("maxima.info-1" 720527 1653 "Functions and Variables for Differentiation"))
("depends" . ("maxima.info-1" 722181 2568 "Functions and Variables for Differentiation"))
("derivabbrev" . ("maxima.info-1" 724750 252 "Functions and Variables for Differentiation"))
("derivdegree" . ("maxima.info-1" 725003 615 "Functions and Variables for Differentiation"))
("derivlist" . ("maxima.info-1" 725619 154 "Functions and Variables for Differentiation"))
("derivsubst" . ("maxima.info-1" 725774 203 "Functions and Variables for Differentiation"))
("describe" . ("maxima.info-1" 33374 2860 "Functions and Variables for Help"))
("desolve" . ("maxima.info-1" 835876 2224 "Functions and Variables for Differential Equations"))
("determinant" . ("maxima.info-1" 888439 346 "Functions and Variables for Matrices and Linear Algebra"))
("detout" . ("maxima.info-1" 888786 973 "Functions and Variables for Matrices and Linear Algebra"))
("dfloat" . ("maxima.info-3" 360565 1058 "Functions and Variables for to_poly_solve"))
("dgauss_a" . ("maxima.info-2" 533467 123 "Functions and Variables for contrib_ode"))
("dgauss_b" . ("maxima.info-2" 533591 123 "Functions and Variables for contrib_ode"))
("dgeev" . ("maxima.info-3" 32446 2923 "Functions and Variables for lapack"))
("dgemm" . ("maxima.info-3" 46261 5373 "Functions and Variables for lapack"))
("dgeqrf" . ("maxima.info-3" 35370 1504 "Functions and Variables for lapack"))
("dgesv" . ("maxima.info-3" 36875 3454 "Functions and Variables for lapack"))
("dgesvd" . ("maxima.info-3" 40330 5167 "Functions and Variables for lapack"))
("diag" . ("maxima.info-2" 615828 1262 "Functions and Variables for diag"))
("diag_matrix" . ("maxima.info-3" 77195 974 "Functions and Variables for linearalgebra"))
("diagmatrix" . ("maxima.info-1" 889760 488 "Functions and Variables for Matrices and Linear Algebra"))
("diagmatrixp" . ("maxima.info-2" 40189 145 "Functions and Variables for ctensor"))
("diagmetric" . ("maxima.info-2" 55019 458 "Functions and Variables for ctensor"))
("diameter" . ("maxima.info-2" 966627 215 "Functions and Variables for graphs"))
("diff" . ("maxima.info-1" 729247 149 "Functions and Variables for Differentiation"))
("diff <1>" . ("maxima.info-1" 725978 3268 "Functions and Variables for Differentiation"))
("diff <2>" . ("maxima.info-1" 982151 1388 "Functions and Variables for itensor"))
("digitcharp" . ("maxima.info-3" 321161 153 "Characters"))
("dim" . ("maxima.info-2" 54769 249 "Functions and Variables for ctensor"))
("dimacs_export" . ("maxima.info-2" 992984 257 "Functions and Variables for graphs"))
("dimacs_import" . ("maxima.info-2" 993242 96 "Functions and Variables for graphs"))
("dimension" . ("maxima.info-1" 806193 247 "Functions and Variables for Equations"))
("dimensionless" . ("maxima.info-2" 926717 1099 "Functions and Variables for ezunits"))
("dimensions" . ("maxima.info-2" 734445 1527 "Functions and Variables for draw"))
("dimensions <1>" . ("maxima.info-2" 923590 1774 "Functions and Variables for ezunits"))
("dimensions_as_list" . ("maxima.info-2" 923591 1773 "Functions and Variables for ezunits"))
("direct" . ("maxima.info-2" 190139 3669 "Functions and Variables for Symmetries"))
("directory" . ("maxima.info-1" 546125 470 "Functions and Variables for File Input and Output"))
("discrete_freq" . ("maxima.info-2" 550156 1331 "Functions and Variables for data manipulation"))
("disjoin" . ("maxima.info-2" 298134 681 "Functions and Variables for Sets"))
("disjointp" . ("maxima.info-2" 298816 384 "Functions and Variables for Sets"))
("disolate" . ("maxima.info-1" 202943 495 "Functions and Variables for Expressions"))
("disp" . ("maxima.info-1" 73854 679 "Functions and Variables for Display"))
("dispJordan" . ("maxima.info-2" 620333 1159 "Functions and Variables for diag"))
("dispcon" . ("maxima.info-1" 954249 267 "Functions and Variables for itensor"))
("dispflag" . ("maxima.info-1" 806441 294 "Functions and Variables for Equations"))
("dispform" . ("maxima.info-1" 203439 1885 "Functions and Variables for Expressions"))
("dispfun" . ("maxima.info-2" 370228 3748 "Functions and Variables for Function Definition"))
("display" . ("maxima.info-1" 74534 863 "Functions and Variables for Display"))
("display2d" . ("maxima.info-1" 75398 1037 "Functions and Variables for Display"))
("display_format_internal" . ("maxima.info-1" 76436 689 "Functions and Variables for Display"))
("display_index_separator" . ("maxima.info-1" 68725 5128 "Functions and Variables for Display"))
("disprule" . ("maxima.info-2" 251726 1382 "Functions and Variables for Rules and Patterns"))
("dispterms" . ("maxima.info-1" 77126 944 "Functions and Variables for Display"))
("distrib" . ("maxima.info-1" 337209 896 "Functions and Variables for Simplification"))
("distribute_over" . ("maxima.info-1" 338106 2235 "Functions and Variables for Simplification"))
("divide" . ("maxima.info-1" 578779 625 "Functions and Variables for Polynomials"))
("divisors" . ("maxima.info-2" 299201 1573 "Functions and Variables for Sets"))
("divsum" . ("maxima.info-2" 130182 563 "Functions and Variables for Number Theory"))
("dkummer_m" . ("maxima.info-2" 534308 110 "Functions and Variables for contrib_ode"))
("dkummer_u" . ("maxima.info-2" 534419 110 "Functions and Variables for contrib_ode"))
("dlange" . ("maxima.info-3" 45498 762 "Functions and Variables for lapack"))
("dlsode_init" . ("maxima.info-3" 158089 1440 "Functions and Variables for odepack"))
("dlsode_step" . ("maxima.info-3" 159530 2279 "Functions and Variables for odepack"))
("do" . ("maxima.info-2" 421714 9088 "Functions and Variables for Program Flow"))
("doallmxops" . ("maxima.info-1" 890249 266 "Functions and Variables for Matrices and Linear Algebra"))
("dodecahedron_graph" . ("maxima.info-2" 956876 73 "Functions and Variables for graphs"))
("domain" . ("maxima.info-1" 340342 170 "Functions and Variables for Simplification"))
("domxexpt" . ("maxima.info-1" 890516 1280 "Functions and Variables for Matrices and Linear Algebra"))
("domxmxops" . ("maxima.info-1" 891797 261 "Functions and Variables for Matrices and Linear Algebra"))
("domxnctimes" . ("maxima.info-1" 892059 156 "Functions and Variables for Matrices and Linear Algebra"))
("dontfactor" . ("maxima.info-1" 892216 430 "Functions and Variables for Matrices and Linear Algebra"))
("doscmxops" . ("maxima.info-1" 892647 140 "Functions and Variables for Matrices and Linear Algebra"))
("doscmxplus" . ("maxima.info-1" 892788 197 "Functions and Variables for Matrices and Linear Algebra"))
("dot0nscsimp" . ("maxima.info-1" 892986 196 "Functions and Variables for Matrices and Linear Algebra"))
("dot0simp" . ("maxima.info-1" 893183 187 "Functions and Variables for Matrices and Linear Algebra"))
("dot1simp" . ("maxima.info-1" 893371 185 "Functions and Variables for Matrices and Linear Algebra"))
("dotassoc" . ("maxima.info-1" 893557 144 "Functions and Variables for Matrices and Linear Algebra"))
("dotconstrules" . ("maxima.info-1" 893702 305 "Functions and Variables for Matrices and Linear Algebra"))
("dotdistrib" . ("maxima.info-1" 894008 153 "Functions and Variables for Matrices and Linear Algebra"))
("dotexptsimp" . ("maxima.info-1" 894162 143 "Functions and Variables for Matrices and Linear Algebra"))
("dotident" . ("maxima.info-1" 894306 102 "Functions and Variables for Matrices and Linear Algebra"))
("dotproduct" . ("maxima.info-3" 78170 207 "Functions and Variables for linearalgebra"))
("dotscrules" . ("maxima.info-1" 894409 193 "Functions and Variables for Matrices and Linear Algebra"))
("dotsimp" . ("maxima.info-1" 938370 247 "Functions and Variables for Affine"))
("dpart" . ("maxima.info-1" 205325 606 "Functions and Variables for Expressions"))
("draw" . ("maxima.info-2" 712662 2029 "Functions and Variables for draw"))
("draw2d" . ("maxima.info-2" 714692 267 "Functions and Variables for draw"))
("draw3d" . ("maxima.info-2" 714960 267 "Functions and Variables for draw"))
("draw_file" . ("maxima.info-2" 715228 440 "Functions and Variables for draw"))
("draw_graph" . ("maxima.info-2" 994326 3227 "Functions and Variables for graphs"))
("draw_graph_program" . ("maxima.info-2" 997554 175 "Functions and Variables for graphs"))
("draw_realpart" . ("maxima.info-2" 735973 674 "Functions and Variables for draw"))
("drawdf" . ("maxima.info-2" 857661 8197 "Functions and Variables for drawdf"))
("dscalar" . ("maxima.info-2" 37442 902 "Functions and Variables for ctensor"))
("e" . ("maxima.info-1" 113198 206 "Functions and Variables for Constants"))
("echelon" . ("maxima.info-1" 894603 1459 "Functions and Variables for Matrices and Linear Algebra"))
("edge_color" . ("maxima.info-2" 999518 76 "Functions and Variables for graphs"))
("edge_coloring" . ("maxima.info-2" 1000437 161 "Functions and Variables for graphs"))
("edge_coloring <1>" . ("maxima.info-2" 966843 754 "Functions and Variables for graphs"))
("edge_connectivity" . ("maxima.info-2" 967857 124 "Functions and Variables for graphs"))
("edge_partition" . ("maxima.info-2" 1000237 199 "Functions and Variables for graphs"))
("edge_type" . ("maxima.info-2" 999655 128 "Functions and Variables for graphs"))
("edge_width" . ("maxima.info-2" 999595 59 "Functions and Variables for graphs"))
("edges" . ("maxima.info-2" 967982 250 "Functions and Variables for graphs"))
("eigens_by_jacobi" . ("maxima.info-3" 78378 3115 "Functions and Variables for linearalgebra"))
("eigenvalues" . ("maxima.info-1" 896063 1612 "Functions and Variables for Matrices and Linear Algebra"))
("eigenvectors" . ("maxima.info-1" 897676 4774 "Functions and Variables for Matrices and Linear Algebra"))
("eighth" . ("maxima.info-1" 127671 123 "Functions and Variables for Lists"))
("einstein" . ("maxima.info-2" 15495 594 "Functions and Variables for ctensor"))
("eivals" . ("maxima.info-1" 896064 1611 "Functions and Variables for Matrices and Linear Algebra"))
("eivects" . ("maxima.info-1" 897677 4773 "Functions and Variables for Matrices and Linear Algebra"))
("elapsed_real_time" . ("maxima.info-2" 233468 498 "Functions and Variables for Runtime Environment"))
("elapsed_run_time" . ("maxima.info-2" 233967 553 "Functions and Variables for Runtime Environment"))
("ele2comp" . ("maxima.info-2" 179132 208 "Functions and Variables for Symmetries"))
("ele2polynome" . ("maxima.info-2" 199696 816 "Functions and Variables for Symmetries"))
("ele2pui" . ("maxima.info-2" 178923 208 "Functions and Variables for Symmetries"))
("elem" . ("maxima.info-2" 179341 1436 "Functions and Variables for Symmetries"))
("elementp" . ("maxima.info-2" 300775 387 "Functions and Variables for Sets"))
("elevation" . ("maxima.info-1" 505058 518 "Plotting Options"))
("elevation <1>" . ("maxima.info-2" 876548 329 "Visualization with VTK"))
("elevation_grid" . ("maxima.info-2" 807478 1018 "Functions and Variables for draw"))
("elim" . ("maxima.info-3" 361624 2599 "Functions and Variables for to_poly_solve"))
("elim_allbut" . ("maxima.info-3" 364224 719 "Functions and Variables for to_poly_solve"))
("eliminate" . ("maxima.info-1" 579405 1311 "Functions and Variables for Polynomials"))
("eliminate_using" . ("maxima.info-3" 364944 1438 "Functions and Variables for to_poly_solve"))
("ellipse" . ("maxima.info-2" 808497 1176 "Functions and Variables for draw"))
("elliptic_e" . ("maxima.info-1" 703142 236 "Functions and Variables for Elliptic Integrals"))
("elliptic_ec" . ("maxima.info-1" 704195 287 "Functions and Variables for Elliptic Integrals"))
("elliptic_eu" . ("maxima.info-1" 703379 349 "Functions and Variables for Elliptic Integrals"))
("elliptic_f" . ("maxima.info-1" 702925 216 "Functions and Variables for Elliptic Integrals"))
("elliptic_kc" . ("maxima.info-1" 703908 286 "Functions and Variables for Elliptic Integrals"))
("elliptic_pi" . ("maxima.info-1" 703729 178 "Functions and Variables for Elliptic Integrals"))
("ematrix" . ("maxima.info-1" 902451 170 "Functions and Variables for Matrices and Linear Algebra"))
("empty_graph" . ("maxima.info-2" 956950 78 "Functions and Variables for graphs"))
("emptyp" . ("maxima.info-2" 301163 316 "Functions and Variables for Sets"))
("encode_time" . ("maxima.info-2" 228780 2515 "Functions and Variables for Runtime Environment"))
("endcons" . ("maxima.info-1" 127795 1371 "Functions and Variables for Lists"))
("endphi" . ("maxima.info-2" 881612 453 "Visualization with VTK"))
("endtheta" . ("maxima.info-2" 882066 449 "Visualization with VTK"))
("engineering_format_floats" . ("maxima.info-2" 889443 561 "Functions and Variables for engineering-format"))
("engineering_format_max" . ("maxima.info-2" 890776 245 "Functions and Variables for engineering-format"))
("engineering_format_min" . ("maxima.info-2" 890005 770 "Functions and Variables for engineering-format"))
("enhanced3d" . ("maxima.info-2" 736648 5642 "Functions and Variables for draw"))
("entermatrix" . ("maxima.info-1" 902622 1369 "Functions and Variables for Matrices and Linear Algebra"))
("entertensor" . ("maxima.info-1" 954517 316 "Functions and Variables for itensor"))
("entier" . ("maxima.info-1" 372535 203 "Functions for Numbers"))
("epsilon_lp" . ("maxima.info-3" 214389 821 "Functions and Variables for simplex"))
("equal" . ("maxima.info-1" 466303 4203 "Functions and Variables for Predicates"))
("equalp" . ("maxima.info-2" 114829 173 "Functions and Variables for Fourier series"))
("equiv_classes" . ("maxima.info-2" 301480 1344 "Functions and Variables for Sets"))
("erf" . ("maxima.info-1" 682122 99 "Error Function"))
("erf_generalized" . ("maxima.info-1" 682426 85 "Error Function"))
("erf_representation" . ("maxima.info-1" 683301 161 "Error Function"))
("erfc" . ("maxima.info-1" 682222 110 "Error Function"))
("erfflag" . ("maxima.info-1" 745670 217 "Functions and Variables for Integration"))
("erfi" . ("maxima.info-1" 682333 92 "Error Function"))
("errcatch" . ("maxima.info-2" 430803 531 "Functions and Variables for Program Flow"))
("error" . ("maxima.info-2" 431335 618 "Functions and Variables for Program Flow"))
("error <1>" . ("maxima.info-2" 431336 617 "Functions and Variables for Program Flow"))
("error_size" . ("maxima.info-2" 432262 1544 "Functions and Variables for Program Flow"))
("error_syms" . ("maxima.info-2" 433807 628 "Functions and Variables for Program Flow"))
("error_type" . ("maxima.info-2" 742291 312 "Functions and Variables for draw"))
("errormsg" . ("maxima.info-2" 434593 1167 "Functions and Variables for Program Flow"))
("errormsg <1>" . ("maxima.info-2" 434436 156 "Functions and Variables for Program Flow"))
("errors" . ("maxima.info-2" 809674 1361 "Functions and Variables for draw"))
("euler" . ("maxima.info-2" 130746 522 "Functions and Variables for Number Theory"))
("ev" . ("maxima.info-1" 307011 8677 "Functions and Variables for Evaluation"))
("ev_point" . ("maxima.info-3" 439055 189 "Functions and Variables for zeilberger"))
("eval" . ("maxima.info-1" 315689 545 "Functions and Variables for Evaluation"))
("eval_string" . ("maxima.info-3" 326243 585 "String Processing"))
("even" . ("maxima.info-1" 436479 649 "Functions and Variables for Properties"))
("evenfun" . ("maxima.info-1" 340513 673 "Functions and Variables for Simplification"))
("evenp" . ("maxima.info-1" 98069 204 "Functions and Variables for Numbers"))
("every" . ("maxima.info-2" 302825 2814 "Functions and Variables for Sets"))
("evflag" . ("maxima.info-1" 316235 2527 "Functions and Variables for Evaluation"))
("evfun" . ("maxima.info-1" 318763 2896 "Functions and Variables for Evaluation"))
("evolution" . ("maxima.info-2" 867801 741 "Graphical analysis of discrete dynamical systems"))
("evolution2d" . ("maxima.info-2" 868543 1033 "Graphical analysis of discrete dynamical systems"))
("evundiff" . ("maxima.info-1" 985668 2373 "Functions and Variables for itensor"))
("example" . ("maxima.info-1" 36235 1384 "Functions and Variables for Help"))
("exp" . ("maxima.info-1" 398055 933 "Root Exponential and Logarithmic Functions"))
("expand" . ("maxima.info-1" 341187 4175 "Functions and Variables for Simplification"))
("expandwrt" . ("maxima.info-1" 345363 567 "Functions and Variables for Simplification"))
("expandwrt_denom" . ("maxima.info-1" 345931 393 "Functions and Variables for Simplification"))
("expandwrt_factored" . ("maxima.info-1" 346325 343 "Functions and Variables for Simplification"))
("expintegral_chi" . ("maxima.info-1" 680732 184 "Exponential Integrals"))
("expintegral_ci" . ("maxima.info-1" 680417 181 "Exponential Integrals"))
("expintegral_e" . ("maxima.info-1" 680095 191 "Exponential Integrals"))
("expintegral_e1" . ("maxima.info-1" 679771 155 "Exponential Integrals"))
("expintegral_e_simplify" . ("maxima.info-2" 535679 248 "Functions and Variables for contrib_ode"))
("expintegral_ei" . ("maxima.info-1" 679927 83 "Exponential Integrals"))
("expintegral_li" . ("maxima.info-1" 680011 83 "Exponential Integrals"))
("expintegral_shi" . ("maxima.info-1" 680599 132 "Exponential Integrals"))
("expintegral_si" . ("maxima.info-1" 680287 129 "Exponential Integrals"))
("expintexpand" . ("maxima.info-1" 681631 203 "Exponential Integrals"))
("expintrep" . ("maxima.info-1" 680917 713 "Exponential Integrals"))
("explicit" . ("maxima.info-2" 811036 1960 "Functions and Variables for draw"))
("explose" . ("maxima.info-2" 188757 263 "Functions and Variables for Symmetries"))
("expon" . ("maxima.info-1" 346669 276 "Functions and Variables for Simplification"))
("exponentialize" . ("maxima.info-1" 346946 569 "Functions and Variables for Simplification"))
("exponentialize <1>" . ("maxima.info-1" 346947 568 "Functions and Variables for Simplification"))
("expop" . ("maxima.info-1" 347516 429 "Functions and Variables for Simplification"))
("express" . ("maxima.info-1" 729397 2712 "Functions and Variables for Differentiation"))
("expt" . ("maxima.info-1" 78071 302 "Functions and Variables for Display"))
("exptdispflag" . ("maxima.info-1" 78374 687 "Functions and Variables for Display"))
("exptisolate" . ("maxima.info-1" 205932 195 "Functions and Variables for Expressions"))
("exptsubst" . ("maxima.info-1" 206128 692 "Functions and Variables for Expressions"))
("exsec" . ("maxima.info-3" 234495 124 "Package functs"))
("extdiff" . ("maxima.info-1" 1017137 1481 "Functions and Variables for itensor"))
("extract_linear_equations" . ("maxima.info-1" 940067 387 "Functions and Variables for Affine"))
("extremal_subset" . ("maxima.info-2" 305640 773 "Functions and Variables for Sets"))
("ezgcd" . ("maxima.info-1" 580717 1250 "Functions and Variables for Polynomials"))
("f90" . ("maxima.info-2" 929905 2061 "Package f90"))
("f90_output_line_length_max" . ("maxima.info-2" 928288 1616 "Package f90"))
("facexpand" . ("maxima.info-1" 581968 210 "Functions and Variables for Polynomials"))
("facsum" . ("maxima.info-3" 223683 1900 "Package facexp"))
("facsum_combine" . ("maxima.info-3" 226281 686 "Package facexp"))
("factcomb" . ("maxima.info-1" 388194 913 "Combinatorial Functions"))
("factlim" . ("maxima.info-1" 392560 187 "Combinatorial Functions"))
("factor" . ("maxima.info-1" 582179 6329 "Functions and Variables for Polynomials"))
("factor_max_degree" . ("maxima.info-1" 588509 1504 "Functions and Variables for Polynomials"))
("factor_max_degree_print_warning" . ("maxima.info-1" 590014 331 "Functions and Variables for Polynomials"))
("factorfacsum" . ("maxima.info-3" 226968 326 "Package facexp"))
("factorflag" . ("maxima.info-1" 590346 170 "Functions and Variables for Polynomials"))
("factorial" . ("maxima.info-1" 389108 3451 "Combinatorial Functions"))
("factorial_expand" . ("maxima.info-1" 392748 235 "Combinatorial Functions"))
("factorout" . ("maxima.info-1" 590517 688 "Functions and Variables for Polynomials"))
("factors_only" . ("maxima.info-2" 131269 370 "Functions and Variables for Number Theory"))
("factorsum" . ("maxima.info-1" 591206 852 "Functions and Variables for Polynomials"))
("facts" . ("maxima.info-1" 458848 466 "Functions and Variables for Facts"))
("false" . ("maxima.info-1" 113476 144 "Functions and Variables for Constants"))
("fast_central_elements" . ("maxima.info-1" 938618 412 "Functions and Variables for Affine"))
("fast_linsolve" . ("maxima.info-1" 935809 663 "Functions and Variables for Affine"))
("fasttimes" . ("maxima.info-1" 592059 428 "Functions and Variables for Polynomials"))
("fb" . ("maxima.info-2" 59513 83 "Functions and Variables for ctensor"))
("feature" . ("maxima.info-1" 437129 374 "Functions and Variables for Properties"))
("featurep" . ("maxima.info-1" 437504 520 "Functions and Variables for Properties"))
("features" . ("maxima.info-1" 438025 1415 "Functions and Variables for Properties"))
("fernfale" . ("maxima.info-2" 945869 347 "Definitions for IFS fractals"))
("fft" . ("maxima.info-1" 848160 4406 "Functions and Variables for fast Fourier transform"))
("fib" . ("maxima.info-2" 131640 450 "Functions and Variables for Number Theory"))
("fibtophi" . ("maxima.info-2" 132091 1195 "Functions and Variables for Number Theory"))
("fifth" . ("maxima.info-1" 129167 122 "Functions and Variables for Lists"))
("file_name" . ("maxima.info-2" 742604 579 "Functions and Variables for draw"))
("file_name <1>" . ("maxima.info-2" 1001328 93 "Functions and Variables for graphs"))
("file_output_append" . ("maxima.info-1" 537021 612 "Functions and Variables for File Input and Output"))
("file_search" . ("maxima.info-1" 537996 1804 "Functions and Variables for File Input and Output"))
("file_search_demo" . ("maxima.info-1" 539842 1588 "Functions and Variables for File Input and Output"))
("file_search_lisp" . ("maxima.info-1" 539802 1628 "Functions and Variables for File Input and Output"))
("file_search_maxima" . ("maxima.info-1" 539801 1629 "Functions and Variables for File Input and Output"))
("file_search_tests" . ("maxima.info-1" 539918 1512 "Functions and Variables for File Input and Output"))
("file_search_usage" . ("maxima.info-1" 539880 1550 "Functions and Variables for File Input and Output"))
("file_type" . ("maxima.info-1" 541431 866 "Functions and Variables for File Input and Output"))
("file_type_lisp" . ("maxima.info-1" 542298 213 "Functions and Variables for File Input and Output"))
("file_type_maxima" . ("maxima.info-1" 542512 250 "Functions and Variables for File Input and Output"))
("filename_merge" . ("maxima.info-1" 537634 361 "Functions and Variables for File Input and Output"))
("fill_color" . ("maxima.info-2" 743184 206 "Functions and Variables for draw"))
("fill_density" . ("maxima.info-2" 743391 208 "Functions and Variables for draw"))
("fillarray" . ("maxima.info-1" 172423 2174 "Functions and Variables for Arrays"))
("filled_func" . ("maxima.info-2" 743600 1412 "Functions and Variables for draw"))
("find_root" . ("maxima.info-1" 855931 4039 "Functions for numerical solution of equations"))
("find_root <1>" . ("maxima.info-1" 855932 4038 "Functions for numerical solution of equations"))
("find_root_abs" . ("maxima.info-1" 856202 3768 "Functions for numerical solution of equations"))
("find_root_error" . ("maxima.info-1" 856137 3833 "Functions for numerical solution of equations"))
("find_root_rel" . ("maxima.info-1" 856239 3731 "Functions for numerical solution of equations"))
("findde" . ("maxima.info-2" 33760 2345 "Functions and Variables for ctensor"))
("first" . ("maxima.info-1" 129290 1575 "Functions and Variables for Lists"))
("firstn" . ("maxima.info-1" 130866 3250 "Functions and Variables for Lists"))
("fix" . ("maxima.info-1" 374619 60 "Functions for Numbers"))
("fixed_vertices" . ("maxima.info-2" 1001860 180 "Functions and Variables for graphs"))
("flatten" . ("maxima.info-2" 306414 2582 "Functions and Variables for Sets"))
("flength" . ("maxima.info-3" 300731 227 "Input and Output"))
("flipflag" . ("maxima.info-1" 960566 584 "Functions and Variables for itensor"))
("float" . ("maxima.info-1" 98274 263 "Functions and Variables for Numbers"))
("float2bf" . ("maxima.info-1" 98538 239 "Functions and Variables for Numbers"))
("floatnump" . ("maxima.info-1" 98778 116 "Functions and Variables for Numbers"))
("floor" . ("maxima.info-1" 372739 1879 "Functions for Numbers"))
("flower_snark" . ("maxima.info-2" 957029 248 "Functions and Variables for graphs"))
("flush" . ("maxima.info-1" 988042 159 "Functions and Variables for itensor"))
("flush1deriv" . ("maxima.info-1" 994025 149 "Functions and Variables for itensor"))
("flush_output" . ("maxima.info-3" 300959 158 "Input and Output"))
("flushd" . ("maxima.info-1" 988202 157 "Functions and Variables for itensor"))
("flushnd" . ("maxima.info-1" 988360 722 "Functions and Variables for itensor"))
("fmin_cobyla" . ("maxima.info-2" 507281 2218 "Functions and Variables for cobyla"))
("font" . ("maxima.info-2" 745013 3193 "Functions and Variables for draw"))
("font_size" . ("maxima.info-2" 748207 419 "Functions and Variables for draw"))
("for" . ("maxima.info-2" 421768 9034 "Functions and Variables for Program Flow"))
("forget" . ("maxima.info-1" 459315 350 "Functions and Variables for Facts"))
("fortindent" . ("maxima.info-1" 565972 309 "Functions and Variables for Fortran Output"))
("fortran" . ("maxima.info-1" 566282 2176 "Functions and Variables for Fortran Output"))
("fortspaces" . ("maxima.info-1" 568459 167 "Functions and Variables for Fortran Output"))
("fourcos" . ("maxima.info-2" 117005 127 "Functions and Variables for Fourier series"))
("fourexpand" . ("maxima.info-2" 116758 246 "Functions and Variables for Fourier series"))
("fourier" . ("maxima.info-2" 116298 141 "Functions and Variables for Fourier series"))
("fourier_elim" . ("maxima.info-3" 366383 3355 "Functions and Variables for to_poly_solve"))
("fourint" . ("maxima.info-2" 117389 151 "Functions and Variables for Fourier series"))
("fourintcos" . ("maxima.info-2" 117541 126 "Functions and Variables for Fourier series"))
("fourintsin" . ("maxima.info-2" 117668 126 "Functions and Variables for Fourier series"))
("foursimp" . ("maxima.info-2" 116440 153 "Functions and Variables for Fourier series"))
("foursin" . ("maxima.info-2" 117133 125 "Functions and Variables for Fourier series"))
("fourth" . ("maxima.info-1" 134117 123 "Functions and Variables for Lists"))
("fposition" . ("maxima.info-3" 301118 457 "Input and Output"))
("fpprec" . ("maxima.info-1" 98895 266 "Functions and Variables for Numbers"))
("fpprintprec" . ("maxima.info-1" 99162 936 "Functions and Variables for Numbers"))
("frame_bracket" . ("maxima.info-2" 25181 361 "Functions and Variables for ctensor"))
("freeof" . ("maxima.info-1" 206821 3823 "Functions and Variables for Expressions"))
("freshline" . ("maxima.info-3" 301576 401 "Input and Output"))
("fresnel_c" . ("maxima.info-1" 682512 393 "Error Function"))
("fresnel_s" . ("maxima.info-1" 682906 394 "Error Function"))
("from" . ("maxima.info-2" 421797 9005 "Functions and Variables for Program Flow"))
("from_adjacency_matrix" . ("maxima.info-2" 957278 106 "Functions and Variables for graphs"))
("frucht_graph" . ("maxima.info-2" 957385 61 "Functions and Variables for graphs"))
("full_listify" . ("maxima.info-2" 308997 529 "Functions and Variables for Sets"))
("fullmap" . ("maxima.info-2" 373977 660 "Functions and Variables for Function Definition"))
("fullmapl" . ("maxima.info-2" 374638 263 "Functions and Variables for Function Definition"))
("fullratsimp" . ("maxima.info-1" 592488 1632 "Functions and Variables for Polynomials"))
("fullratsubst" . ("maxima.info-1" 594121 2088 "Functions and Variables for Polynomials"))
("fullsetify" . ("maxima.info-2" 309527 588 "Functions and Variables for Sets"))
("funcsolve" . ("maxima.info-1" 806736 937 "Functions and Variables for Equations"))
("functions" . ("maxima.info-2" 374902 1820 "Functions and Variables for Function Definition"))
("fundamental_dimensions" . ("maxima.info-2" 920614 1296 "Functions and Variables for ezunits"))
("fundamental_units" . ("maxima.info-2" 925365 1351 "Functions and Variables for ezunits"))
("fundef" . ("maxima.info-2" 376723 950 "Functions and Variables for Function Definition"))
("funmake" . ("maxima.info-2" 377674 3167 "Functions and Variables for Function Definition"))
("funp" . ("maxima.info-2" 115334 341 "Functions and Variables for Fourier series"))
("fv" . ("maxima.info-2" 933256 354 "Functions and Variables for finance"))
("gamma" . ("maxima.info-1" 648483 3147 "Gamma and factorial Functions"))
("gamma_expand" . ("maxima.info-1" 654139 1666 "Gamma and factorial Functions"))
("gamma_incomplete" . ("maxima.info-1" 652247 665 "Gamma and factorial Functions"))
("gamma_incomplete_generalized" . ("maxima.info-1" 653462 676 "Gamma and factorial Functions"))
("gamma_incomplete_lower" . ("maxima.info-1" 651713 533 "Gamma and factorial Functions"))
("gamma_incomplete_regularized" . ("maxima.info-1" 652913 548 "Gamma and factorial Functions"))
("gammalim" . ("maxima.info-1" 655806 399 "Gamma and factorial Functions"))
("garbage_collect" . ("maxima.info-2" 419167 382 "Garbage Collection"))
("gauss_a" . ("maxima.info-2" 532859 543 "Functions and Variables for contrib_ode"))
("gauss_b" . ("maxima.info-2" 533403 63 "Functions and Variables for contrib_ode"))
("gaussprob" . ("maxima.info-3" 233771 168 "Package functs"))
("gcd" . ("maxima.info-1" 596210 2137 "Functions and Variables for Polynomials"))
("gcdex" . ("maxima.info-1" 598348 1763 "Functions and Variables for Polynomials"))
("gcdivide" . ("maxima.info-3" 231020 1678 "Package functs"))
("gcfac" . ("maxima.info-3" 240794 976 "Package scifac"))
("gcfactor" . ("maxima.info-1" 600112 279 "Functions and Variables for Polynomials"))
("gd" . ("maxima.info-3" 233940 139 "Package functs"))
("gdet" . ("maxima.info-2" 57260 141 "Functions and Variables for ctensor"))
("gen_laguerre" . ("maxima.info-3" 185572 167 "Functions and Variables for orthogonal polynomials"))
("generalized_lambert_w" . ("maxima.info-1" 695296 365 "Functions and Variables for Special Functions"))
("genfact" . ("maxima.info-1" 392984 230 "Combinatorial Functions"))
("genindex" . ("maxima.info-2" 236382 165 "Functions and Variables for Miscellaneous Options"))
("genmatrix" . ("maxima.info-1" 903992 2750 "Functions and Variables for Matrices and Linear Algebra"))
("gensumnum" . ("maxima.info-2" 236548 248 "Functions and Variables for Miscellaneous Options"))
("gensym" . ("maxima.info-2" 236797 966 "Functions and Variables for Miscellaneous Options"))
("geo_amortization" . ("maxima.info-2" 939186 1651 "Functions and Variables for finance"))
("geo_annuity_fv" . ("maxima.info-2" 935641 463 "Functions and Variables for finance"))
("geo_annuity_pv" . ("maxima.info-2" 935174 466 "Functions and Variables for finance"))
("geomap" . ("maxima.info-2" 849177 6187 "Functions and Variables for worldmap"))
("geometric" . ("maxima.info-3" 232912 204 "Package functs"))
("geometric_mean" . ("maxima.info-2" 573066 922 "Functions and Variables for descriptive statistics"))
("geomview_command" . ("maxima.info-1" 479998 461 "Functions and Variables for Plotting"))
("geosum" . ("maxima.info-3" 233509 261 "Package functs"))
("get" . ("maxima.info-1" 439441 1030 "Functions and Variables for Properties"))
("get_edge_weight" . ("maxima.info-2" 968233 728 "Functions and Variables for graphs"))
("get_index_properties" . ("maxima.info-1" 68270 168 "Functions and Variables for Display"))
("get_lu_factors" . ("maxima.info-3" 81494 288 "Functions and Variables for linearalgebra"))
("get_output_stream_string" . ("maxima.info-3" 301978 294 "Input and Output"))
("get_pixel" . ("maxima.info-2" 838889 159 "Functions and Variables for pictures"))
("get_plot_option" . ("maxima.info-1" 480460 408 "Functions and Variables for Plotting"))
("get_tex_environment" . ("maxima.info-1" 563260 1259 "Functions and Variables for TeX Output"))
("get_tex_environment_default" . ("maxima.info-1" 564520 1209 "Functions and Variables for TeX Output"))
("get_vertex_label" . ("maxima.info-2" 968962 305 "Functions and Variables for graphs"))
("getcurrentdirectory" . ("maxima.info-3" 162752 291 "Directory operations"))
("getenv" . ("maxima.info-3" 163601 249 "Environment operations"))
("gfactor" . ("maxima.info-1" 600392 338 "Functions and Variables for Polynomials"))
("gfactorsum" . ("maxima.info-1" 600731 114 "Functions and Variables for Polynomials"))
("ggf" . ("maxima.info-2" 951702 494 "Functions and Variables for ggf"))
("girth" . ("maxima.info-2" 970990 237 "Functions and Variables for graphs"))
("global_variances" . ("maxima.info-2" 582523 1801 "Functions and Variables for descriptive statistics"))
("globalsolve" . ("maxima.info-1" 807674 2007 "Functions and Variables for Equations"))
("gnuplot_close" . ("maxima.info-1" 529600 116 "Gnuplot_pipes Format Functions"))
("gnuplot_command" . ("maxima.info-1" 480869 449 "Functions and Variables for Plotting"))
("gnuplot_curve_styles" . ("maxima.info-1" 529135 108 "Gnuplot Options"))
("gnuplot_curve_titles" . ("maxima.info-1" 529006 128 "Gnuplot Options"))
("gnuplot_default_term_command" . ("maxima.info-1" 526418 292 "Gnuplot Options"))
("gnuplot_dumb_term_command" . ("maxima.info-1" 526711 314 "Gnuplot Options"))
("gnuplot_file_args" . ("maxima.info-1" 481319 455 "Functions and Variables for Plotting"))
("gnuplot_file_name" . ("maxima.info-2" 748627 757 "Functions and Variables for draw"))
("gnuplot_out_file" . ("maxima.info-1" 524608 1013 "Gnuplot Options"))
("gnuplot_pdf_term_command" . ("maxima.info-1" 527026 358 "Gnuplot Options"))
("gnuplot_pm3d" . ("maxima.info-1" 525622 167 "Gnuplot Options"))
("gnuplot_png_term_command" . ("maxima.info-1" 527385 320 "Gnuplot Options"))
("gnuplot_postamble" . ("maxima.info-1" 526085 332 "Gnuplot Options"))
("gnuplot_preamble" . ("maxima.info-1" 525790 294 "Gnuplot Options"))
("gnuplot_ps_term_command" . ("maxima.info-1" 527706 402 "Gnuplot Options"))
("gnuplot_replot" . ("maxima.info-1" 529857 260 "Gnuplot_pipes Format Functions"))
("gnuplot_reset" . ("maxima.info-1" 530118 189 "Gnuplot_pipes Format Functions"))
("gnuplot_restart" . ("maxima.info-1" 529717 139 "Gnuplot_pipes Format Functions"))
("gnuplot_start" . ("maxima.info-1" 529414 185 "Gnuplot_pipes Format Functions"))
("gnuplot_strings" . ("maxima.info-1" 528109 580 "Gnuplot Options"))
("gnuplot_svg_term_command" . ("maxima.info-1" 528690 315 "Gnuplot Options"))
("gnuplot_term" . ("maxima.info-1" 522322 2285 "Gnuplot Options"))
("gnuplot_view_args" . ("maxima.info-1" 481775 1340 "Functions and Variables for Plotting"))
("go" . ("maxima.info-2" 435761 515 "Functions and Variables for Program Flow"))
("gr2d" . ("maxima.info-2" 710569 1261 "Functions and Variables for draw"))
("gr3d" . ("maxima.info-2" 711831 796 "Functions and Variables for draw"))
("gradef" . ("maxima.info-1" 732110 1999 "Functions and Variables for Differentiation"))
("gradefs" . ("maxima.info-1" 734110 278 "Functions and Variables for Differentiation"))
("gramschmidt" . ("maxima.info-1" 906743 2501 "Functions and Variables for Matrices and Linear Algebra"))
("graph6_decode" . ("maxima.info-2" 993339 110 "Functions and Variables for graphs"))
("graph6_encode" . ("maxima.info-2" 993450 109 "Functions and Variables for graphs"))
("graph6_export" . ("maxima.info-2" 993560 133 "Functions and Variables for graphs"))
("graph6_import" . ("maxima.info-2" 993694 107 "Functions and Variables for graphs"))
("graph_center" . ("maxima.info-2" 969638 240 "Functions and Variables for graphs"))
("graph_charpoly" . ("maxima.info-2" 969268 369 "Functions and Variables for graphs"))
("graph_eigenvalues" . ("maxima.info-2" 969879 358 "Functions and Variables for graphs"))
("graph_flow" . ("maxima.info-2" 933969 384 "Functions and Variables for finance"))
("graph_order" . ("maxima.info-2" 970739 250 "Functions and Variables for graphs"))
("graph_periphery" . ("maxima.info-2" 970238 254 "Functions and Variables for graphs"))
("graph_product" . ("maxima.info-2" 957447 248 "Functions and Variables for graphs"))
("graph_size" . ("maxima.info-2" 970493 245 "Functions and Variables for graphs"))
("graph_union" . ("maxima.info-2" 957696 93 "Functions and Variables for graphs"))
("great_rhombicosidodecahedron_graph" . ("maxima.info-2" 957858 105 "Functions and Variables for graphs"))
("great_rhombicuboctahedron_graph" . ("maxima.info-2" 957964 99 "Functions and Variables for graphs"))
("grid" . ("maxima.info-1" 505577 294 "Plotting Options"))
("grid <1>" . ("maxima.info-2" 749385 717 "Functions and Variables for draw"))
("grid2d" . ("maxima.info-1" 505872 320 "Plotting Options"))
("grid_graph" . ("maxima.info-2" 957790 67 "Functions and Variables for graphs"))
("grind" . ("maxima.info-1" 83183 555 "Functions and Variables for Display"))
("grind <1>" . ("maxima.info-1" 79062 4120 "Functions and Variables for Display"))
("grobner_basis" . ("maxima.info-1" 936473 587 "Functions and Variables for Affine"))
("grotzch_graph" . ("maxima.info-2" 958064 63 "Functions and Variables for graphs"))
("halfangles" . ("maxima.info-1" 415020 1961 "Functions and Variables for Trigonometric"))
("hamilton_cycle" . ("maxima.info-2" 971228 381 "Functions and Variables for graphs"))
("hamilton_path" . ("maxima.info-2" 971610 392 "Functions and Variables for graphs"))
("hankel" . ("maxima.info-3" 81783 288 "Functions and Variables for linearalgebra"))
("hankel_1" . ("maxima.info-1" 642190 1651 "Bessel Functions"))
("hankel_2" . ("maxima.info-1" 643842 655 "Bessel Functions"))
("harmonic" . ("maxima.info-3" 233117 235 "Package functs"))
("harmonic_mean" . ("maxima.info-2" 572135 930 "Functions and Variables for descriptive statistics"))
("hav" . ("maxima.info-3" 234620 124 "Package functs"))
("head_angle" . ("maxima.info-2" 750103 1216 "Functions and Variables for draw"))
("head_angle <1>" . ("maxima.info-2" 1000788 128 "Functions and Variables for graphs"))
("head_both" . ("maxima.info-2" 751320 602 "Functions and Variables for draw"))
("head_length" . ("maxima.info-2" 751923 690 "Functions and Variables for draw"))
("head_length <1>" . ("maxima.info-2" 1000917 131 "Functions and Variables for graphs"))
("head_type" . ("maxima.info-2" 752614 817 "Functions and Variables for draw"))
("heawood_graph" . ("maxima.info-2" 958128 63 "Functions and Variables for graphs"))
("height" . ("maxima.info-2" 876878 173 "Visualization with VTK"))
("height <1>" . ("maxima.info-2" 882516 160 "Visualization with VTK"))
("hermite" . ("maxima.info-3" 185740 144 "Functions and Variables for orthogonal polynomials"))
("hessian" . ("maxima.info-3" 82072 1120 "Functions and Variables for linearalgebra"))
("hgfred" . ("maxima.info-1" 692964 2186 "Functions and Variables for Special Functions"))
("hilbert_matrix" . ("maxima.info-3" 83193 137 "Functions and Variables for linearalgebra"))
("hilbertmap" . ("maxima.info-2" 949770 246 "Definitions for Peano maps"))
("hipow" . ("maxima.info-1" 600846 891 "Functions and Variables for Polynomials"))
("histogram" . ("maxima.info-2" 603521 3741 "Functions and Variables for statistical graphs"))
("histogram_description" . ("maxima.info-2" 607263 813 "Functions and Variables for statistical graphs"))
("hodge" . ("maxima.info-1" 1018619 1498 "Functions and Variables for itensor"))
("horner" . ("maxima.info-1" 854799 1131 "Functions for numerical solution of equations"))
("hypergeometric" . ("maxima.info-1" 684947 1583 "Hypergeometric Functions"))
("hypergeometric_representation" . ("maxima.info-1" 683463 176 "Error Function"))
("hypergeometric_simp" . ("maxima.info-1" 691597 1366 "Functions and Variables for Special Functions"))
("i" . ("maxima.info-1" 113406 69 "Functions and Variables for Constants"))
("ibase" . ("maxima.info-1" 83739 1993 "Functions and Variables for Display"))
("ic1" . ("maxima.info-1" 838101 437 "Functions and Variables for Differential Equations"))
("ic2" . ("maxima.info-1" 838539 654 "Functions and Variables for Differential Equations"))
("ic_convert" . ("maxima.info-1" 1022401 2168 "Functions and Variables for itensor"))
("icc1" . ("maxima.info-1" 1004581 599 "Functions and Variables for itensor"))
("icc2" . ("maxima.info-1" 1005181 638 "Functions and Variables for itensor"))
("ichr1" . ("maxima.info-1" 994803 355 "Functions and Variables for itensor"))
("ichr2" . ("maxima.info-1" 995159 287 "Functions and Variables for itensor"))
("icosahedron_graph" . ("maxima.info-2" 958192 71 "Functions and Variables for graphs"))
("icosidodecahedron_graph" . ("maxima.info-2" 958264 83 "Functions and Variables for graphs"))
("icounter" . ("maxima.info-1" 970402 236 "Functions and Variables for itensor"))
("icurvature" . ("maxima.info-1" 995447 574 "Functions and Variables for itensor"))
("ident" . ("maxima.info-1" 909245 71 "Functions and Variables for Matrices and Linear Algebra"))
("identfor" . ("maxima.info-3" 83331 575 "Functions and Variables for linearalgebra"))
("identity" . ("maxima.info-2" 310116 275 "Functions and Variables for Sets"))
("idiff" . ("maxima.info-1" 983540 712 "Functions and Variables for itensor"))
("idim" . ("maxima.info-1" 994629 173 "Functions and Variables for itensor"))
("idummy" . ("maxima.info-1" 969968 306 "Functions and Variables for itensor"))
("idummyx" . ("maxima.info-1" 970275 126 "Functions and Variables for itensor"))
("ieqn" . ("maxima.info-1" 809682 1379 "Functions and Variables for Equations"))
("ieqnprint" . ("maxima.info-1" 811062 675 "Functions and Variables for Equations"))
("if" . ("maxima.info-2" 436277 2576 "Functions and Variables for Program Flow"))
("ifactors" . ("maxima.info-2" 133287 1209 "Functions and Variables for Number Theory"))
("ifb" . ("maxima.info-1" 1003580 1000 "Functions and Variables for itensor"))
("ifc1" . ("maxima.info-1" 1005820 438 "Functions and Variables for itensor"))
("ifc2" . ("maxima.info-1" 1006259 401 "Functions and Variables for itensor"))
("ifg" . ("maxima.info-1" 1006986 109 "Functions and Variables for itensor"))
("ifgi" . ("maxima.info-1" 1007096 110 "Functions and Variables for itensor"))
("ifr" . ("maxima.info-1" 1006661 129 "Functions and Variables for itensor"))
("iframe_bracket_form" . ("maxima.info-1" 1007207 128 "Functions and Variables for itensor"))
("iframes" . ("maxima.info-1" 1003380 199 "Functions and Variables for itensor"))
("ifri" . ("maxima.info-1" 1006791 194 "Functions and Variables for itensor"))
("ifs" . ("maxima.info-2" 869577 1415 "Graphical analysis of discrete dynamical systems"))
("igcdex" . ("maxima.info-2" 134497 679 "Functions and Variables for Number Theory"))
("igeodesic_coords" . ("maxima.info-1" 998158 1983 "Functions and Variables for itensor"))
("igeowedge_flag" . ("maxima.info-1" 1020118 394 "Functions and Variables for itensor"))
("ikt1" . ("maxima.info-1" 1008905 436 "Functions and Variables for itensor"))
("ikt2" . ("maxima.info-1" 1009342 271 "Functions and Variables for itensor"))
("ilt" . ("maxima.info-1" 745888 2156 "Functions and Variables for Integration"))
("image" . ("maxima.info-2" 812997 3781 "Functions and Variables for draw"))
("imaginary" . ("maxima.info-1" 445659 217 "Functions and Variables for Properties"))
("imagpart" . ("maxima.info-1" 383991 579 "Functions for Complex Numbers"))
("imetric" . ("maxima.info-1" 994239 389 "Functions and Variables for itensor"))
("imetric <1>" . ("maxima.info-1" 994240 388 "Functions and Variables for itensor"))
("implicit" . ("maxima.info-2" 816779 1914 "Functions and Variables for draw"))
("implicit_derivative" . ("maxima.info-3" 16455 456 "Functions and Variables for impdiff"))
("implicit_plot" . ("maxima.info-1" 483116 989 "Functions and Variables for Plotting"))
("in" . ("maxima.info-2" 421904 8898 "Functions and Variables for Program Flow"))
("in_neighbors" . ("maxima.info-2" 972507 375 "Functions and Variables for graphs"))
("inchar" . ("maxima.info-1" 46566 868 "Functions and Variables for Command Line"))
("increasing" . ("maxima.info-1" 435877 601 "Functions and Variables for Properties"))
("ind" . ("maxima.info-1" 113704 196 "Functions and Variables for Constants"))
("indexed_tensor" . ("maxima.info-1" 962920 234 "Functions and Variables for itensor"))
("indices" . ("maxima.info-1" 956093 1004 "Functions and Variables for itensor"))
("induced_subgraph" . ("maxima.info-2" 958348 498 "Functions and Variables for graphs"))
("inf" . ("maxima.info-1" 113901 65 "Functions and Variables for Constants"))
("inference_result" . ("maxima.info-3" 252738 1827 "Functions and Variables for inference_result"))
("inferencep" . ("maxima.info-3" 254566 138 "Functions and Variables for inference_result"))
("infeval" . ("maxima.info-1" 321660 364 "Functions and Variables for Evaluation"))
("infinity" . ("maxima.info-1" 113967 69 "Functions and Variables for Constants"))
("infix" . ("maxima.info-1" 285654 4269 "User defined operators"))
("inflag" . ("maxima.info-1" 210645 690 "Functions and Variables for Expressions"))
("info_display" . ("maxima.info-2" 472905 320 "Functions and Variables for alt-display"))
("infolists" . ("maxima.info-1" 47435 1975 "Functions and Variables for Command Line"))
("init_atensor" . ("maxima.info-2" 68644 2503 "Functions and Variables for atensor"))
("init_ctensor" . ("maxima.info-2" 12268 298 "Functions and Variables for ctensor"))
("inm" . ("maxima.info-1" 1007666 335 "Functions and Variables for itensor"))
("inmc1" . ("maxima.info-1" 1008002 365 "Functions and Variables for itensor"))
("inmc2" . ("maxima.info-1" 1008368 536 "Functions and Variables for itensor"))
("innerproduct" . ("maxima.info-1" 909317 462 "Functions and Variables for Matrices and Linear Algebra"))
("inpart" . ("maxima.info-1" 211336 1263 "Functions and Variables for Expressions"))
("inprod" . ("maxima.info-1" 909318 461 "Functions and Variables for Matrices and Linear Algebra"))
("inrt" . ("maxima.info-2" 135177 289 "Functions and Variables for Number Theory"))
("intanalysis" . ("maxima.info-1" 748045 1476 "Functions and Variables for Integration"))
("integer" . ("maxima.info-1" 440472 470 "Functions and Variables for Properties"))
("integer_partitions" . ("maxima.info-2" 310392 1878 "Functions and Variables for Sets"))
("integerp" . ("maxima.info-1" 100099 929 "Functions and Variables for Numbers"))
("integervalued" . ("maxima.info-1" 440943 501 "Functions and Variables for Properties"))
("integrate" . ("maxima.info-1" 749522 8464 "Functions and Variables for Integration"))
("integrate_use_rootsof" . ("maxima.info-1" 760201 2349 "Functions and Variables for Integration"))
("integration_constant" . ("maxima.info-1" 757987 863 "Functions and Variables for Integration"))
("integration_constant_counter" . ("maxima.info-1" 758851 1349 "Functions and Variables for Integration"))
("interpolate_color" . ("maxima.info-2" 753432 2785 "Functions and Variables for draw"))
("intersect" . ("maxima.info-2" 312271 104 "Functions and Variables for Sets"))
("intersection" . ("maxima.info-2" 312376 927 "Functions and Variables for Sets"))
("intervalp" . ("maxima.info-3" 185885 112 "Functions and Variables for orthogonal polynomials"))
("intfaclim" . ("maxima.info-1" 601738 659 "Functions and Variables for Polynomials"))
("intopois" . ("maxima.info-2" 118044 72 "Functions and Variables for Poisson series"))
("intosum" . ("maxima.info-2" 75831 506 "Functions and Variables for Sums and Products"))
("inv_mod" . ("maxima.info-2" 135467 402 "Functions and Variables for Number Theory"))
("invariant1" . ("maxima.info-2" 39477 205 "Functions and Variables for ctensor"))
("invariant2" . ("maxima.info-2" 39683 257 "Functions and Variables for ctensor"))
("inverse_fft" . ("maxima.info-1" 845576 2583 "Functions and Variables for fast Fourier transform"))
("inverse_jacobi_cd" . ("maxima.info-1" 702263 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_cn" . ("maxima.info-1" 701535 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_cs" . ("maxima.info-1" 702159 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_dc" . ("maxima.info-1" 702575 105 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_dn" . ("maxima.info-1" 701639 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_ds" . ("maxima.info-1" 702471 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_nc" . ("maxima.info-1" 702055 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_nd" . ("maxima.info-1" 702367 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_ns" . ("maxima.info-1" 701743 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_sc" . ("maxima.info-1" 701847 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_sd" . ("maxima.info-1" 701951 103 "Functions and Variables for Elliptic Functions"))
("inverse_jacobi_sn" . ("maxima.info-1" 701431 103 "Functions and Variables for Elliptic Functions"))
("inverse_real_fft" . ("maxima.info-1" 853313 360 "Functions and Variables for fast Fourier transform"))
("invert" . ("maxima.info-1" 910008 1101 "Functions and Variables for Matrices and Linear Algebra"))
("invert_by_adjoint" . ("maxima.info-1" 909780 227 "Functions and Variables for Matrices and Linear Algebra"))
("invert_by_lu" . ("maxima.info-3" 83907 168 "Functions and Variables for linearalgebra"))
("ip_grid" . ("maxima.info-2" 756218 190 "Functions and Variables for draw"))
("ip_grid_in" . ("maxima.info-2" 756409 200 "Functions and Variables for draw"))
("irr" . ("maxima.info-2" 942553 401 "Functions and Variables for finance"))
("irrational" . ("maxima.info-1" 445450 164 "Functions and Variables for Properties"))
("is" . ("maxima.info-1" 459666 1820 "Functions and Variables for Facts"))
("is_biconnected" . ("maxima.info-2" 972883 336 "Functions and Variables for graphs"))
("is_bipartite" . ("maxima.info-2" 973220 351 "Functions and Variables for graphs"))
("is_connected" . ("maxima.info-2" 973572 281 "Functions and Variables for graphs"))
("is_digraph" . ("maxima.info-2" 973854 330 "Functions and Variables for graphs"))
("is_edge_in_graph" . ("maxima.info-2" 974185 604 "Functions and Variables for graphs"))
("is_graph" . ("maxima.info-2" 974790 315 "Functions and Variables for graphs"))
("is_graph_or_digraph" . ("maxima.info-2" 975106 372 "Functions and Variables for graphs"))
("is_isomorphic" . ("maxima.info-2" 975479 390 "Functions and Variables for graphs"))
("is_planar" . ("maxima.info-2" 975870 525 "Functions and Variables for graphs"))
("is_sconnected" . ("maxima.info-2" 976396 368 "Functions and Variables for graphs"))
("is_tree" . ("maxima.info-2" 977157 340 "Functions and Variables for graphs"))
("is_vertex_in_graph" . ("maxima.info-2" 976765 391 "Functions and Variables for graphs"))
("ishow" . ("maxima.info-1" 955750 342 "Functions and Variables for itensor"))
("isolate" . ("maxima.info-1" 212600 858 "Functions and Variables for Expressions"))
("isolate_wrt_times" . ("maxima.info-1" 213459 773 "Functions and Variables for Expressions"))
("isomorphism" . ("maxima.info-2" 972003 503 "Functions and Variables for graphs"))
("isqrt" . ("maxima.info-2" 135870 122 "Functions and Variables for Number Theory"))
("isreal_p" . ("maxima.info-3" 369739 1325 "Functions and Variables for to_poly_solve"))
("items_inference" . ("maxima.info-3" 254705 712 "Functions and Variables for inference_result"))
("iterations" . ("maxima.info-1" 506193 138 "Plotting Options"))
("itr" . ("maxima.info-1" 1009614 2757 "Functions and Variables for itensor"))
("jacobi" . ("maxima.info-2" 135993 256 "Functions and Variables for Number Theory"))
("jacobi_cd" . ("maxima.info-1" 701041 98 "Functions and Variables for Elliptic Functions"))
("jacobi_cn" . ("maxima.info-1" 700396 80 "Functions and Variables for Elliptic Functions"))
("jacobi_cs" . ("maxima.info-1" 700942 98 "Functions and Variables for Elliptic Functions"))
("jacobi_dc" . ("maxima.info-1" 701332 98 "Functions and Variables for Elliptic Functions"))
("jacobi_dn" . ("maxima.info-1" 700477 80 "Functions and Variables for Elliptic Functions"))
("jacobi_ds" . ("maxima.info-1" 701233 98 "Functions and Variables for Elliptic Functions"))
("jacobi_nc" . ("maxima.info-1" 700849 92 "Functions and Variables for Elliptic Functions"))
("jacobi_nd" . ("maxima.info-1" 701140 92 "Functions and Variables for Elliptic Functions"))
("jacobi_ns" . ("maxima.info-1" 700558 92 "Functions and Variables for Elliptic Functions"))
("jacobi_p" . ("maxima.info-3" 185998 338 "Functions and Variables for orthogonal polynomials"))
("jacobi_sc" . ("maxima.info-1" 700651 98 "Functions and Variables for Elliptic Functions"))
("jacobi_sd" . ("maxima.info-1" 700750 98 "Functions and Variables for Elliptic Functions"))
("jacobi_sn" . ("maxima.info-1" 700315 80 "Functions and Variables for Elliptic Functions"))
("jacobian" . ("maxima.info-3" 84076 949 "Functions and Variables for linearalgebra"))
("join" . ("maxima.info-1" 134241 752 "Functions and Variables for Lists"))
("jordan" . ("maxima.info-2" 617907 2425 "Functions and Variables for diag"))
("julia" . ("maxima.info-1" 484106 1739 "Functions and Variables for Plotting"))
("julia_parameter" . ("maxima.info-2" 947447 273 "Definitions for complex fractals"))
("julia_set" . ("maxima.info-2" 946935 511 "Definitions for complex fractals"))
("julia_sin" . ("maxima.info-2" 947721 790 "Definitions for complex fractals"))
("kdels" . ("maxima.info-1" 971437 861 "Functions and Variables for itensor"))
("kdelta" . ("maxima.info-1" 970639 797 "Functions and Variables for itensor"))
("keepfloat" . ("maxima.info-1" 602398 903 "Functions and Variables for Polynomials"))
("key" . ("maxima.info-2" 756610 723 "Functions and Variables for draw"))
("key_pos" . ("maxima.info-2" 757334 1028 "Functions and Variables for draw"))
("kill" . ("maxima.info-1" 49411 2794 "Functions and Variables for Command Line"))
("killcontext" . ("maxima.info-1" 461487 734 "Functions and Variables for Facts"))
("kinvariant" . ("maxima.info-2" 59597 85 "Functions and Variables for ctensor"))
("km" . ("maxima.info-2" 577501 1469 "Functions and Variables for descriptive statistics"))
("kostka" . ("maxima.info-2" 198083 245 "Functions and Variables for Symmetries"))
("kron_delta" . ("maxima.info-2" 313304 903 "Functions and Variables for Sets"))
("kronecker_product" . ("maxima.info-3" 85026 107 "Functions and Variables for linearalgebra"))
("kt" . ("maxima.info-2" 60496 82 "Functions and Variables for ctensor"))
("kummer_m" . ("maxima.info-2" 533715 409 "Functions and Variables for contrib_ode"))
("kummer_u" . ("maxima.info-2" 534125 182 "Functions and Variables for contrib_ode"))
("kurtosis" . ("maxima.info-2" 573989 876 "Functions and Variables for descriptive statistics"))
("kurtosis_bernoulli" . ("maxima.info-2" 695108 443 "Functions and Variables for discrete distributions"))
("kurtosis_beta" . ("maxima.info-2" 664501 192 "Functions and Variables for continuous distributions"))
("kurtosis_binomial" . ("maxima.info-2" 689705 235 "Functions and Variables for discrete distributions"))
("kurtosis_chi2" . ("maxima.info-2" 648243 399 "Functions and Variables for continuous distributions"))
("kurtosis_continuous_uniform" . ("maxima.info-2" 666806 218 "Functions and Variables for continuous distributions"))
("kurtosis_discrete_uniform" . ("maxima.info-2" 701209 234 "Functions and Variables for discrete distributions"))
("kurtosis_exp" . ("maxima.info-2" 656833 319 "Functions and Variables for continuous distributions"))
("kurtosis_f" . ("maxima.info-2" 653104 191 "Functions and Variables for continuous distributions"))
("kurtosis_gamma" . ("maxima.info-2" 661941 194 "Functions and Variables for continuous distributions"))
("kurtosis_general_finite_discrete" . ("maxima.info-2" 686874 229 "Functions and Variables for discrete distributions"))
("kurtosis_geometric" . ("maxima.info-2" 698545 363 "Functions and Variables for discrete distributions"))
("kurtosis_gumbel" . ("maxima.info-2" 683213 194 "Functions and Variables for continuous distributions"))
("kurtosis_hypergeometric" . ("maxima.info-2" 704257 275 "Functions and Variables for discrete distributions"))
("kurtosis_laplace" . ("maxima.info-2" 679626 196 "Functions and Variables for continuous distributions"))
("kurtosis_logistic" . ("maxima.info-2" 668964 199 "Functions and Variables for continuous distributions"))
("kurtosis_lognormal" . ("maxima.info-2" 659612 200 "Functions and Variables for continuous distributions"))
("kurtosis_negative_binomial" . ("maxima.info-2" 707164 249 "Functions and Variables for discrete distributions"))
("kurtosis_noncentral_chi2" . ("maxima.info-2" 650770 204 "Functions and Variables for continuous distributions"))
("kurtosis_noncentral_student_t" . ("maxima.info-2" 644192 285 "Functions and Variables for continuous distributions"))
("kurtosis_normal" . ("maxima.info-2" 636988 222 "Functions and Variables for continuous distributions"))
("kurtosis_pareto" . ("maxima.info-2" 671019 198 "Functions and Variables for continuous distributions"))
("kurtosis_poisson" . ("maxima.info-2" 692051 194 "Functions and Variables for discrete distributions"))
("kurtosis_rayleigh" . ("maxima.info-2" 677148 643 "Functions and Variables for continuous distributions"))
("kurtosis_student_t" . ("maxima.info-2" 639754 194 "Functions and Variables for continuous distributions"))
("kurtosis_weibull" . ("maxima.info-2" 673071 198 "Functions and Variables for continuous distributions"))
("label" . ("maxima.info-1" 506332 166 "Plotting Options"))
("label <1>" . ("maxima.info-2" 818694 1248 "Functions and Variables for draw"))
("label_alignment" . ("maxima.info-2" 758363 901 "Functions and Variables for draw"))
("label_alignment <1>" . ("maxima.info-2" 997968 172 "Functions and Variables for graphs"))
("label_orientation" . ("maxima.info-2" 759265 918 "Functions and Variables for draw"))
("labels" . ("maxima.info-1" 53347 216 "Functions and Variables for Command Line"))
("labels <1>" . ("maxima.info-1" 52206 1140 "Functions and Variables for Command Line"))
("lagrange" . ("maxima.info-3" 17719 4144 "Functions and Variables for interpol"))
("laguerre" . ("maxima.info-3" 186337 164 "Functions and Variables for orthogonal polynomials"))
("lambda" . ("maxima.info-2" 380842 5935 "Functions and Variables for Function Definition"))
("lambert_w" . ("maxima.info-1" 695151 144 "Functions and Variables for Special Functions"))
("laplace" . ("maxima.info-1" 734389 4446 "Functions and Variables for Differentiation"))
("laplacian_matrix" . ("maxima.info-2" 977498 702 "Functions and Variables for graphs"))
("lassociative" . ("maxima.info-1" 347946 204 "Functions and Variables for Simplification"))
("last" . ("maxima.info-1" 134994 123 "Functions and Variables for Lists"))
("lastn" . ("maxima.info-1" 135118 3259 "Functions and Variables for Lists"))
("lbfgs" . ("maxima.info-3" 53606 14604 "Functions and Variables for lbfgs"))
("lbfgs_ncorrections" . ("maxima.info-3" 68485 201 "Functions and Variables for lbfgs"))
("lbfgs_nfeval_max" . ("maxima.info-3" 68211 273 "Functions and Variables for lbfgs"))
("lc2kdt" . ("maxima.info-1" 972555 3445 "Functions and Variables for itensor"))
("lc_l" . ("maxima.info-1" 976001 1072 "Functions and Variables for itensor"))
("lc_u" . ("maxima.info-1" 977074 289 "Functions and Variables for itensor"))
("lcm" . ("maxima.info-2" 136250 215 "Functions and Variables for Number Theory"))
("ldefint" . ("maxima.info-1" 762551 716 "Functions and Variables for Integration"))
("ldisp" . ("maxima.info-1" 85733 1100 "Functions and Variables for Display"))
("ldisplay" . ("maxima.info-1" 86834 1318 "Functions and Variables for Display"))
("leftjust" . ("maxima.info-1" 88153 503 "Functions and Variables for Display"))
("legend" . ("maxima.info-1" 506499 485 "Plotting Options"))
("legendre_p" . ("maxima.info-3" 186502 184 "Functions and Variables for orthogonal polynomials"))
("legendre_q" . ("maxima.info-3" 186687 164 "Functions and Variables for orthogonal polynomials"))
("leinstein" . ("maxima.info-2" 16090 403 "Functions and Variables for ctensor"))
("length" . ("maxima.info-1" 138378 835 "Functions and Variables for Lists"))
("let" . ("maxima.info-2" 253109 4262 "Functions and Variables for Rules and Patterns"))
("let_rule_packages" . ("maxima.info-2" 260937 220 "Functions and Variables for Rules and Patterns"))
("letrat" . ("maxima.info-2" 257372 827 "Functions and Variables for Rules and Patterns"))
("letrules" . ("maxima.info-2" 258200 537 "Functions and Variables for Rules and Patterns"))
("letsimp" . ("maxima.info-2" 258738 2198 "Functions and Variables for Rules and Patterns"))
("levi_civita" . ("maxima.info-1" 972299 255 "Functions and Variables for itensor"))
("lfg" . ("maxima.info-2" 58279 189 "Functions and Variables for ctensor"))
("lfreeof" . ("maxima.info-1" 215979 461 "Functions and Variables for Expressions"))
("lg" . ("maxima.info-2" 59215 151 "Functions and Variables for ctensor"))
("lgtreillis" . ("maxima.info-2" 198329 243 "Functions and Variables for Symmetries"))
("lhospitallim" . ("maxima.info-1" 704821 233 "Functions and Variables for Limits"))
("lhs" . ("maxima.info-1" 811738 1631 "Functions and Variables for Equations"))
("li" . ("maxima.info-1" 398989 2550 "Root Exponential and Logarithmic Functions"))
("liediff" . ("maxima.info-1" 984253 798 "Functions and Variables for itensor"))
("limit" . ("maxima.info-1" 705055 2044 "Functions and Variables for Limits"))
("limsubst" . ("maxima.info-1" 707100 266 "Functions and Variables for Limits"))
("linalg_rank" . ("maxima.info-3" 102450 492 "Functions and Variables for linearalgebra"))
("line_graph" . ("maxima.info-2" 958847 77 "Functions and Variables for graphs"))
("line_type" . ("maxima.info-2" 760184 910 "Functions and Variables for draw"))
("line_width" . ("maxima.info-2" 761095 701 "Functions and Variables for draw"))
("linear" . ("maxima.info-1" 348151 1659 "Functions and Variables for Simplification"))
("linear <1>" . ("maxima.info-3" 230279 740 "Package functs"))
("linear_program" . ("maxima.info-3" 215211 1060 "Functions and Variables for simplex"))
("linear_regression" . ("maxima.info-3" 288352 3683 "Functions and Variables for stats"))
("linear_solver" . ("maxima.info-3" 437783 184 "Functions and Variables for zeilberger"))
("linearinterpol" . ("maxima.info-3" 23137 2638 "Functions and Variables for interpol"))
("linechar" . ("maxima.info-1" 53564 737 "Functions and Variables for Command Line"))
("linel" . ("maxima.info-1" 88657 428 "Functions and Variables for Display"))
("linenum" . ("maxima.info-1" 54302 109 "Functions and Variables for Command Line"))
("linewidth" . ("maxima.info-2" 882677 178 "Visualization with VTK"))
("linsolve" . ("maxima.info-1" 813370 3131 "Functions and Variables for Equations"))
("linsolve_params" . ("maxima.info-1" 816668 366 "Functions and Variables for Equations"))
("linsolvewarn" . ("maxima.info-1" 816502 165 "Functions and Variables for Equations"))
("lispdisp" . ("maxima.info-1" 89086 516 "Functions and Variables for Display"))
("list_correlations" . ("maxima.info-2" 586501 3188 "Functions and Variables for descriptive statistics"))
("list_matrix_entries" . ("maxima.info-1" 911110 227 "Functions and Variables for Matrices and Linear Algebra"))
("list_nc_monomials" . ("maxima.info-1" 940455 293 "Functions and Variables for Affine"))
("listarith" . ("maxima.info-1" 139214 346 "Functions and Variables for Lists"))
("listarray" . ("maxima.info-1" 174598 3708 "Functions and Variables for Arrays"))
("listconstvars" . ("maxima.info-1" 214233 480 "Functions and Variables for Expressions"))
("listdummyvars" . ("maxima.info-1" 214714 702 "Functions and Variables for Expressions"))
("listify" . ("maxima.info-2" 314208 412 "Functions and Variables for Sets"))
("listoftens" . ("maxima.info-1" 955189 560 "Functions and Variables for itensor"))
("listofvars" . ("maxima.info-1" 215417 561 "Functions and Variables for Expressions"))
("listp" . ("maxima.info-1" 139561 84 "Functions and Variables for Lists"))
("listp <1>" . ("maxima.info-3" 85134 338 "Functions and Variables for linearalgebra"))
("lmax" . ("maxima.info-1" 374680 183 "Functions for Numbers"))
("lmin" . ("maxima.info-1" 374864 183 "Functions for Numbers"))
("lmxchar" . ("maxima.info-1" 911338 506 "Functions and Variables for Matrices and Linear Algebra"))
("load" . ("maxima.info-1" 542763 1587 "Functions and Variables for File Input and Output"))
("load_pathname" . ("maxima.info-1" 544351 848 "Functions and Variables for File Input and Output"))
("loadfile" . ("maxima.info-1" 545200 412 "Functions and Variables for File Input and Output"))
("loadprint" . ("maxima.info-1" 545613 511 "Functions and Variables for File Input and Output"))
("local" . ("maxima.info-2" 386778 1329 "Functions and Variables for Function Definition"))
("locate_matrix_entry" . ("maxima.info-3" 85473 935 "Functions and Variables for linearalgebra"))
("log" . ("maxima.info-1" 401540 1419 "Root Exponential and Logarithmic Functions"))
("log_gamma" . ("maxima.info-1" 651631 81 "Gamma and factorial Functions"))
("logabs" . ("maxima.info-1" 402960 443 "Root Exponential and Logarithmic Functions"))
("logarc" . ("maxima.info-1" 403668 224 "Root Exponential and Logarithmic Functions"))
("logarc <1>" . ("maxima.info-1" 403404 263 "Root Exponential and Logarithmic Functions"))
("logcb" . ("maxima.info-2" 761797 703 "Functions and Variables for draw"))
("logconcoeffp" . ("maxima.info-1" 403893 416 "Root Exponential and Logarithmic Functions"))
("logcontract" . ("maxima.info-1" 404310 992 "Root Exponential and Logarithmic Functions"))
("logexpand" . ("maxima.info-1" 405303 3099 "Root Exponential and Logarithmic Functions"))
("lognegint" . ("maxima.info-1" 408403 157 "Root Exponential and Logarithmic Functions"))
("logsimp" . ("maxima.info-1" 408561 148 "Root Exponential and Logarithmic Functions"))
("logx" . ("maxima.info-1" 506985 138 "Plotting Options"))
("logx <1>" . ("maxima.info-2" 762501 548 "Functions and Variables for draw"))
("logx_secondary" . ("maxima.info-2" 763050 866 "Functions and Variables for draw"))
("logy" . ("maxima.info-1" 507124 136 "Plotting Options"))
("logy <1>" . ("maxima.info-2" 763917 425 "Functions and Variables for draw"))
("logy_secondary" . ("maxima.info-2" 764343 832 "Functions and Variables for draw"))
("logz" . ("maxima.info-2" 765176 402 "Functions and Variables for draw"))
("lopow" . ("maxima.info-1" 603302 219 "Functions and Variables for Polynomials"))
("lorentz_gauge" . ("maxima.info-1" 997958 199 "Functions and Variables for itensor"))
("lowercasep" . ("maxima.info-3" 321315 138 "Characters"))
("lpart" . ("maxima.info-1" 216441 213 "Functions and Variables for Expressions"))
("lratsubst" . ("maxima.info-1" 603522 1010 "Functions and Variables for Polynomials"))
("lreduce" . ("maxima.info-1" 139646 1350 "Functions and Variables for Lists"))
("lriem" . ("maxima.info-2" 58893 81 "Functions and Variables for ctensor"))
("lriemann" . ("maxima.info-2" 17745 470 "Functions and Variables for ctensor"))
("lsquares_estimates" . ("maxima.info-3" 105643 6577 "Functions and Variables for lsquares"))
("lsquares_estimates_approximate" . ("maxima.info-3" 114506 2973 "Functions and Variables for lsquares"))
("lsquares_estimates_exact" . ("maxima.info-3" 112221 2284 "Functions and Variables for lsquares"))
("lsquares_mse" . ("maxima.info-3" 117480 4327 "Functions and Variables for lsquares"))
("lsquares_residual_mse" . ("maxima.info-3" 123944 2070 "Functions and Variables for lsquares"))
("lsquares_residuals" . ("maxima.info-3" 121808 2135 "Functions and Variables for lsquares"))
("lsum" . ("maxima.info-2" 75144 686 "Functions and Variables for Sums and Products"))
("ltreillis" . ("maxima.info-2" 198573 273 "Functions and Variables for Symmetries"))
("lu_backsub" . ("maxima.info-3" 86409 4276 "Functions and Variables for linearalgebra"))
("lu_factor" . ("maxima.info-3" 90686 5379 "Functions and Variables for linearalgebra"))
("lucas" . ("maxima.info-2" 136466 871 "Functions and Variables for Number Theory"))
("m1pbranch" . ("maxima.info-1" 101029 588 "Functions and Variables for Numbers"))
("macroexpand" . ("maxima.info-2" 347922 1225 "Macros"))
("macroexpand1" . ("maxima.info-2" 349148 1137 "Macros"))
("macroexpansion" . ("maxima.info-2" 388108 6129 "Functions and Variables for Function Definition"))
("macros" . ("maxima.info-2" 350286 322 "Macros"))
("mainvar" . ("maxima.info-1" 216655 689 "Functions and Variables for Expressions"))
("makeOrders" . ("maxima.info-3" 135123 809 "Functions and Variables for makeOrders"))
("make_array" . ("maxima.info-1" 178307 2137 "Functions and Variables for Arrays"))
("make_graph" . ("maxima.info-2" 958925 1104 "Functions and Variables for graphs"))
("make_level_picture" . ("maxima.info-2" 839049 1163 "Functions and Variables for pictures"))
("make_poly_continent" . ("maxima.info-2" 843942 609 "Functions and Variables for worldmap"))
("make_poly_country" . ("maxima.info-2" 844552 359 "Functions and Variables for worldmap"))
("make_polygon" . ("maxima.info-2" 844912 3087 "Functions and Variables for worldmap"))
("make_random_state" . ("maxima.info-1" 424334 758 "Random Numbers"))
("make_rgb_picture" . ("maxima.info-2" 840213 1122 "Functions and Variables for pictures"))
("make_string_input_stream" . ("maxima.info-3" 302273 796 "Input and Output"))
("make_string_output_stream" . ("maxima.info-3" 303070 701 "Input and Output"))
("make_transform" . ("maxima.info-1" 485846 746 "Functions and Variables for Plotting"))
("makebox" . ("maxima.info-1" 989772 261 "Functions and Variables for itensor"))
("makefact" . ("maxima.info-1" 678733 157 "Gamma and factorial Functions"))
("makegamma" . ("maxima.info-1" 656206 166 "Gamma and factorial Functions"))
("makelist" . ("maxima.info-1" 140997 1877 "Functions and Variables for Lists"))
("makeset" . ("maxima.info-2" 314621 1605 "Functions and Variables for Sets"))
("mandelbrot" . ("maxima.info-1" 486593 1471 "Functions and Variables for Plotting"))
("mandelbrot_set" . ("maxima.info-2" 946441 493 "Definitions for complex fractals"))
("manual_demo" . ("maxima.info-1" 37620 195 "Functions and Variables for Help"))
("map" . ("maxima.info-2" 438854 1869 "Functions and Variables for Program Flow"))
("mapatom" . ("maxima.info-2" 440724 219 "Functions and Variables for Program Flow"))
("maperror" . ("maxima.info-2" 440944 522 "Functions and Variables for Program Flow"))
("maplist" . ("maxima.info-2" 441840 447 "Functions and Variables for Program Flow"))
("mapprint" . ("maxima.info-2" 441467 372 "Functions and Variables for Program Flow"))
("mat_cond" . ("maxima.info-3" 96066 518 "Functions and Variables for linearalgebra"))
("mat_fullunblocker" . ("maxima.info-3" 97410 170 "Functions and Variables for linearalgebra"))
("mat_function" . ("maxima.info-2" 623959 4104 "Functions and Variables for diag"))
("mat_norm" . ("maxima.info-3" 96585 312 "Functions and Variables for linearalgebra"))
("mat_trace" . ("maxima.info-3" 97581 232 "Functions and Variables for linearalgebra"))
("mat_unblocker" . ("maxima.info-3" 97814 1370 "Functions and Variables for linearalgebra"))
("matchdeclare" . ("maxima.info-2" 261158 7877 "Functions and Variables for Rules and Patterns"))
("matchfix" . ("maxima.info-1" 289924 4648 "User defined operators"))
("mathml_display" . ("maxima.info-2" 473226 361 "Functions and Variables for alt-display"))
("matrix" . ("maxima.info-1" 911845 6023 "Functions and Variables for Matrices and Linear Algebra"))
("matrix_element_add" . ("maxima.info-1" 918549 1303 "Functions and Variables for Matrices and Linear Algebra"))
("matrix_element_mult" . ("maxima.info-1" 919853 1970 "Functions and Variables for Matrices and Linear Algebra"))
("matrix_element_transpose" . ("maxima.info-1" 921824 2191 "Functions and Variables for Matrices and Linear Algebra"))
("matrix_size" . ("maxima.info-3" 97266 143 "Functions and Variables for linearalgebra"))
("matrixexp" . ("maxima.info-1" 917869 422 "Functions and Variables for Matrices and Linear Algebra"))
("matrixmap" . ("maxima.info-1" 918292 161 "Functions and Variables for Matrices and Linear Algebra"))
("matrixp" . ("maxima.info-1" 918454 94 "Functions and Variables for Matrices and Linear Algebra"))
("matrixp <1>" . ("maxima.info-3" 96898 367 "Functions and Variables for linearalgebra"))
("mattrace" . ("maxima.info-1" 924016 272 "Functions and Variables for Matrices and Linear Algebra"))
("max" . ("maxima.info-1" 375048 536 "Functions for Numbers"))
("max_clique" . ("maxima.info-2" 978201 265 "Functions and Variables for graphs"))
("max_degree" . ("maxima.info-2" 978467 384 "Functions and Variables for graphs"))
("max_flow" . ("maxima.info-2" 978852 1032 "Functions and Variables for graphs"))
("max_independent_set" . ("maxima.info-2" 979885 340 "Functions and Variables for graphs"))
("max_matching" . ("maxima.info-2" 980226 405 "Functions and Variables for graphs"))
("maxapplydepth" . ("maxima.info-2" 269036 152 "Functions and Variables for Rules and Patterns"))
("maxapplyheight" . ("maxima.info-2" 269189 160 "Functions and Variables for Rules and Patterns"))
("maxima_tempdir" . ("maxima.info-2" 218911 454 "Functions and Variables for Runtime Environment"))
("maxima_userdir" . ("maxima.info-2" 219366 696 "Functions and Variables for Runtime Environment"))
("maximize_lp" . ("maxima.info-3" 216272 258 "Functions and Variables for simplex"))
("maxnegex" . ("maxima.info-1" 349811 179 "Functions and Variables for Simplification"))
("maxposex" . ("maxima.info-1" 349991 172 "Functions and Variables for Simplification"))
("maxpsifracdenom" . ("maxima.info-1" 678488 244 "Gamma and factorial Functions"))
("maxpsifracnum" . ("maxima.info-1" 678247 240 "Gamma and factorial Functions"))
("maxpsinegint" . ("maxima.info-1" 677958 288 "Gamma and factorial Functions"))
("maxpsiposint" . ("maxima.info-1" 677786 171 "Gamma and factorial Functions"))
("maxtayorder" . ("maxima.info-2" 89208 238 "Functions and Variables for Series"))
("maybe" . ("maxima.info-1" 462222 752 "Functions and Variables for Facts"))
("md5sum" . ("maxima.info-3" 341700 1177 "Octets and Utilities for Cryptography"))
("mean" . ("maxima.info-2" 559979 872 "Functions and Variables for descriptive statistics"))
("mean_bernoulli" . ("maxima.info-2" 693670 313 "Functions and Variables for discrete distributions"))
("mean_beta" . ("maxima.info-2" 663784 167 "Functions and Variables for continuous distributions"))
("mean_binomial" . ("maxima.info-2" 688805 215 "Functions and Variables for discrete distributions"))
("mean_chi2" . ("maxima.info-2" 646880 288 "Functions and Variables for continuous distributions"))
("mean_continuous_uniform" . ("maxima.info-2" 665979 193 "Functions and Variables for continuous distributions"))
("mean_deviation" . ("maxima.info-2" 570279 964 "Functions and Variables for descriptive statistics"))
("mean_discrete_uniform" . ("maxima.info-2" 700313 214 "Functions and Variables for discrete distributions"))
("mean_exp" . ("maxima.info-2" 655310 378 "Functions and Variables for continuous distributions"))
("mean_f" . ("maxima.info-2" 652391 166 "Functions and Variables for continuous distributions"))
("mean_gamma" . ("maxima.info-2" 661216 169 "Functions and Variables for continuous distributions"))
("mean_general_finite_discrete" . ("maxima.info-2" 685998 209 "Functions and Variables for discrete distributions"))
("mean_geometric" . ("maxima.info-2" 697167 329 "Functions and Variables for discrete distributions"))
("mean_gumbel" . ("maxima.info-2" 682019 313 "Functions and Variables for continuous distributions"))
("mean_hypergeometric" . ("maxima.info-2" 703187 261 "Functions and Variables for discrete distributions"))
("mean_laplace" . ("maxima.info-2" 678893 171 "Functions and Variables for continuous distributions"))
("mean_logistic" . ("maxima.info-2" 668219 174 "Functions and Variables for continuous distributions"))
("mean_lognormal" . ("maxima.info-2" 658863 175 "Functions and Variables for continuous distributions"))
("mean_negative_binomial" . ("maxima.info-2" 706208 229 "Functions and Variables for discrete distributions"))
("mean_noncentral_chi2" . ("maxima.info-2" 650004 179 "Functions and Variables for continuous distributions"))
("mean_noncentral_student_t" . ("maxima.info-2" 642714 643 "Functions and Variables for continuous distributions"))
("mean_normal" . ("maxima.info-2" 636191 181 "Functions and Variables for continuous distributions"))
("mean_pareto" . ("maxima.info-2" 670273 172 "Functions and Variables for continuous distributions"))
("mean_poisson" . ("maxima.info-2" 691341 165 "Functions and Variables for discrete distributions"))
("mean_rayleigh" . ("maxima.info-2" 675059 390 "Functions and Variables for continuous distributions"))
("mean_student_t" . ("maxima.info-2" 638829 202 "Functions and Variables for continuous distributions"))
("mean_weibull" . ("maxima.info-2" 672330 173 "Functions and Variables for continuous distributions"))
("median" . ("maxima.info-2" 568799 735 "Functions and Variables for descriptive statistics"))
("median_deviation" . ("maxima.info-2" 571244 890 "Functions and Variables for descriptive statistics"))
("member" . ("maxima.info-1" 142875 1339 "Functions and Variables for Lists"))
("mesh" . ("maxima.info-2" 819943 1424 "Functions and Variables for draw"))
("mesh_lines_color" . ("maxima.info-1" 507261 380 "Plotting Options"))
("method" . ("maxima.info-2" 532504 98 "Functions and Variables for contrib_ode"))
("metricexpandall" . ("maxima.info-3" 421789 979 "Functions and Variables for Units"))
("mgf1_sha1" . ("maxima.info-3" 342878 922 "Octets and Utilities for Cryptography"))
("min" . ("maxima.info-1" 375585 537 "Functions for Numbers"))
("min_degree" . ("maxima.info-2" 980632 383 "Functions and Variables for graphs"))
("min_edge_cut" . ("maxima.info-2" 981016 123 "Functions and Variables for graphs"))
("min_vertex_cover" . ("maxima.info-2" 981140 95 "Functions and Variables for graphs"))
("min_vertex_cut" . ("maxima.info-2" 981236 129 "Functions and Variables for graphs"))
("minf" . ("maxima.info-1" 114037 81 "Functions and Variables for Constants"))
("minfactorial" . ("maxima.info-1" 393215 542 "Combinatorial Functions"))
("minimalPoly" . ("maxima.info-2" 621493 739 "Functions and Variables for diag"))
("minimize_lp" . ("maxima.info-3" 216531 3411 "Functions and Variables for simplex"))
("minimum_spanning_tree" . ("maxima.info-2" 981366 314 "Functions and Variables for graphs"))
("minor" . ("maxima.info-1" 924289 144 "Functions and Variables for Matrices and Linear Algebra"))
("minpack_lsquares" . ("maxima.info-3" 130851 2567 "Functions and Variables for minpack"))
("minpack_solve" . ("maxima.info-3" 133419 1328 "Functions and Variables for minpack"))
("mkdir" . ("maxima.info-3" 162638 56 "Directory operations"))
("mnewton" . ("maxima.info-3" 137136 1585 "Functions and Variables for mnewton"))
("mod" . ("maxima.info-2" 137338 1234 "Functions and Variables for Number Theory"))
("mod_big_prime" . ("maxima.info-3" 439245 154 "Functions and Variables for zeilberger"))
("mod_test" . ("maxima.info-3" 438705 174 "Functions and Variables for zeilberger"))
("mod_threshold" . ("maxima.info-3" 439400 164 "Functions and Variables for zeilberger"))
("mode_check_errorp" . ("maxima.info-2" 398988 137 "Functions and Variables for Function Definition"))
("mode_check_warnp" . ("maxima.info-2" 399126 133 "Functions and Variables for Function Definition"))
("mode_checkp" . ("maxima.info-2" 397891 1096 "Functions and Variables for Function Definition"))
("mode_declare" . ("maxima.info-2" 394238 3652 "Functions and Variables for Function Definition"))
("mode_identity" . ("maxima.info-2" 399260 1487 "Functions and Variables for Function Definition"))
("modedeclare" . ("maxima.info-2" 394239 3651 "Functions and Variables for Function Definition"))
("modular_linear_solver" . ("maxima.info-3" 438880 174 "Functions and Variables for zeilberger"))
("modulus" . ("maxima.info-1" 604533 1862 "Functions and Variables for Polynomials"))
("moebius" . ("maxima.info-2" 316227 1217 "Functions and Variables for Sets"))
("mon2schur" . ("maxima.info-2" 180778 1138 "Functions and Variables for Symmetries"))
("mono" . ("maxima.info-1" 939659 241 "Functions and Variables for Affine"))
("monomial_dimensions" . ("maxima.info-1" 939901 165 "Functions and Variables for Affine"))
("multi_display_for_texinfo" . ("maxima.info-2" 473858 920 "Functions and Variables for alt-display"))
("multi_elem" . ("maxima.info-2" 181917 729 "Functions and Variables for Symmetries"))
("multi_orbit" . ("maxima.info-2" 193809 672 "Functions and Variables for Symmetries"))
("multi_pui" . ("maxima.info-2" 182647 447 "Functions and Variables for Symmetries"))
("multibernstein_poly" . ("maxima.info-2" 486277 430 "Functions and Variables for Bernstein"))
("multinomial" . ("maxima.info-2" 213682 273 "Functions and Variables for Symmetries"))
("multinomial_coeff" . ("maxima.info-2" 317445 1294 "Functions and Variables for Sets"))
("multiplicative" . ("maxima.info-1" 350164 1882 "Functions and Variables for Simplification"))
("multiplicities" . ("maxima.info-1" 817035 201 "Functions and Variables for Equations"))
("multiplot_mode" . ("maxima.info-2" 715669 1341 "Functions and Variables for draw"))
("multsym" . ("maxima.info-2" 194482 817 "Functions and Variables for Symmetries"))
("multthru" . ("maxima.info-1" 352047 2320 "Functions and Variables for Simplification"))
("mycielski_graph" . ("maxima.info-2" 960030 89 "Functions and Variables for graphs"))
("myoptions" . ("maxima.info-1" 54412 184 "Functions and Variables for Command Line"))
("nary" . ("maxima.info-1" 354368 700 "Functions and Variables for Simplification"))
("nary <1>" . ("maxima.info-1" 294573 582 "User defined operators"))
("natural_unit" . ("maxima.info-2" 927817 238 "Functions and Variables for ezunits"))
("nc_degree" . ("maxima.info-1" 938206 163 "Functions and Variables for Affine"))
("ncexpt" . ("maxima.info-1" 78072 301 "Functions and Variables for Display"))
("ncharpoly" . ("maxima.info-1" 924434 794 "Functions and Variables for Matrices and Linear Algebra"))
("negative_picture" . ("maxima.info-2" 841336 98 "Functions and Variables for pictures"))
("negdistrib" . ("maxima.info-1" 355069 786 "Functions and Variables for Simplification"))
("negsumdispflag" . ("maxima.info-1" 89603 380 "Functions and Variables for Display"))
("neighbors" . ("maxima.info-2" 981681 275 "Functions and Variables for graphs"))
("new" . ("maxima.info-1" 187042 771 "Functions and Variables for Structures"))
("new_graph" . ("maxima.info-2" 960120 81 "Functions and Variables for graphs"))
("new_variable" . ("maxima.info-3" 371065 1741 "Functions and Variables for to_poly_solve"))
("newcontext" . ("maxima.info-1" 462975 455 "Functions and Variables for Facts"))
("newdet" . ("maxima.info-1" 925229 170 "Functions and Variables for Matrices and Linear Algebra"))
("newline" . ("maxima.info-3" 321454 72 "Characters"))
("newline <1>" . ("maxima.info-3" 303772 344 "Input and Output"))
("newton" . ("maxima.info-1" 859971 1288 "Functions for numerical solution of equations"))
("newtonepsilon" . ("maxima.info-3" 136631 291 "Functions and Variables for mnewton"))
("newtonmaxiter" . ("maxima.info-3" 136923 212 "Functions and Variables for mnewton"))
("next" . ("maxima.info-2" 421877 8925 "Functions and Variables for Program Flow"))
("next_prime" . ("maxima.info-2" 138573 155 "Functions and Variables for Number Theory"))
("nextlayerfactor" . ("maxima.info-3" 225584 696 "Package facexp"))
("nicedummies" . ("maxima.info-3" 372807 721 "Functions and Variables for to_poly_solve"))
("niceindices" . ("maxima.info-2" 89447 1430 "Functions and Variables for Series"))
("niceindicespref" . ("maxima.info-2" 90878 1084 "Functions and Variables for Series"))
("ninth" . ("maxima.info-1" 144215 122 "Functions and Variables for Lists"))
("nm" . ("maxima.info-2" 60579 83 "Functions and Variables for ctensor"))
("nmc" . ("maxima.info-2" 60663 98 "Functions and Variables for ctensor"))
("noeval" . ("maxima.info-1" 322025 217 "Functions and Variables for Evaluation"))
("nofix" . ("maxima.info-1" 295156 548 "User defined operators"))
("nolabels" . ("maxima.info-1" 54597 761 "Functions and Variables for Command Line"))
("nonarray" . ("maxima.info-1" 441445 577 "Functions and Variables for Properties"))
("noncentral_moment" . ("maxima.info-2" 563604 936 "Functions and Variables for descriptive statistics"))
("nonegative_lp" . ("maxima.info-3" 219944 303 "Functions and Variables for simplex"))
("noninteger" . ("maxima.info-1" 440473 469 "Functions and Variables for Properties"))
("nonmetricity" . ("maxima.info-2" 33272 126 "Functions and Variables for ctensor"))
("nonnegative_lp" . ("maxima.info-3" 219943 304 "Functions and Variables for simplex"))
("nonnegintegerp" . ("maxima.info-1" 101618 104 "Functions and Variables for Numbers"))
("nonscalar" . ("maxima.info-1" 442023 139 "Functions and Variables for Properties"))
("nonscalarp" . ("maxima.info-1" 442163 219 "Functions and Variables for Properties"))
("nonzeroandfreeof" . ("maxima.info-3" 230061 217 "Package functs"))
("not" . ("maxima.info-1" 266621 543 "Logical operators"))
("notequal" . ("maxima.info-1" 470507 934 "Functions and Variables for Predicates"))
("noun" . ("maxima.info-1" 217345 615 "Functions and Variables for Expressions"))
("noundisp" . ("maxima.info-1" 217961 199 "Functions and Variables for Expressions"))
("nounify" . ("maxima.info-1" 218161 405 "Functions and Variables for Expressions"))
("nouns" . ("maxima.info-1" 322243 277 "Functions and Variables for Evaluation"))
("np" . ("maxima.info-2" 59683 78 "Functions and Variables for ctensor"))
("npi" . ("maxima.info-2" 59762 631 "Functions and Variables for ctensor"))
("nptetrad" . ("maxima.info-2" 25800 725 "Functions and Variables for ctensor"))
("npv" . ("maxima.info-2" 942234 318 "Functions and Variables for finance"))
("nroots" . ("maxima.info-1" 817237 401 "Functions and Variables for Equations"))
("nterms" . ("maxima.info-1" 218567 355 "Functions and Variables for Expressions"))
("ntermst" . ("maxima.info-2" 40671 369 "Functions and Variables for ctensor"))
("nthroot" . ("maxima.info-1" 817639 340 "Functions and Variables for Equations"))
("nticks" . ("maxima.info-1" 507642 345 "Plotting Options"))
("nticks <1>" . ("maxima.info-2" 765579 665 "Functions and Variables for draw"))
("ntrig" . ("maxima.info-1" 416982 277 "Functions and Variables for Trigonometric"))
("nullity" . ("maxima.info-3" 99459 100 "Functions and Variables for linearalgebra"))
("nullspace" . ("maxima.info-3" 99185 273 "Functions and Variables for linearalgebra"))
("num" . ("maxima.info-1" 606396 767 "Functions and Variables for Polynomials"))
("num_distinct_partitions" . ("maxima.info-2" 318740 869 "Functions and Variables for Sets"))
("num_partitions" . ("maxima.info-2" 319610 915 "Functions and Variables for Sets"))
("number_to_octets" . ("maxima.info-3" 343801 462 "Octets and Utilities for Cryptography"))
("numbered_boundaries" . ("maxima.info-2" 843417 524 "Functions and Variables for worldmap"))
("numberp" . ("maxima.info-1" 101723 1162 "Functions and Variables for Numbers"))
("numer" . ("maxima.info-1" 102886 706 "Functions and Variables for Numbers"))
("numer_pbranch" . ("maxima.info-1" 103593 1125 "Functions and Variables for Numbers"))
("numerval" . ("maxima.info-1" 104719 444 "Functions and Variables for Numbers"))
("numfactor" . ("maxima.info-1" 678891 559 "Gamma and factorial Functions"))
("nusum" . ("maxima.info-2" 91963 2147 "Functions and Variables for Series"))
("nzeta" . ("maxima.info-1" 695662 118 "Functions and Variables for Special Functions"))
("nzetai" . ("maxima.info-1" 695844 64 "Functions and Variables for Special Functions"))
("nzetar" . ("maxima.info-1" 695781 62 "Functions and Variables for Special Functions"))
("obase" . ("maxima.info-1" 89984 1166 "Functions and Variables for Display"))
("octets_to_number" . ("maxima.info-3" 344264 168 "Octets and Utilities for Cryptography"))
("octets_to_oid" . ("maxima.info-3" 344433 403 "Octets and Utilities for Cryptography"))
("octets_to_string" . ("maxima.info-3" 344837 1950 "Octets and Utilities for Cryptography"))
("odd" . ("maxima.info-1" 436480 648 "Functions and Variables for Properties"))
("odd_girth" . ("maxima.info-2" 981957 359 "Functions and Variables for graphs"))
("oddfun" . ("maxima.info-1" 340514 672 "Functions and Variables for Simplification"))
("oddp" . ("maxima.info-1" 105164 200 "Functions and Variables for Numbers"))
("ode2" . ("maxima.info-1" 839194 3978 "Functions and Variables for Differential Equations"))
("ode_check" . ("maxima.info-2" 531348 1155 "Functions and Variables for contrib_ode"))
("odelin" . ("maxima.info-2" 530575 772 "Functions and Variables for contrib_ode"))
("oid_to_octets" . ("maxima.info-3" 346788 151 "Octets and Utilities for Cryptography"))
("op" . ("maxima.info-1" 218923 1717 "Functions and Variables for Expressions"))
("opacity" . ("maxima.info-2" 882856 254 "Visualization with VTK"))
("opena" . ("maxima.info-3" 304117 272 "Input and Output"))
("opena_binary" . ("maxima.info-3" 150301 141 "Functions and Variables for binary input and output"))
("openr" . ("maxima.info-3" 304390 861 "Input and Output"))
("openr_binary" . ("maxima.info-3" 149919 181 "Functions and Variables for binary input and output"))
("openw" . ("maxima.info-3" 305252 352 "Input and Output"))
("openw_binary" . ("maxima.info-3" 150101 199 "Functions and Variables for binary input and output"))
("operatorp" . ("maxima.info-1" 220641 350 "Functions and Variables for Expressions"))
("opproperties" . ("maxima.info-1" 355856 452 "Functions and Variables for Simplification"))
("opsubst" . ("maxima.info-1" 220992 861 "Functions and Variables for Expressions"))
("opsubst <1>" . ("maxima.info-3" 164209 2283 "Functions and Variables for opsubst"))
("optimize" . ("maxima.info-1" 221854 372 "Functions and Variables for Expressions"))
("optimprefix" . ("maxima.info-1" 222227 150 "Functions and Variables for Expressions"))
("optionset" . ("maxima.info-1" 55359 616 "Functions and Variables for Command Line"))
("or" . ("maxima.info-1" 267165 991 "Logical operators"))
("orbit" . ("maxima.info-2" 195300 548 "Functions and Variables for Symmetries"))
("orbits" . ("maxima.info-2" 870993 1415 "Graphical analysis of discrete dynamical systems"))
("ordergreat" . ("maxima.info-1" 222378 793 "Functions and Variables for Expressions"))
("ordergreatp" . ("maxima.info-1" 223172 3730 "Functions and Variables for Expressions"))
("orderless" . ("maxima.info-1" 222379 792 "Functions and Variables for Expressions"))
("orderlessp" . ("maxima.info-1" 223173 3729 "Functions and Variables for Expressions"))
("orientation" . ("maxima.info-2" 883111 369 "Visualization with VTK"))
("origin" . ("maxima.info-2" 883481 271 "Visualization with VTK"))
("orthogonal_complement" . ("maxima.info-3" 99560 264 "Functions and Variables for linearalgebra"))
("orthopoly_recur" . ("maxima.info-3" 186852 1160 "Functions and Variables for orthogonal polynomials"))
("orthopoly_returns_intervals" . ("maxima.info-3" 188013 370 "Functions and Variables for orthogonal polynomials"))
("orthopoly_weight" . ("maxima.info-3" 188384 744 "Functions and Variables for orthogonal polynomials"))
("out_neighbors" . ("maxima.info-2" 982317 377 "Functions and Variables for graphs"))
("outative" . ("maxima.info-1" 357867 1247 "Functions and Variables for Simplification"))
("outchar" . ("maxima.info-1" 55976 868 "Functions and Variables for Command Line"))
("outermap" . ("maxima.info-2" 445770 6779 "Functions and Variables for Program Flow"))
("outofpois" . ("maxima.info-2" 118117 358 "Functions and Variables for Poisson series"))
("packagefile" . ("maxima.info-2" 237764 713 "Functions and Variables for Miscellaneous Options"))
("pade" . ("maxima.info-2" 94111 3077 "Functions and Variables for Series"))
("palette" . ("maxima.info-1" 507988 1506 "Plotting Options"))
("palette <1>" . ("maxima.info-2" 766245 3199 "Functions and Variables for draw"))
("parGosper" . ("maxima.info-3" 436391 320 "Functions and Variables for zeilberger"))
("parabolic_cylinder_d" . ("maxima.info-1" 686991 133 "Parabolic Cylinder Functions"))
("parametric" . ("maxima.info-2" 821368 1480 "Functions and Variables for draw"))
("parametric_surface" . ("maxima.info-2" 822849 1251 "Functions and Variables for draw"))
("parg" . ("maxima.info-3" 373529 1364 "Functions and Variables for to_poly_solve"))
("parse_string" . ("maxima.info-3" 326829 636 "String Processing"))
("parse_timedate" . ("maxima.info-2" 225148 3631 "Functions and Variables for Runtime Environment"))
("part" . ("maxima.info-1" 226903 1444 "Functions and Variables for Expressions"))
("part2cont" . ("maxima.info-2" 189021 353 "Functions and Variables for Symmetries"))
("partfrac" . ("maxima.info-2" 138729 1312 "Functions and Variables for Number Theory"))
("partition" . ("maxima.info-1" 228348 586 "Functions and Variables for Expressions"))
("partition_set" . ("maxima.info-2" 320526 742 "Functions and Variables for Sets"))
("partpol" . ("maxima.info-2" 189375 285 "Functions and Variables for Symmetries"))
("partswitch" . ("maxima.info-1" 228935 213 "Functions and Variables for Expressions"))
("path_digraph" . ("maxima.info-2" 960202 81 "Functions and Variables for graphs"))
("path_graph" . ("maxima.info-2" 960284 70 "Functions and Variables for graphs"))
("pathname_directory" . ("maxima.info-1" 546596 559 "Functions and Variables for File Input and Output"))
("pathname_name" . ("maxima.info-1" 546597 558 "Functions and Variables for File Input and Output"))
("pathname_type" . ("maxima.info-1" 546643 512 "Functions and Variables for File Input and Output"))
("pdf_bernoulli" . ("maxima.info-2" 692782 353 "Functions and Variables for discrete distributions"))
("pdf_beta" . ("maxima.info-2" 662863 207 "Functions and Variables for continuous distributions"))
("pdf_binomial" . ("maxima.info-2" 687734 259 "Functions and Variables for discrete distributions"))
("pdf_cauchy" . ("maxima.info-2" 680206 209 "Functions and Variables for continuous distributions"))
("pdf_chi2" . ("maxima.info-2" 645417 573 "Functions and Variables for continuous distributions"))
("pdf_continuous_uniform" . ("maxima.info-2" 665173 233 "Functions and Variables for continuous distributions"))
("pdf_discrete_uniform" . ("maxima.info-2" 699457 253 "Functions and Variables for discrete distributions"))
("pdf_exp" . ("maxima.info-2" 653915 378 "Functions and Variables for continuous distributions"))
("pdf_f" . ("maxima.info-2" 651379 203 "Functions and Variables for continuous distributions"))
("pdf_file" . ("maxima.info-1" 510975 789 "Plotting Options"))
("pdf_gamma" . ("maxima.info-2" 660247 209 "Functions and Variables for continuous distributions"))
("pdf_general_finite_discrete" . ("maxima.info-2" 684059 844 "Functions and Variables for discrete distributions"))
("pdf_geometric" . ("maxima.info-2" 695980 346 "Functions and Variables for discrete distributions"))
("pdf_gumbel" . ("maxima.info-2" 681302 209 "Functions and Variables for continuous distributions"))
("pdf_hypergeometric" . ("maxima.info-2" 701915 531 "Functions and Variables for discrete distributions"))
("pdf_laplace" . ("maxima.info-2" 678170 211 "Functions and Variables for continuous distributions"))
("pdf_logistic" . ("maxima.info-2" 667486 214 "Functions and Variables for continuous distributions"))
("pdf_lognormal" . ("maxima.info-2" 657519 215 "Functions and Variables for continuous distributions"))
("pdf_negative_binomial" . ("maxima.info-2" 705149 273 "Functions and Variables for discrete distributions"))
("pdf_noncentral_chi2" . ("maxima.info-2" 649044 286 "Functions and Variables for continuous distributions"))
("pdf_noncentral_student_t" . ("maxima.info-2" 640770 1102 "Functions and Variables for continuous distributions"))
("pdf_normal" . ("maxima.info-2" 634775 209 "Functions and Variables for continuous distributions"))
("pdf_pareto" . ("maxima.info-2" 669551 211 "Functions and Variables for continuous distributions"))
("pdf_poisson" . ("maxima.info-2" 690498 209 "Functions and Variables for discrete distributions"))
("pdf_rank_sum" . ("maxima.info-3" 292747 247 "Functions and Variables for special distributions"))
("pdf_rayleigh" . ("maxima.info-2" 673655 435 "Functions and Variables for continuous distributions"))
("pdf_signed_rank" . ("maxima.info-3" 292276 235 "Functions and Variables for special distributions"))
("pdf_student_t" . ("maxima.info-2" 637703 228 "Functions and Variables for continuous distributions"))
("pdf_weibull" . ("maxima.info-2" 671601 213 "Functions and Variables for continuous distributions"))
("pearson_skewness" . ("maxima.info-2" 575755 828 "Functions and Variables for descriptive statistics"))
("perm_cycles" . ("maxima.info-2" 514415 409 "Functions and Variables for Combinatorics"))
("perm_decomp" . ("maxima.info-2" 514825 434 "Functions and Variables for Combinatorics"))
("perm_inverse" . ("maxima.info-2" 515260 443 "Functions and Variables for Combinatorics"))
("perm_length" . ("maxima.info-2" 515704 464 "Functions and Variables for Combinatorics"))
("perm_lex_next" . ("maxima.info-2" 516169 338 "Functions and Variables for Combinatorics"))
("perm_lex_rank" . ("maxima.info-2" 516508 411 "Functions and Variables for Combinatorics"))
("perm_lex_unrank" . ("maxima.info-2" 516920 370 "Functions and Variables for Combinatorics"))
("perm_next" . ("maxima.info-2" 517291 356 "Functions and Variables for Combinatorics"))
("perm_parity" . ("maxima.info-2" 517648 439 "Functions and Variables for Combinatorics"))
("perm_rank" . ("maxima.info-2" 518088 397 "Functions and Variables for Combinatorics"))
("perm_undecomp" . ("maxima.info-2" 518486 349 "Functions and Variables for Combinatorics"))
("perm_unrank" . ("maxima.info-2" 518836 356 "Functions and Variables for Combinatorics"))
("permanent" . ("maxima.info-1" 925400 265 "Functions and Variables for Matrices and Linear Algebra"))
("permp" . ("maxima.info-2" 519193 445 "Functions and Variables for Combinatorics"))
("perms" . ("maxima.info-2" 519639 1491 "Functions and Variables for Combinatorics"))
("perms_lex" . ("maxima.info-2" 521131 1791 "Functions and Variables for Combinatorics"))
("permult" . ("maxima.info-2" 522923 272 "Functions and Variables for Combinatorics"))
("permut" . ("maxima.info-2" 213956 84 "Functions and Variables for Symmetries"))
("permutation" . ("maxima.info-3" 234919 190 "Package functs"))
("permutations" . ("maxima.info-2" 321269 566 "Functions and Variables for Sets"))
("permute" . ("maxima.info-2" 523196 608 "Functions and Variables for Combinatorics"))
("petersen_graph" . ("maxima.info-2" 960355 199 "Functions and Variables for graphs"))
("petrov" . ("maxima.info-2" 27804 3792 "Functions and Variables for ctensor"))
("pfeformat" . ("maxima.info-1" 91151 820 "Functions and Variables for Display"))
("phi" . ("maxima.info-1" 114120 2414 "Functions and Variables for Constants"))
("phiresolution" . ("maxima.info-2" 883753 277 "Visualization with VTK"))
("pi" . ("maxima.info-1" 116536 200 "Functions and Variables for Constants"))
("pickapart" . ("maxima.info-1" 229149 2974 "Functions and Variables for Expressions"))
("picture_equalp" . ("maxima.info-2" 841435 109 "Functions and Variables for pictures"))
("picturep" . ("maxima.info-2" 841545 117 "Functions and Variables for pictures"))
("piece" . ("maxima.info-1" 232124 210 "Functions and Variables for Expressions"))
("piechart" . ("maxima.info-2" 608077 1617 "Functions and Variables for statistical graphs"))
("piechart_description" . ("maxima.info-2" 609695 184 "Functions and Variables for statistical graphs"))
("pivot_count_sx" . ("maxima.info-3" 220442 134 "Functions and Variables for simplex"))
("pivot_max_sx" . ("maxima.info-3" 220577 116 "Functions and Variables for simplex"))
("planar_embedding" . ("maxima.info-2" 982695 540 "Functions and Variables for graphs"))
("playback" . ("maxima.info-1" 56845 2018 "Functions and Variables for Command Line"))
("plog" . ("maxima.info-1" 408710 146 "Root Exponential and Logarithmic Functions"))
("plot2d" . ("maxima.info-1" 488380 6409 "Functions and Variables for Plotting"))
("plot3d" . ("maxima.info-1" 494790 4508 "Functions and Variables for Plotting"))
("plot_format" . ("maxima.info-1" 509495 302 "Plotting Options"))
("plot_options" . ("maxima.info-1" 499299 291 "Functions and Variables for Plotting"))
("plot_realpart" . ("maxima.info-1" 509798 643 "Plotting Options"))
("plotdf" . ("maxima.info-1" 862877 8926 "Functions for numerical solution of differential equations"))
("ploteq" . ("maxima.info-1" 871804 1221 "Functions for numerical solution of differential equations"))
("plsquares" . ("maxima.info-3" 126015 4139 "Functions and Variables for lsquares"))
("png_file" . ("maxima.info-1" 511765 726 "Plotting Options"))
("pochhammer" . ("maxima.info-3" 189129 1273 "Functions and Variables for orthogonal polynomials"))
("pochhammer_max_index" . ("maxima.info-3" 190403 508 "Functions and Variables for orthogonal polynomials"))
("point_size" . ("maxima.info-2" 769445 575 "Functions and Variables for draw"))
("point_type" . ("maxima.info-1" 510442 532 "Plotting Options"))
("point_type <1>" . ("maxima.info-2" 770021 1705 "Functions and Variables for draw"))
("points" . ("maxima.info-2" 884031 202 "Visualization with VTK"))
("points <1>" . ("maxima.info-2" 824101 6304 "Functions and Variables for draw"))
("points_joined" . ("maxima.info-2" 771727 1168 "Functions and Variables for draw"))
("pointsize" . ("maxima.info-2" 884234 175 "Visualization with VTK"))
("poisdiff" . ("maxima.info-2" 118476 157 "Functions and Variables for Poisson series"))
("poisexpt" . ("maxima.info-2" 118634 126 "Functions and Variables for Poisson series"))
("poisint" . ("maxima.info-2" 118761 180 "Functions and Variables for Poisson series"))
("poislim" . ("maxima.info-2" 118942 295 "Functions and Variables for Poisson series"))
("poismap" . ("maxima.info-2" 119238 317 "Functions and Variables for Poisson series"))
("poisplus" . ("maxima.info-2" 119556 89 "Functions and Variables for Poisson series"))
("poissimp" . ("maxima.info-2" 119646 110 "Functions and Variables for Poisson series"))
("poisson" . ("maxima.info-2" 119757 110 "Functions and Variables for Poisson series"))
("poissubst" . ("maxima.info-2" 119868 894 "Functions and Variables for Poisson series"))
("poistimes" . ("maxima.info-2" 120763 92 "Functions and Variables for Poisson series"))
("poistrim" . ("maxima.info-2" 120856 378 "Functions and Variables for Poisson series"))
("polar" . ("maxima.info-2" 830406 872 "Functions and Variables for draw"))
("polar_to_xy" . ("maxima.info-1" 488065 314 "Functions and Variables for Plotting"))
("polarform" . ("maxima.info-1" 384571 661 "Functions for Complex Numbers"))
("polartorect" . ("maxima.info-1" 844296 603 "Functions and Variables for fast Fourier transform"))
("poly_add" . ("maxima.info-3" 4792 250 "Functions and Variables for grobner"))
("poly_buchberger" . ("maxima.info-3" 9597 186 "Functions and Variables for grobner"))
("poly_buchberger_criterion" . ("maxima.info-3" 9280 316 "Functions and Variables for grobner"))
("poly_coefficient_ring" . ("maxima.info-3" 2483 329 "Functions and Variables for grobner"))
("poly_colon_ideal" . ("maxima.info-3" 11794 227 "Functions and Variables for grobner"))
("poly_content" . ("maxima.info-3" 8045 203 "Functions and Variables for grobner"))
("poly_depends_p" . ("maxima.info-3" 11390 137 "Functions and Variables for grobner"))
("poly_elimination_ideal" . ("maxima.info-3" 11528 265 "Functions and Variables for grobner"))
("poly_elimination_order" . ("maxima.info-3" 3225 402 "Functions and Variables for grobner"))
("poly_exact_divide" . ("maxima.info-3" 8873 219 "Functions and Variables for grobner"))
("poly_expand" . ("maxima.info-3" 6272 1475 "Functions and Variables for grobner"))
("poly_expt" . ("maxima.info-3" 7748 296 "Functions and Variables for grobner"))
("poly_gcd" . ("maxima.info-3" 12299 625 "Functions and Variables for grobner"))
("poly_grobner" . ("maxima.info-3" 11040 166 "Functions and Variables for grobner"))
("poly_grobner_algorithm" . ("maxima.info-3" 4015 248 "Functions and Variables for grobner"))
("poly_grobner_debug" . ("maxima.info-3" 3884 130 "Functions and Variables for grobner"))
("poly_grobner_equal" . ("maxima.info-3" 12925 672 "Functions and Variables for grobner"))
("poly_grobner_member" . ("maxima.info-3" 13887 455 "Functions and Variables for grobner"))
("poly_grobner_subsetp" . ("maxima.info-3" 13598 288 "Functions and Variables for grobner"))
("poly_ideal_intersection" . ("maxima.info-3" 12022 158 "Functions and Variables for grobner"))
("poly_ideal_polysaturation" . ("maxima.info-3" 15524 309 "Functions and Variables for grobner"))
("poly_ideal_polysaturation1" . ("maxima.info-3" 15095 428 "Functions and Variables for grobner"))
("poly_ideal_saturation" . ("maxima.info-3" 14704 390 "Functions and Variables for grobner"))
("poly_ideal_saturation1" . ("maxima.info-3" 14343 360 "Functions and Variables for grobner"))
("poly_lcm" . ("maxima.info-3" 12181 117 "Functions and Variables for grobner"))
("poly_minimization" . ("maxima.info-3" 10500 297 "Functions and Variables for grobner"))
("poly_monomial_order" . ("maxima.info-3" 2262 220 "Functions and Variables for grobner"))
("poly_multiply" . ("maxima.info-3" 5311 246 "Functions and Variables for grobner"))
("poly_normal_form" . ("maxima.info-3" 9093 186 "Functions and Variables for grobner"))
("poly_normalize" . ("maxima.info-3" 5966 237 "Functions and Variables for grobner"))
("poly_normalize_list" . ("maxima.info-3" 10798 241 "Functions and Variables for grobner"))
("poly_polysaturation_extension" . ("maxima.info-3" 16004 101 "Functions and Variables for grobner"))
("poly_primary_elimination_order" . ("maxima.info-3" 2813 207 "Functions and Variables for grobner"))
("poly_primitive_part" . ("maxima.info-3" 5720 245 "Functions and Variables for grobner"))
("poly_pseudo_divide" . ("maxima.info-3" 8249 623 "Functions and Variables for grobner"))
("poly_reduced_grobner" . ("maxima.info-3" 11207 182 "Functions and Variables for grobner"))
("poly_reduction" . ("maxima.info-3" 10292 207 "Functions and Variables for grobner"))
("poly_return_term_list" . ("maxima.info-3" 3628 255 "Functions and Variables for grobner"))
("poly_s_polynomial" . ("maxima.info-3" 5558 161 "Functions and Variables for grobner"))
("poly_saturation_extension" . ("maxima.info-3" 15834 169 "Functions and Variables for grobner"))
("poly_secondary_elimination_order" . ("maxima.info-3" 3021 203 "Functions and Variables for grobner"))
("poly_subtract" . ("maxima.info-3" 5043 267 "Functions and Variables for grobner"))
("poly_top_reduction_only" . ("maxima.info-3" 4264 226 "Functions and Variables for grobner"))
("polydecomp" . ("maxima.info-1" 607164 1929 "Functions and Variables for Polynomials"))
("polyfactor" . ("maxima.info-1" 817980 331 "Functions and Variables for Equations"))
("polygon" . ("maxima.info-2" 831279 865 "Functions and Variables for draw"))
("polymod" . ("maxima.info-1" 609094 360 "Functions and Variables for Polynomials"))
("polynome2ele" . ("maxima.info-2" 200513 588 "Functions and Variables for Symmetries"))
("polynomialp" . ("maxima.info-3" 99825 1674 "Functions and Variables for linearalgebra"))
("polytocompanion" . ("maxima.info-3" 101500 289 "Functions and Variables for linearalgebra"))
("pop" . ("maxima.info-1" 144338 295 "Functions and Variables for Lists"))
("posfun" . ("maxima.info-1" 442383 152 "Functions and Variables for Properties"))
("position" . ("maxima.info-2" 884410 216 "Visualization with VTK"))
("postfix" . ("maxima.info-1" 295705 470 "User defined operators"))
("postsubscript" . ("maxima.info-1" 64896 3373 "Functions and Variables for Display"))
("postsuperscript" . ("maxima.info-1" 64926 3343 "Functions and Variables for Display"))
("potential" . ("maxima.info-1" 763268 547 "Functions and Variables for Integration"))
("power_mod" . ("maxima.info-2" 140042 540 "Functions and Variables for Number Theory"))
("powerdisp" . ("maxima.info-1" 91972 796 "Functions and Variables for Display"))
("powerseries" . ("maxima.info-2" 97189 1917 "Functions and Variables for Series"))
("powerset" . ("maxima.info-2" 321836 1096 "Functions and Variables for Sets"))
("pred" . ("maxima.info-1" 322521 356 "Functions and Variables for Evaluation"))
("prederror" . ("maxima.info-2" 442288 465 "Functions and Variables for Program Flow"))
("prefix" . ("maxima.info-1" 296176 389 "User defined operators"))
("presubscript" . ("maxima.info-1" 64980 3289 "Functions and Variables for Display"))
("presuperscript" . ("maxima.info-1" 64952 3317 "Functions and Variables for Display"))
("prev_prime" . ("maxima.info-2" 141644 156 "Functions and Variables for Number Theory"))
("primep" . ("maxima.info-2" 140583 761 "Functions and Variables for Number Theory"))
("primep_number_of_tests" . ("maxima.info-2" 141345 122 "Functions and Variables for Number Theory"))
("primes" . ("maxima.info-2" 141468 175 "Functions and Variables for Number Theory"))
("principal_components" . ("maxima.info-2" 589690 4264 "Functions and Variables for descriptive statistics"))
("print" . ("maxima.info-1" 92769 1346 "Functions and Variables for Display"))
("print_graph" . ("maxima.info-2" 983236 700 "Functions and Variables for graphs"))
("printf" . ("maxima.info-3" 305605 5018 "Input and Output"))
("printfile" . ("maxima.info-1" 547156 579 "Functions and Variables for File Input and Output"))
("printpois" . ("maxima.info-2" 121235 188 "Functions and Variables for Poisson series"))
("printprops" . ("maxima.info-1" 442536 539 "Functions and Variables for Properties"))
("prodrac" . ("maxima.info-2" 201102 245 "Functions and Variables for Symmetries"))
("product" . ("maxima.info-2" 76736 2529 "Functions and Variables for Sums and Products"))
("product_use_gamma" . ("maxima.info-3" 249561 246 "Functions and Variables for solve_rec"))
("program" . ("maxima.info-2" 1001422 437 "Functions and Variables for graphs"))
("programmode" . ("maxima.info-1" 818312 447 "Functions and Variables for Equations"))
("prompt" . ("maxima.info-1" 58864 192 "Functions and Variables for Command Line"))
("properties" . ("maxima.info-1" 443076 122 "Functions and Variables for Properties"))
("proportional_axes" . ("maxima.info-2" 772896 1213 "Functions and Variables for draw"))
("props" . ("maxima.info-1" 443199 282 "Functions and Variables for Properties"))
("propvars" . ("maxima.info-1" 443515 182 "Functions and Variables for Properties"))
("ps_file" . ("maxima.info-1" 512492 818 "Plotting Options"))
("psexpand" . ("maxima.info-2" 99107 452 "Functions and Variables for Series"))
("psi" . ("maxima.info-1" 676889 896 "Gamma and factorial Functions"))
("psi <1>" . ("maxima.info-2" 26526 1277 "Functions and Variables for ctensor"))
("psubst" . ("maxima.info-1" 232335 832 "Functions and Variables for Expressions"))
("ptriangularize" . ("maxima.info-3" 101790 433 "Functions and Variables for linearalgebra"))
("pui" . ("maxima.info-2" 183095 1330 "Functions and Variables for Symmetries"))
("pui2comp" . ("maxima.info-2" 184426 1258 "Functions and Variables for Symmetries"))
("pui2ele" . ("maxima.info-2" 185685 389 "Functions and Variables for Symmetries"))
("pui2polynome" . ("maxima.info-2" 201348 657 "Functions and Variables for Symmetries"))
("pui_direct" . ("maxima.info-2" 195849 2197 "Functions and Variables for Symmetries"))
("puireduc" . ("maxima.info-2" 186075 682 "Functions and Variables for Symmetries"))
("push" . ("maxima.info-1" 144634 1289 "Functions and Variables for Lists"))
("put" . ("maxima.info-1" 443748 838 "Functions and Variables for Properties"))
("pv" . ("maxima.info-2" 933611 357 "Functions and Variables for finance"))
("pytranslate" . ("maxima.info-3" 195135 1878 "Functions in pytranslate"))
("qput" . ("maxima.info-1" 444638 762 "Functions and Variables for Properties"))
("qrange" . ("maxima.info-2" 569535 743 "Functions and Variables for descriptive statistics"))
("qty" . ("maxima.info-2" 914706 970 "Functions and Variables for ezunits"))
("quad_control" . ("maxima.info-1" 791716 603 "Functions and Variables for QUADPACK"))
("quad_qag" . ("maxima.info-1" 770071 2746 "Functions and Variables for QUADPACK"))
("quad_qagi" . ("maxima.info-1" 774991 2469 "Functions and Variables for QUADPACK"))
("quad_qagp" . ("maxima.info-1" 789151 2564 "Functions and Variables for QUADPACK"))
("quad_qags" . ("maxima.info-1" 772818 2172 "Functions and Variables for QUADPACK"))
("quad_qawc" . ("maxima.info-1" 777461 3220 "Functions and Variables for QUADPACK"))
("quad_qawf" . ("maxima.info-1" 780682 2643 "Functions and Variables for QUADPACK"))
("quad_qawo" . ("maxima.info-1" 783326 2919 "Functions and Variables for QUADPACK"))
("quad_qaws" . ("maxima.info-1" 786246 2904 "Functions and Variables for QUADPACK"))
("quadrilateral" . ("maxima.info-2" 832145 1068 "Functions and Variables for draw"))
("quantile" . ("maxima.info-2" 567889 909 "Functions and Variables for descriptive statistics"))
("quantile_bernoulli" . ("maxima.info-2" 693363 306 "Functions and Variables for discrete distributions"))
("quantile_beta" . ("maxima.info-2" 663496 287 "Functions and Variables for continuous distributions"))
("quantile_binomial" . ("maxima.info-2" 688465 339 "Functions and Variables for discrete distributions"))
("quantile_cauchy" . ("maxima.info-2" 680631 291 "Functions and Variables for continuous distributions"))
("quantile_chi2" . ("maxima.info-2" 646459 420 "Functions and Variables for continuous distributions"))
("quantile_continuous_uniform" . ("maxima.info-2" 665646 332 "Functions and Variables for continuous distributions"))
("quantile_discrete_uniform" . ("maxima.info-2" 699966 346 "Functions and Variables for discrete distributions"))
("quantile_exp" . ("maxima.info-2" 654680 629 "Functions and Variables for continuous distributions"))
("quantile_f" . ("maxima.info-2" 652047 343 "Functions and Variables for continuous distributions"))
("quantile_gamma" . ("maxima.info-2" 660926 289 "Functions and Variables for continuous distributions"))
("quantile_general_finite_discrete" . ("maxima.info-2" 685772 225 "Functions and Variables for discrete distributions"))
("quantile_geometric" . ("maxima.info-2" 696714 452 "Functions and Variables for discrete distributions"))
("quantile_gumbel" . ("maxima.info-2" 681727 291 "Functions and Variables for continuous distributions"))
("quantile_hypergeometric" . ("maxima.info-2" 702807 379 "Functions and Variables for discrete distributions"))
("quantile_laplace" . ("maxima.info-2" 678599 293 "Functions and Variables for continuous distributions"))
("quantile_logistic" . ("maxima.info-2" 667921 297 "Functions and Variables for continuous distributions"))
("quantile_lognormal" . ("maxima.info-2" 658323 539 "Functions and Variables for continuous distributions"))
("quantile_negative_binomial" . ("maxima.info-2" 705845 362 "Functions and Variables for discrete distributions"))
("quantile_noncentral_chi2" . ("maxima.info-2" 649623 380 "Functions and Variables for continuous distributions"))
("quantile_noncentral_student_t" . ("maxima.info-2" 642312 401 "Functions and Variables for continuous distributions"))
("quantile_normal" . ("maxima.info-2" 635592 598 "Functions and Variables for continuous distributions"))
("quantile_pareto" . ("maxima.info-2" 669980 292 "Functions and Variables for continuous distributions"))
("quantile_poisson" . ("maxima.info-2" 691052 288 "Functions and Variables for discrete distributions"))
("quantile_rayleigh" . ("maxima.info-2" 674529 529 "Functions and Variables for continuous distributions"))
("quantile_student_t" . ("maxima.info-2" 638535 293 "Functions and Variables for continuous distributions"))
("quantile_weibull" . ("maxima.info-2" 672034 295 "Functions and Variables for continuous distributions"))
("quartile_skewness" . ("maxima.info-2" 576584 916 "Functions and Variables for descriptive statistics"))
("quit" . ("maxima.info-1" 59057 376 "Functions and Variables for Command Line"))
("qunit" . ("maxima.info-2" 141801 415 "Functions and Variables for Number Theory"))
("quotient" . ("maxima.info-1" 609455 343 "Functions and Variables for Polynomials"))
("racah_v" . ("maxima.info-2" 503702 158 "Functions and Variables for clebsch_gordan"))
("racah_w" . ("maxima.info-2" 503861 142 "Functions and Variables for clebsch_gordan"))
("radcan" . ("maxima.info-1" 359115 1231 "Functions and Variables for Simplification"))
("radexpand" . ("maxima.info-1" 360347 807 "Functions and Variables for Simplification"))
("radius" . ("maxima.info-2" 884627 223 "Visualization with VTK"))
("radius <1>" . ("maxima.info-2" 983937 209 "Functions and Variables for graphs"))
("radsubstflag" . ("maxima.info-1" 625178 176 "Functions and Variables for Polynomials"))
("random" . ("maxima.info-1" 425234 1642 "Random Numbers"))
("random_bernoulli" . ("maxima.info-2" 695552 427 "Functions and Variables for discrete distributions"))
("random_beta" . ("maxima.info-2" 664694 478 "Functions and Variables for continuous distributions"))
("random_binomial" . ("maxima.info-2" 689941 556 "Functions and Variables for discrete distributions"))
("random_bipartite_graph" . ("maxima.info-2" 960555 159 "Functions and Variables for graphs"))
("random_cauchy" . ("maxima.info-2" 680923 378 "Functions and Variables for continuous distributions"))
("random_chi2" . ("maxima.info-2" 648643 400 "Functions and Variables for continuous distributions"))
("random_continuous_uniform" . ("maxima.info-2" 667025 460 "Functions and Variables for continuous distributions"))
("random_digraph" . ("maxima.info-2" 960715 142 "Functions and Variables for graphs"))
("random_discrete_uniform" . ("maxima.info-2" 701444 470 "Functions and Variables for discrete distributions"))
("random_exp" . ("maxima.info-2" 657153 365 "Functions and Variables for continuous distributions"))
("random_f" . ("maxima.info-2" 653296 618 "Functions and Variables for continuous distributions"))
("random_gamma" . ("maxima.info-2" 662136 726 "Functions and Variables for continuous distributions"))
("random_general_finite_discrete" . ("maxima.info-2" 687104 629 "Functions and Variables for discrete distributions"))
("random_geometric" . ("maxima.info-2" 698909 547 "Functions and Variables for discrete distributions"))
("random_graph" . ("maxima.info-2" 961073 132 "Functions and Variables for graphs"))
("random_graph1" . ("maxima.info-2" 961206 105 "Functions and Variables for graphs"))
("random_gumbel" . ("maxima.info-2" 683408 380 "Functions and Variables for continuous distributions"))
("random_hypergeometric" . ("maxima.info-2" 704533 615 "Functions and Variables for discrete distributions"))
("random_laplace" . ("maxima.info-2" 679823 382 "Functions and Variables for continuous distributions"))
("random_logistic" . ("maxima.info-2" 669164 386 "Functions and Variables for continuous distributions"))
("random_lognormal" . ("maxima.info-2" 659813 433 "Functions and Variables for continuous distributions"))
("random_negative_binomial" . ("maxima.info-2" 707414 506 "Functions and Variables for discrete distributions"))
("random_network" . ("maxima.info-2" 961312 515 "Functions and Variables for graphs"))
("random_noncentral_chi2" . ("maxima.info-2" 650975 403 "Functions and Variables for continuous distributions"))
("random_noncentral_student_t" . ("maxima.info-2" 644478 938 "Functions and Variables for continuous distributions"))
("random_normal" . ("maxima.info-2" 637211 491 "Functions and Variables for continuous distributions"))
("random_pareto" . ("maxima.info-2" 671218 382 "Functions and Variables for continuous distributions"))
("random_perm" . ("maxima.info-2" 523805 264 "Functions and Variables for Combinatorics"))
("random_permutation" . ("maxima.info-2" 322933 796 "Functions and Variables for Sets"))
("random_poisson" . ("maxima.info-2" 692246 535 "Functions and Variables for discrete distributions"))
("random_rayleigh" . ("maxima.info-2" 677792 377 "Functions and Variables for continuous distributions"))
("random_regular_graph" . ("maxima.info-2" 960858 214 "Functions and Variables for graphs"))
("random_student_t" . ("maxima.info-2" 639949 820 "Functions and Variables for continuous distributions"))
("random_tournament" . ("maxima.info-2" 961828 88 "Functions and Variables for graphs"))
("random_tree" . ("maxima.info-2" 961917 76 "Functions and Variables for graphs"))
("random_weibull" . ("maxima.info-2" 673270 384 "Functions and Variables for continuous distributions"))
("range" . ("maxima.info-2" 567413 475 "Functions and Variables for descriptive statistics"))
("rank" . ("maxima.info-1" 925666 276 "Functions and Variables for Matrices and Linear Algebra"))
("rassociative" . ("maxima.info-1" 361155 196 "Functions and Variables for Simplification"))
("rat" . ("maxima.info-1" 609799 2533 "Functions and Variables for Polynomials"))
("ratalgdenom" . ("maxima.info-1" 612333 294 "Functions and Variables for Polynomials"))
("ratchristof" . ("maxima.info-2" 57402 99 "Functions and Variables for ctensor"))
("ratcoef" . ("maxima.info-1" 612628 1106 "Functions and Variables for Polynomials"))
("ratdenom" . ("maxima.info-1" 613735 620 "Functions and Variables for Polynomials"))
("ratdenomdivide" . ("maxima.info-1" 614356 1838 "Functions and Variables for Polynomials"))
("ratdiff" . ("maxima.info-1" 616195 1842 "Functions and Variables for Polynomials"))
("ratdisrep" . ("maxima.info-1" 618038 432 "Functions and Variables for Polynomials"))
("rateinstein" . ("maxima.info-2" 57502 241 "Functions and Variables for ctensor"))
("ratepsilon" . ("maxima.info-1" 105365 267 "Functions and Variables for Numbers"))
("ratexpand" . ("maxima.info-1" 618471 2246 "Functions and Variables for Polynomials"))
("ratexpand <1>" . ("maxima.info-1" 618472 2245 "Functions and Variables for Polynomials"))
("ratfac" . ("maxima.info-1" 620718 1001 "Functions and Variables for Polynomials"))
("ratinterpol" . ("maxima.info-3" 30342 1406 "Functions and Variables for interpol"))
("rational" . ("maxima.info-1" 445425 189 "Functions and Variables for Properties"))
("rational <1>" . ("maxima.info-3" 229745 315 "Package functs"))
("rationalize" . ("maxima.info-1" 105633 1472 "Functions and Variables for Numbers"))
("ratmx" . ("maxima.info-1" 925943 590 "Functions and Variables for Matrices and Linear Algebra"))
("ratnumer" . ("maxima.info-1" 621720 612 "Functions and Variables for Polynomials"))
("ratnump" . ("maxima.info-1" 107106 139 "Functions and Variables for Numbers"))
("ratp" . ("maxima.info-1" 622333 261 "Functions and Variables for Polynomials"))
("ratp_coeffs" . ("maxima.info-3" 204350 278 "Functions and Variables for ratpow"))
("ratp_dense_coeffs" . ("maxima.info-3" 204629 316 "Functions and Variables for ratpow"))
("ratp_hipow" . ("maxima.info-3" 202971 333 "Functions and Variables for ratpow"))
("ratp_lopow" . ("maxima.info-3" 203305 1044 "Functions and Variables for ratpow"))
("ratprint" . ("maxima.info-1" 622595 207 "Functions and Variables for Polynomials"))
("ratriemann" . ("maxima.info-2" 57744 277 "Functions and Variables for ctensor"))
("ratsimp" . ("maxima.info-1" 622803 2191 "Functions and Variables for Polynomials"))
("ratsimp <1>" . ("maxima.info-1" 622804 2190 "Functions and Variables for Polynomials"))
("ratsimpexpons" . ("maxima.info-1" 624995 182 "Functions and Variables for Polynomials"))
("ratsubst" . ("maxima.info-1" 625355 1575 "Functions and Variables for Polynomials"))
("ratvars" . ("maxima.info-1" 626931 928 "Functions and Variables for Polynomials"))
("ratvars <1>" . ("maxima.info-1" 626932 927 "Functions and Variables for Polynomials"))
("ratvars <2>" . ("maxima.info-1" 626974 885 "Functions and Variables for Polynomials"))
("ratvarswitch" . ("maxima.info-1" 627860 1518 "Functions and Variables for Polynomials"))
("ratweight" . ("maxima.info-1" 629379 1182 "Functions and Variables for Polynomials"))
("ratweights" . ("maxima.info-1" 630562 294 "Functions and Variables for Polynomials"))
("ratweyl" . ("maxima.info-2" 58022 256 "Functions and Variables for ctensor"))
("ratwtlvl" . ("maxima.info-1" 630857 261 "Functions and Variables for Polynomials"))
("read" . ("maxima.info-1" 59434 557 "Functions and Variables for Command Line"))
("read_array" . ("maxima.info-3" 144878 678 "Functions and Variables for plain-text input and output"))
("read_binary_array" . ("maxima.info-3" 150859 476 "Functions and Variables for binary input and output"))
("read_binary_list" . ("maxima.info-3" 151336 604 "Functions and Variables for binary input and output"))
("read_binary_matrix" . ("maxima.info-3" 150443 415 "Functions and Variables for binary input and output"))
("read_hash_table" . ("maxima.info-3" 145557 827 "Functions and Variables for plain-text input and output"))
("read_list" . ("maxima.info-3" 147118 743 "Functions and Variables for plain-text input and output"))
("read_matrix" . ("maxima.info-3" 143395 1482 "Functions and Variables for plain-text input and output"))
("read_nested_list" . ("maxima.info-3" 146385 732 "Functions and Variables for plain-text input and output"))
("read_xpm" . ("maxima.info-2" 841663 91 "Functions and Variables for pictures"))
("readbyte" . ("maxima.info-3" 310624 878 "Input and Output"))
("readchar" . ("maxima.info-3" 311503 214 "Input and Output"))
("readline" . ("maxima.info-3" 311718 214 "Input and Output"))
("readonly" . ("maxima.info-1" 59992 673 "Functions and Variables for Command Line"))
("real" . ("maxima.info-1" 445635 241 "Functions and Variables for Properties"))
("real_fft" . ("maxima.info-1" 852567 745 "Functions and Variables for fast Fourier transform"))
("real_imagpart_to_conjugate" . ("maxima.info-3" 374894 734 "Functions and Variables for to_poly_solve"))
("realonly" . ("maxima.info-1" 818760 158 "Functions and Variables for Equations"))
("realpart" . ("maxima.info-1" 385233 575 "Functions for Complex Numbers"))
("realroots" . ("maxima.info-1" 818919 2077 "Functions and Variables for Equations"))
("rearray" . ("maxima.info-1" 180445 369 "Functions and Variables for Arrays"))
("rectangle" . ("maxima.info-2" 833214 981 "Functions and Variables for draw"))
("rectform" . ("maxima.info-1" 385809 456 "Functions for Complex Numbers"))
("rectform_log_if_constant" . ("maxima.info-3" 375629 1015 "Functions and Variables for to_poly_solve"))
("recttopolar" . ("maxima.info-1" 844900 675 "Functions and Variables for fast Fourier transform"))
("rediff" . ("maxima.info-1" 985052 124 "Functions and Variables for itensor"))
("redraw" . ("maxima.info-2" 1000599 188 "Functions and Variables for graphs"))
("reduce_consts" . ("maxima.info-3" 239288 1374 "Package rducon"))
("reduce_order" . ("maxima.info-3" 242910 1790 "Functions and Variables for solve_rec"))
("refcheck" . ("maxima.info-2" 459408 192 "Functions and Variables for Debugging"))
("region" . ("maxima.info-2" 834196 729 "Functions and Variables for draw"))
("region_boundaries" . ("maxima.info-2" 848000 544 "Functions and Variables for worldmap"))
("region_boundaries_plus" . ("maxima.info-2" 848545 585 "Functions and Variables for worldmap"))
("rem" . ("maxima.info-1" 445918 238 "Functions and Variables for Properties"))
("remainder" . ("maxima.info-1" 631119 370 "Functions and Variables for Polynomials"))
("remarray" . ("maxima.info-1" 180815 558 "Functions and Variables for Arrays"))
("rembox" . ("maxima.info-1" 233168 2490 "Functions and Variables for Expressions"))
("remcomps" . ("maxima.info-1" 967281 130 "Functions and Variables for itensor"))
("remcon" . ("maxima.info-1" 962164 262 "Functions and Variables for itensor"))
("remcoord" . ("maxima.info-1" 989479 292 "Functions and Variables for itensor"))
("remfun" . ("maxima.info-2" 115003 330 "Functions and Variables for Fourier series"))
("remfunction" . ("maxima.info-2" 400748 742 "Functions and Variables for Function Definition"))
("remlet" . ("maxima.info-2" 269350 960 "Functions and Variables for Rules and Patterns"))
("remove" . ("maxima.info-1" 446179 1529 "Functions and Variables for Properties"))
("remove_constvalue" . ("maxima.info-2" 912461 150 "Functions and Variables for ezunits"))
("remove_dimensions" . ("maxima.info-2" 920376 164 "Functions and Variables for ezunits"))
("remove_edge" . ("maxima.info-2" 992450 370 "Functions and Variables for graphs"))
("remove_fundamental_dimensions" . ("maxima.info-2" 920542 1368 "Functions and Variables for ezunits"))
("remove_fundamental_units" . ("maxima.info-2" 921979 1610 "Functions and Variables for ezunits"))
("remove_index_properties" . ("maxima.info-1" 68439 285 "Functions and Variables for Display"))
("remove_plot_option" . ("maxima.info-1" 499591 226 "Functions and Variables for Plotting"))
("remove_vertex" . ("maxima.info-2" 992821 90 "Functions and Variables for graphs"))
("rempart" . ("maxima.info-3" 228684 231 "Package functs"))
("remrule" . ("maxima.info-2" 270311 2037 "Functions and Variables for Rules and Patterns"))
("remsym" . ("maxima.info-1" 980978 161 "Functions and Variables for itensor"))
("remvalue" . ("maxima.info-2" 238478 441 "Functions and Variables for Miscellaneous Options"))
("rename" . ("maxima.info-1" 957098 3183 "Functions and Variables for itensor"))
("rename_file" . ("maxima.info-3" 163296 82 "File operations"))
("reset" . ("maxima.info-1" 60666 460 "Functions and Variables for Command Line"))
("reset_displays" . ("maxima.info-2" 474779 160 "Functions and Variables for alt-display"))
("residue" . ("maxima.info-1" 763816 676 "Functions and Variables for Integration"))
("resolution" . ("maxima.info-2" 884851 198 "Visualization with VTK"))
("resolvante" . ("maxima.info-2" 202296 7352 "Functions and Variables for Symmetries"))
("resolvante_alternee1" . ("maxima.info-2" 209649 371 "Functions and Variables for Symmetries"))
("resolvante_bipartite" . ("maxima.info-2" 210021 558 "Functions and Variables for Symmetries"))
("resolvante_diedrale" . ("maxima.info-2" 210580 689 "Functions and Variables for Symmetries"))
("resolvante_klein" . ("maxima.info-2" 211270 324 "Functions and Variables for Symmetries"))
("resolvante_klein3" . ("maxima.info-2" 211595 324 "Functions and Variables for Symmetries"))
("resolvante_produit_sym" . ("maxima.info-2" 211920 1072 "Functions and Variables for Symmetries"))
("resolvante_unitaire" . ("maxima.info-2" 212993 322 "Functions and Variables for Symmetries"))
("resolvante_vierer" . ("maxima.info-2" 213316 323 "Functions and Variables for Symmetries"))
("rest" . ("maxima.info-1" 145924 1091 "Functions and Variables for Lists"))
("restart" . ("maxima.info-2" 877052 248 "Visualization with VTK"))
("resultant" . ("maxima.info-1" 632983 557 "Functions and Variables for Polynomials"))
("resultant <1>" . ("maxima.info-1" 631490 1492 "Functions and Variables for Polynomials"))
("return" . ("maxima.info-2" 442754 1197 "Functions and Variables for Program Flow"))
("reveal" . ("maxima.info-1" 235659 2531 "Functions and Variables for Expressions"))
("reverse" . ("maxima.info-1" 147016 232 "Functions and Variables for Lists"))
("revert" . ("maxima.info-2" 99560 1872 "Functions and Variables for Series"))
("revert2" . ("maxima.info-2" 99561 1871 "Functions and Variables for Series"))
("rgb2level" . ("maxima.info-2" 841755 136 "Functions and Variables for pictures"))
("rhs" . ("maxima.info-1" 820997 1625 "Functions and Variables for Equations"))
("ric" . ("maxima.info-2" 59061 74 "Functions and Variables for ctensor"))
("ricci" . ("maxima.info-2" 14531 269 "Functions and Variables for ctensor"))
("riem" . ("maxima.info-2" 58608 284 "Functions and Variables for ctensor"))
("riemann" . ("maxima.info-2" 16494 1250 "Functions and Variables for ctensor"))
("rinvariant" . ("maxima.info-2" 18410 246 "Functions and Variables for ctensor"))
("risch" . ("maxima.info-1" 764493 1049 "Functions and Variables for Integration"))
("rk" . ("maxima.info-1" 873026 3449 "Functions for numerical solution of differential equations"))
("rmdir" . ("maxima.info-3" 162695 56 "Directory operations"))
("rmxchar" . ("maxima.info-1" 926648 159 "Functions and Variables for Matrices and Linear Algebra"))
("rncombine" . ("maxima.info-2" 238920 694 "Functions and Variables for Miscellaneous Options"))
("romberg" . ("maxima.info-3" 205277 4795 "Functions and Variables for romberg"))
("rombergabs" . ("maxima.info-3" 210073 541 "Functions and Variables for romberg"))
("rombergit" . ("maxima.info-3" 210615 427 "Functions and Variables for romberg"))
("rombergmin" . ("maxima.info-3" 211043 283 "Functions and Variables for romberg"))
("rombergtol" . ("maxima.info-3" 211327 544 "Functions and Variables for romberg"))
("room" . ("maxima.info-2" 220063 400 "Functions and Variables for Runtime Environment"))
("rootsconmode" . ("maxima.info-1" 822623 173 "Functions and Variables for Equations"))
("rootscontract" . ("maxima.info-1" 822797 2667 "Functions and Variables for Equations"))
("rootsepsilon" . ("maxima.info-1" 825465 195 "Functions and Variables for Equations"))
("round" . ("maxima.info-1" 376123 322 "Functions for Numbers"))
("row" . ("maxima.info-1" 926534 113 "Functions and Variables for Matrices and Linear Algebra"))
("rowop" . ("maxima.info-3" 102224 225 "Functions and Variables for linearalgebra"))
("rowswap" . ("maxima.info-3" 102943 148 "Functions and Variables for linearalgebra"))
("rreduce" . ("maxima.info-1" 147249 1461 "Functions and Variables for Lists"))
("run_testsuite" . ("maxima.info-1" 23945 2145 "Functions and Variables for Bug Detection and Reporting"))
("run_viewer" . ("maxima.info-1" 513311 1071 "Plotting Options"))
("same_xy" . ("maxima.info-1" 514383 205 "Plotting Options"))
("same_xyz" . ("maxima.info-1" 514589 161 "Plotting Options"))
("save" . ("maxima.info-1" 547736 2884 "Functions and Variables for File Input and Output"))
("savedef" . ("maxima.info-2" 401491 395 "Functions and Variables for Function Definition"))
("savefactors" . ("maxima.info-1" 633541 305 "Functions and Variables for Polynomials"))
("saving" . ("maxima.info-2" 940838 1395 "Functions and Variables for finance"))
("scalar" . ("maxima.info-1" 447731 107 "Functions and Variables for Properties"))
("scalarmatrixp" . ("maxima.info-1" 926808 456 "Functions and Variables for Matrices and Linear Algebra"))
("scalarp" . ("maxima.info-1" 447871 270 "Functions and Variables for Properties"))
("scale" . ("maxima.info-2" 885050 446 "Visualization with VTK"))
("scale_lp" . ("maxima.info-3" 220248 193 "Functions and Variables for simplex"))
("scaled_bessel_i" . ("maxima.info-1" 645488 485 "Bessel Functions"))
("scaled_bessel_i0" . ("maxima.info-1" 645974 80 "Bessel Functions"))
("scaled_bessel_i1" . ("maxima.info-1" 646055 80 "Bessel Functions"))
("scalefactors" . ("maxima.info-1" 927265 1050 "Functions and Variables for Matrices and Linear Algebra"))
("scanmap" . ("maxima.info-2" 443952 1638 "Functions and Variables for Program Flow"))
("scatterplot" . ("maxima.info-2" 609880 1946 "Functions and Variables for statistical graphs"))
("scatterplot_description" . ("maxima.info-2" 611827 195 "Functions and Variables for statistical graphs"))
("scene" . ("maxima.info-2" 873726 2239 "Visualization with VTK"))
("schur2comp" . ("maxima.info-2" 186758 655 "Functions and Variables for Symmetries"))
("sconcat" . ("maxima.info-1" 111148 627 "Functions and Variables for Strings"))
("scopy" . ("maxima.info-3" 327466 81 "String Processing"))
("scsimp" . ("maxima.info-1" 361352 416 "Functions and Variables for Simplification"))
("scurvature" . ("maxima.info-2" 15334 160 "Functions and Variables for ctensor"))
("sdowncase" . ("maxima.info-3" 327548 227 "String Processing"))
("sec" . ("maxima.info-1" 417260 40 "Functions and Variables for Trigonometric"))
("sech" . ("maxima.info-1" 417301 52 "Functions and Variables for Trigonometric"))
("second" . ("maxima.info-1" 148711 123 "Functions and Variables for Lists"))
("sequal" . ("maxima.info-3" 327776 142 "String Processing"))
("sequalignore" . ("maxima.info-3" 327919 277 "String Processing"))
("set_alt_display" . ("maxima.info-2" 474940 795 "Functions and Variables for alt-display"))
("set_draw_defaults" . ("maxima.info-2" 717011 747 "Functions and Variables for draw"))
("set_edge_weight" . ("maxima.info-2" 984147 485 "Functions and Variables for graphs"))
("set_partitions" . ("maxima.info-2" 326344 1635 "Functions and Variables for Sets"))
("set_plot_option" . ("maxima.info-1" 499818 1261 "Functions and Variables for Plotting"))
("set_prompt" . ("maxima.info-2" 475736 2635 "Functions and Variables for alt-display"))
("set_random_state" . ("maxima.info-1" 425093 140 "Random Numbers"))
("set_tex_environment" . ("maxima.info-1" 563261 1258 "Functions and Variables for TeX Output"))
("set_tex_environment_default" . ("maxima.info-1" 564521 1208 "Functions and Variables for TeX Output"))
("set_up_dot_simplifications" . ("maxima.info-1" 937061 901 "Functions and Variables for Affine"))
("set_vertex_label" . ("maxima.info-2" 984633 491 "Functions and Variables for graphs"))
("setcheck" . ("maxima.info-2" 459601 1167 "Functions and Variables for Debugging"))
("setcheckbreak" . ("maxima.info-2" 460769 479 "Functions and Variables for Debugging"))
("setdifference" . ("maxima.info-2" 323730 867 "Functions and Variables for Sets"))
("setelmx" . ("maxima.info-1" 928316 232 "Functions and Variables for Matrices and Linear Algebra"))
("setequalp" . ("maxima.info-2" 324598 623 "Functions and Variables for Sets"))
("setify" . ("maxima.info-2" 325222 579 "Functions and Variables for Sets"))
("setp" . ("maxima.info-2" 325802 541 "Functions and Variables for Sets"))
("setunits" . ("maxima.info-3" 403609 4909 "Functions and Variables for Units"))
("setup_autoload" . ("maxima.info-2" 239615 1388 "Functions and Variables for Miscellaneous Options"))
("setval" . ("maxima.info-2" 461249 244 "Functions and Variables for Debugging"))
("seventh" . ("maxima.info-1" 148835 124 "Functions and Variables for Lists"))
("sexplode" . ("maxima.info-3" 328197 88 "String Processing"))
("sf" . ("maxima.info-2" 72163 286 "Functions and Variables for atensor"))
("sha1sum" . ("maxima.info-3" 346940 1213 "Octets and Utilities for Cryptography"))
("sha256sum" . ("maxima.info-3" 348154 752 "Octets and Utilities for Cryptography"))
("share_testsuite_files" . ("maxima.info-1" 26726 191 "Functions and Variables for Bug Detection and Reporting"))
("shortest_path" . ("maxima.info-2" 985125 366 "Functions and Variables for graphs"))
("shortest_weighted_path" . ("maxima.info-2" 985492 616 "Functions and Variables for graphs"))
("show" . ("maxima.info-1" 960282 283 "Functions and Variables for itensor"))
("show_edge_color" . ("maxima.info-2" 999899 106 "Functions and Variables for graphs"))
("show_edge_type" . ("maxima.info-2" 1000087 149 "Functions and Variables for graphs"))
("show_edge_width" . ("maxima.info-2" 1000006 80 "Functions and Variables for graphs"))
("show_edges" . ("maxima.info-2" 999784 114 "Functions and Variables for graphs"))
("show_form" . ("maxima.info-3" 197014 162 "Functions in pytranslate"))
("show_id" . ("maxima.info-2" 997730 115 "Functions and Variables for graphs"))
("show_label" . ("maxima.info-2" 997846 121 "Functions and Variables for graphs"))
("show_vertex_color" . ("maxima.info-2" 998997 114 "Functions and Variables for graphs"))
("show_vertex_size" . ("maxima.info-2" 998910 86 "Functions and Variables for graphs"))
("show_vertex_type" . ("maxima.info-2" 998717 192 "Functions and Variables for graphs"))
("show_vertices" . ("maxima.info-2" 998592 124 "Functions and Variables for graphs"))
("show_weight" . ("maxima.info-2" 998141 120 "Functions and Variables for graphs"))
("showcomps" . ("maxima.info-1" 967412 2555 "Functions and Variables for itensor"))
("showratvars" . ("maxima.info-1" 633847 162 "Functions and Variables for Polynomials"))
("showtime" . ("maxima.info-1" 61127 341 "Functions and Variables for Command Line"))
("sierpinskiale" . ("maxima.info-2" 945206 372 "Definitions for IFS fractals"))
("sierpinskimap" . ("maxima.info-2" 950017 256 "Definitions for Peano maps"))
("sign" . ("maxima.info-1" 463431 398 "Functions and Variables for Facts"))
("signum" . ("maxima.info-1" 376446 748 "Functions for Numbers"))
("similaritytransform" . ("maxima.info-1" 928549 1185 "Functions and Variables for Matrices and Linear Algebra"))
("simp" . ("maxima.info-1" 361769 1654 "Functions and Variables for Simplification"))
("simp_inequality" . ("maxima.info-3" 376645 1945 "Functions and Variables for to_poly_solve"))
("simplified_output" . ("maxima.info-3" 437582 200 "Functions and Variables for zeilberger"))
("simplify_products" . ("maxima.info-3" 244701 193 "Functions and Variables for solve_rec"))
("simplify_sum" . ("maxima.info-3" 244895 825 "Functions and Variables for solve_rec"))
("simplode" . ("maxima.info-3" 328286 683 "String Processing"))
("simpmetderiv" . ("maxima.info-1" 990908 3116 "Functions and Variables for itensor"))
("simpproduct" . ("maxima.info-2" 76338 397 "Functions and Variables for Sums and Products"))
("simpsum" . ("maxima.info-2" 79266 374 "Functions and Variables for Sums and Products"))
("simtran" . ("maxima.info-1" 928550 1184 "Functions and Variables for Matrices and Linear Algebra"))
("sin" . ("maxima.info-1" 417354 38 "Functions and Variables for Trigonometric"))
("sinh" . ("maxima.info-1" 417393 50 "Functions and Variables for Trigonometric"))
("sinnpiflag" . ("maxima.info-2" 116594 81 "Functions and Variables for Fourier series"))
("sinsert" . ("maxima.info-3" 328970 520 "String Processing"))
("sinvertcase" . ("maxima.info-3" 329491 453 "String Processing"))
("sixth" . ("maxima.info-1" 148960 122 "Functions and Variables for Lists"))
("skewness" . ("maxima.info-2" 574866 888 "Functions and Variables for descriptive statistics"))
("skewness_bernoulli" . ("maxima.info-2" 694644 463 "Functions and Variables for discrete distributions"))
("skewness_beta" . ("maxima.info-2" 664308 192 "Functions and Variables for continuous distributions"))
("skewness_binomial" . ("maxima.info-2" 689469 235 "Functions and Variables for discrete distributions"))
("skewness_chi2" . ("maxima.info-2" 647769 473 "Functions and Variables for continuous distributions"))
("skewness_continuous_uniform" . ("maxima.info-2" 666587 218 "Functions and Variables for continuous distributions"))
("skewness_discrete_uniform" . ("maxima.info-2" 700974 234 "Functions and Variables for discrete distributions"))
("skewness_exp" . ("maxima.info-2" 656513 319 "Functions and Variables for continuous distributions"))
("skewness_f" . ("maxima.info-2" 652912 191 "Functions and Variables for continuous distributions"))
("skewness_gamma" . ("maxima.info-2" 661746 194 "Functions and Variables for continuous distributions"))
("skewness_general_finite_discrete" . ("maxima.info-2" 686644 229 "Functions and Variables for discrete distributions"))
("skewness_geometric" . ("maxima.info-2" 698191 353 "Functions and Variables for discrete distributions"))
("skewness_gumbel" . ("maxima.info-2" 682693 519 "Functions and Variables for continuous distributions"))
("skewness_hypergeometric" . ("maxima.info-2" 703981 275 "Functions and Variables for discrete distributions"))
("skewness_laplace" . ("maxima.info-2" 679429 196 "Functions and Variables for continuous distributions"))
("skewness_logistic" . ("maxima.info-2" 668764 199 "Functions and Variables for continuous distributions"))
("skewness_lognormal" . ("maxima.info-2" 659411 200 "Functions and Variables for continuous distributions"))
("skewness_negative_binomial" . ("maxima.info-2" 706914 249 "Functions and Variables for discrete distributions"))
("skewness_noncentral_chi2" . ("maxima.info-2" 650565 204 "Functions and Variables for continuous distributions"))
("skewness_noncentral_student_t" . ("maxima.info-2" 643906 285 "Functions and Variables for continuous distributions"))
("skewness_normal" . ("maxima.info-2" 636765 222 "Functions and Variables for continuous distributions"))
("skewness_pareto" . ("maxima.info-2" 670820 198 "Functions and Variables for continuous distributions"))
("skewness_poisson" . ("maxima.info-2" 691860 190 "Functions and Variables for discrete distributions"))
("skewness_rayleigh" . ("maxima.info-2" 676484 663 "Functions and Variables for continuous distributions"))
("skewness_student_t" . ("maxima.info-2" 639531 222 "Functions and Variables for continuous distributions"))
("skewness_weibull" . ("maxima.info-2" 672872 198 "Functions and Variables for continuous distributions"))
("slength" . ("maxima.info-3" 329945 85 "String Processing"))
("smake" . ("maxima.info-3" 330031 196 "String Processing"))
("small_rhombicosidodecahedron_graph" . ("maxima.info-2" 961994 105 "Functions and Variables for graphs"))
("small_rhombicuboctahedron_graph" . ("maxima.info-2" 962100 99 "Functions and Variables for graphs"))
("smax" . ("maxima.info-2" 566776 636 "Functions and Variables for descriptive statistics"))
("smin" . ("maxima.info-2" 566142 633 "Functions and Variables for descriptive statistics"))
("smismatch" . ("maxima.info-3" 330228 474 "String Processing"))
("snowmap" . ("maxima.info-2" 948732 759 "Definitions for Koch snowflakes"))
("snub_cube_graph" . ("maxima.info-2" 962200 67 "Functions and Variables for graphs"))
("snub_dodecahedron_graph" . ("maxima.info-2" 962268 83 "Functions and Variables for graphs"))
("solve" . ("maxima.info-1" 825661 7024 "Functions and Variables for Equations"))
("solve_rec" . ("maxima.info-3" 245721 2975 "Functions and Variables for solve_rec"))
("solve_rec_rat" . ("maxima.info-3" 248697 863 "Functions and Variables for solve_rec"))
("solvedecomposes" . ("maxima.info-1" 832686 167 "Functions and Variables for Equations"))
("solveexplicit" . ("maxima.info-1" 832854 233 "Functions and Variables for Equations"))
("solvefactors" . ("maxima.info-1" 833088 240 "Functions and Variables for Equations"))
("solvenullwarn" . ("maxima.info-1" 833329 296 "Functions and Variables for Equations"))
("solveradcan" . ("maxima.info-1" 833626 242 "Functions and Variables for Equations"))
("solvetrigwarn" . ("maxima.info-1" 833869 249 "Functions and Variables for Equations"))
("some" . ("maxima.info-2" 327980 2925 "Functions and Variables for Sets"))
("somrac" . ("maxima.info-2" 202006 253 "Functions and Variables for Symmetries"))
("sort" . ("maxima.info-1" 149083 5886 "Functions and Variables for Lists"))
("space" . ("maxima.info-3" 321527 47 "Characters"))
("sparse" . ("maxima.info-1" 929735 203 "Functions and Variables for Matrices and Linear Algebra"))
("sparse6_decode" . ("maxima.info-2" 993802 117 "Functions and Variables for graphs"))
("sparse6_encode" . ("maxima.info-2" 993920 116 "Functions and Variables for graphs"))
("sparse6_export" . ("maxima.info-2" 994037 135 "Functions and Variables for graphs"))
("sparse6_import" . ("maxima.info-2" 994173 110 "Functions and Variables for graphs"))
("specint" . ("maxima.info-1" 687364 4232 "Functions and Variables for Special Functions"))
("sphere" . ("maxima.info-2" 880020 120 "Visualization with VTK"))
("spherical" . ("maxima.info-2" 834926 729 "Functions and Variables for draw"))
("spherical_bessel_j" . ("maxima.info-3" 190912 193 "Functions and Variables for orthogonal polynomials"))
("spherical_bessel_y" . ("maxima.info-3" 191106 194 "Functions and Variables for orthogonal polynomials"))
("spherical_hankel1" . ("maxima.info-3" 191301 165 "Functions and Variables for orthogonal polynomials"))
("spherical_hankel2" . ("maxima.info-3" 191467 166 "Functions and Variables for orthogonal polynomials"))
("spherical_harmonic" . ("maxima.info-3" 191634 126 "Functions and Variables for orthogonal polynomials"))
("spherical_to_xyz" . ("maxima.info-1" 501080 447 "Functions and Variables for Plotting"))
("splice" . ("maxima.info-2" 350609 1631 "Macros"))
("split" . ("maxima.info-3" 330703 801 "String Processing"))
("sposition" . ("maxima.info-3" 331505 246 "String Processing"))
("spring_embedding_depth" . ("maxima.info-2" 1001049 154 "Functions and Variables for graphs"))
("sprint" . ("maxima.info-3" 311933 789 "Input and Output"))
("sqfr" . ("maxima.info-1" 634010 731 "Functions and Variables for Polynomials"))
("sqrt" . ("maxima.info-1" 408857 151 "Root Exponential and Logarithmic Functions"))
("sqrtdenest" . ("maxima.info-1" 238191 861 "Functions and Variables for Expressions"))
("sqrtdispflag" . ("maxima.info-1" 94116 148 "Functions and Variables for Display"))
("sremove" . ("maxima.info-3" 331752 778 "String Processing"))
("sremovefirst" . ("maxima.info-3" 332531 334 "String Processing"))
("sreverse" . ("maxima.info-3" 332866 142 "String Processing"))
("ssearch" . ("maxima.info-3" 333009 667 "String Processing"))
("ssort" . ("maxima.info-3" 333677 701 "String Processing"))
("sstatus" . ("maxima.info-2" 220464 457 "Functions and Variables for Runtime Environment"))
("ssubst" . ("maxima.info-3" 334379 933 "String Processing"))
("ssubstfirst" . ("maxima.info-3" 335313 356 "String Processing"))
("staircase" . ("maxima.info-2" 872409 859 "Graphical analysis of discrete dynamical systems"))
("standardize" . ("maxima.info-2" 551488 376 "Functions and Variables for data manipulation"))
("standardize_inverse_trig" . ("maxima.info-3" 378591 508 "Functions and Variables for to_poly_solve"))
("stardisp" . ("maxima.info-1" 94265 163 "Functions and Variables for Display"))
("starplot" . ("maxima.info-2" 612023 2292 "Functions and Variables for statistical graphs"))
("starplot_description" . ("maxima.info-2" 614316 184 "Functions and Variables for statistical graphs"))
("startphi" . ("maxima.info-2" 885497 454 "Visualization with VTK"))
("starttheta" . ("maxima.info-2" 885952 450 "Visualization with VTK"))
("stats_numer" . ("maxima.info-3" 257533 254 "Functions and Variables for stats"))
("status" . ("maxima.info-2" 220922 1004 "Functions and Variables for Runtime Environment"))
("std" . ("maxima.info-2" 562313 641 "Functions and Variables for descriptive statistics"))
("std1" . ("maxima.info-2" 562955 648 "Functions and Variables for descriptive statistics"))
("std_bernoulli" . ("maxima.info-2" 694304 339 "Functions and Variables for discrete distributions"))
("std_beta" . ("maxima.info-2" 664122 185 "Functions and Variables for continuous distributions"))
("std_binomial" . ("maxima.info-2" 689240 228 "Functions and Variables for discrete distributions"))
("std_chi2" . ("maxima.info-2" 647461 307 "Functions and Variables for continuous distributions"))
("std_continuous_uniform" . ("maxima.info-2" 666375 211 "Functions and Variables for continuous distributions"))
("std_discrete_uniform" . ("maxima.info-2" 700746 227 "Functions and Variables for discrete distributions"))
("std_exp" . ("maxima.info-2" 656117 395 "Functions and Variables for continuous distributions"))
("std_f" . ("maxima.info-2" 652727 184 "Functions and Variables for continuous distributions"))
("std_gamma" . ("maxima.info-2" 661558 187 "Functions and Variables for continuous distributions"))
("std_general_finite_discrete" . ("maxima.info-2" 686421 222 "Functions and Variables for discrete distributions"))
("std_geometric" . ("maxima.info-2" 697834 356 "Functions and Variables for discrete distributions"))
("std_gumbel" . ("maxima.info-2" 682505 187 "Functions and Variables for continuous distributions"))
("std_hypergeometric" . ("maxima.info-2" 703712 268 "Functions and Variables for discrete distributions"))
("std_laplace" . ("maxima.info-2" 679239 189 "Functions and Variables for continuous distributions"))
("std_logistic" . ("maxima.info-2" 668571 192 "Functions and Variables for continuous distributions"))
("std_lognormal" . ("maxima.info-2" 659217 193 "Functions and Variables for continuous distributions"))
("std_negative_binomial" . ("maxima.info-2" 706671 242 "Functions and Variables for discrete distributions"))
("std_noncentral_chi2" . ("maxima.info-2" 650367 197 "Functions and Variables for continuous distributions"))
("std_noncentral_student_t" . ("maxima.info-2" 643627 278 "Functions and Variables for continuous distributions"))
("std_normal" . ("maxima.info-2" 636565 199 "Functions and Variables for continuous distributions"))
("std_pareto" . ("maxima.info-2" 670628 191 "Functions and Variables for continuous distributions"))
("std_poisson" . ("maxima.info-2" 691676 183 "Functions and Variables for discrete distributions"))
("std_rayleigh" . ("maxima.info-2" 675976 507 "Functions and Variables for continuous distributions"))
("std_student_t" . ("maxima.info-2" 639343 187 "Functions and Variables for continuous distributions"))
("std_weibull" . ("maxima.info-2" 672680 191 "Functions and Variables for continuous distributions"))
("stemplot" . ("maxima.info-2" 614501 1001 "Functions and Variables for statistical graphs"))
("step" . ("maxima.info-2" 421850 8952 "Functions and Variables for Program Flow"))
("stirling" . ("maxima.info-3" 293603 2488 "Functions and Variables for stirling"))
("stirling1" . ("maxima.info-2" 330906 1319 "Functions and Variables for Sets"))
("stirling2" . ("maxima.info-2" 332226 1444 "Functions and Variables for Sets"))
("strim" . ("maxima.info-3" 335670 350 "String Processing"))
("striml" . ("maxima.info-3" 336021 112 "String Processing"))
("strimr" . ("maxima.info-3" 336134 113 "String Processing"))
("string" . ("maxima.info-1" 111776 282 "Functions and Variables for Strings"))
("string_to_octets" . ("maxima.info-3" 348907 693 "Octets and Utilities for Cryptography"))
("stringdisp" . ("maxima.info-1" 112059 767 "Functions and Variables for Strings"))
("stringout" . ("maxima.info-1" 550621 2181 "Functions and Variables for File Input and Output"))
("stringp" . ("maxima.info-3" 336248 104 "String Processing"))
("strong_components" . ("maxima.info-2" 986109 366 "Functions and Variables for graphs"))
("structures" . ("maxima.info-1" 185365 119 "Functions and Variables for Structures"))
("struve_h" . ("maxima.info-1" 683917 102 "Struve Functions"))
("struve_l" . ("maxima.info-1" 684020 118 "Struve Functions"))
("style" . ("maxima.info-1" 514751 1932 "Plotting Options"))
("sublis" . ("maxima.info-1" 239053 464 "Functions and Variables for Expressions"))
("sublis_apply_lambda" . ("maxima.info-1" 239518 269 "Functions and Variables for Expressions"))
("sublist" . ("maxima.info-1" 154970 321 "Functions and Variables for Lists"))
("sublist_indices" . ("maxima.info-1" 155292 1077 "Functions and Variables for Lists"))
("submatrix" . ("maxima.info-1" 929939 313 "Functions and Variables for Matrices and Linear Algebra"))
("subnumsimp" . ("maxima.info-1" 239788 584 "Functions and Variables for Expressions"))
("subsample" . ("maxima.info-2" 551865 6201 "Functions and Variables for data manipulation"))
("subset" . ("maxima.info-2" 333671 606 "Functions and Variables for Sets"))
("subsetp" . ("maxima.info-2" 334278 392 "Functions and Variables for Sets"))
("subst" . ("maxima.info-1" 240373 3327 "Functions and Variables for Expressions"))
("subst_parallel" . ("maxima.info-3" 379100 2106 "Functions and Variables for to_poly_solve"))
("substinpart" . ("maxima.info-1" 243701 2410 "Functions and Variables for Expressions"))
("substpart" . ("maxima.info-1" 246112 1152 "Functions and Variables for Expressions"))
("substring" . ("maxima.info-3" 336353 596 "String Processing"))
("subvar" . ("maxima.info-1" 181374 723 "Functions and Variables for Arrays"))
("subvarp" . ("maxima.info-1" 182098 114 "Functions and Variables for Arrays"))
("sum" . ("maxima.info-2" 79641 4598 "Functions and Variables for Sums and Products"))
("sumcontract" . ("maxima.info-2" 84240 588 "Functions and Variables for Sums and Products"))
("sumexpand" . ("maxima.info-2" 84829 948 "Functions and Variables for Sums and Products"))
("summand_to_rec" . ("maxima.info-3" 249808 1265 "Functions and Variables for solve_rec"))
("sumsplitfact" . ("maxima.info-1" 393758 995 "Combinatorial Functions"))
("supcase" . ("maxima.info-3" 336950 487 "String Processing"))
("supcontext" . ("maxima.info-1" 463830 507 "Functions and Variables for Facts"))
("surface" . ("maxima.info-2" 886403 294 "Visualization with VTK"))
("surface_hide" . ("maxima.info-2" 774110 527 "Functions and Variables for draw"))
("svg_file" . ("maxima.info-1" 516684 712 "Plotting Options"))
("symbolp" . ("maxima.info-1" 247265 125 "Functions and Variables for Expressions"))
("symmdifference" . ("maxima.info-2" 334671 1034 "Functions and Variables for Sets"))
("symmetric" . ("maxima.info-1" 363424 229 "Functions and Variables for Simplification"))
("symmetricp" . ("maxima.info-2" 40335 335 "Functions and Variables for ctensor"))
("system" . ("maxima.info-2" 221927 807 "Functions and Variables for Runtime Environment"))
("t" . ("maxima.info-1" 517397 79 "Plotting Options"))
("tab" . ("maxima.info-3" 321575 43 "Characters"))
("take_channel" . ("maxima.info-2" 841892 913 "Functions and Variables for pictures"))
("take_inference" . ("maxima.info-3" 255418 1853 "Functions and Variables for inference_result"))
("tan" . ("maxima.info-1" 417444 41 "Functions and Variables for Trigonometric"))
("tanh" . ("maxima.info-1" 417486 53 "Functions and Variables for Trigonometric"))
("taylor" . ("maxima.info-2" 101433 7940 "Functions and Variables for Series"))
("taylor_logexpand" . ("maxima.info-2" 110627 604 "Functions and Variables for Series"))
("taylor_order_coefficients" . ("maxima.info-2" 111232 281 "Functions and Variables for Series"))
("taylor_simplifier" . ("maxima.info-2" 111514 135 "Functions and Variables for Series"))
("taylor_truncate_polynomials" . ("maxima.info-2" 111650 293 "Functions and Variables for Series"))
("taylordepth" . ("maxima.info-2" 109374 252 "Functions and Variables for Series"))
("taylorinfo" . ("maxima.info-2" 109627 893 "Functions and Variables for Series"))
("taylorp" . ("maxima.info-2" 110521 105 "Functions and Variables for Series"))
("taytorat" . ("maxima.info-2" 111944 195 "Functions and Variables for Series"))
("tcl_output" . ("maxima.info-2" 241004 1211 "Functions and Variables for Miscellaneous Options"))
("tcontract" . ("maxima.info-2" 189661 212 "Functions and Variables for Symmetries"))
("tellrat" . ("maxima.info-1" 634742 2259 "Functions and Variables for Polynomials"))
("tellsimp" . ("maxima.info-2" 272349 2431 "Functions and Variables for Rules and Patterns"))
("tellsimpafter" . ("maxima.info-2" 274781 9202 "Functions and Variables for Rules and Patterns"))
("tensorkill" . ("maxima.info-2" 60762 158 "Functions and Variables for ctensor"))
("tentex" . ("maxima.info-1" 1020923 1228 "Functions and Variables for itensor"))
("tenth" . ("maxima.info-1" 156370 123 "Functions and Variables for Lists"))
("terminal" . ("maxima.info-2" 774638 3134 "Functions and Variables for draw"))
("terminal <1>" . ("maxima.info-2" 1001204 123 "Functions and Variables for graphs"))
("test_mean" . ("maxima.info-3" 257788 4378 "Functions and Variables for stats"))
("test_means_difference" . ("maxima.info-3" 262167 4833 "Functions and Variables for stats"))
("test_normality" . ("maxima.info-3" 287297 1054 "Functions and Variables for stats"))
("test_proportion" . ("maxima.info-3" 272298 3514 "Functions and Variables for stats"))
("test_proportions_difference" . ("maxima.info-3" 275813 3690 "Functions and Variables for stats"))
("test_rank_sum" . ("maxima.info-3" 284534 2762 "Functions and Variables for stats"))
("test_sign" . ("maxima.info-3" 279504 1937 "Functions and Variables for stats"))
("test_signed_rank" . ("maxima.info-3" 281442 3091 "Functions and Variables for stats"))
("test_variance" . ("maxima.info-3" 267001 2543 "Functions and Variables for stats"))
("test_variance_ratio" . ("maxima.info-3" 269545 2752 "Functions and Variables for stats"))
("testsuite_files" . ("maxima.info-1" 26091 634 "Functions and Variables for Bug Detection and Reporting"))
("tex" . ("maxima.info-1" 555639 2300 "Functions and Variables for TeX Output"))
("tex1" . ("maxima.info-1" 557940 345 "Functions and Variables for TeX Output"))
("tex_display" . ("maxima.info-2" 473588 269 "Functions and Variables for alt-display"))
("texput" . ("maxima.info-1" 558286 4973 "Functions and Variables for TeX Output"))
("thetaresolution" . ("maxima.info-2" 886698 291 "Visualization with VTK"))
("third" . ("maxima.info-1" 156494 122 "Functions and Variables for Lists"))
("throw" . ("maxima.info-2" 445591 178 "Functions and Variables for Program Flow"))
("thru" . ("maxima.info-2" 421823 8979 "Functions and Variables for Program Flow"))
("time" . ("maxima.info-2" 222735 483 "Functions and Variables for Runtime Environment"))
("timedate" . ("maxima.info-2" 223219 1928 "Functions and Variables for Runtime Environment"))
("timer" . ("maxima.info-2" 461494 1142 "Functions and Variables for Debugging"))
("timer_devalue" . ("maxima.info-2" 463233 419 "Functions and Variables for Debugging"))
("timer_info" . ("maxima.info-2" 463653 762 "Functions and Variables for Debugging"))
("title" . ("maxima.info-1" 517477 106 "Plotting Options"))
("title <1>" . ("maxima.info-2" 777773 421 "Functions and Variables for draw"))
("tldefint" . ("maxima.info-1" 765543 112 "Functions and Variables for Integration"))
("tlimit" . ("maxima.info-1" 707367 235 "Functions and Variables for Limits"))
("tlimswitch" . ("maxima.info-1" 707603 466 "Functions and Variables for Limits"))
("to_lisp" . ("maxima.info-1" 61469 1101 "Functions and Variables for Command Line"))
("to_poly" . ("maxima.info-3" 381207 2516 "Functions and Variables for to_poly_solve"))
("to_poly_solve" . ("maxima.info-3" 383724 13974 "Functions and Variables for to_poly_solve"))
("todd_coxeter" . ("maxima.info-2" 214375 1786 "Functions and Variables for Groups"))
("toeplitz" . ("maxima.info-3" 103092 833 "Functions and Variables for linearalgebra"))
("tokens" . ("maxima.info-3" 337438 850 "String Processing"))
("topological_sort" . ("maxima.info-2" 986476 540 "Functions and Variables for graphs"))
("totaldisrep" . ("maxima.info-1" 637002 418 "Functions and Variables for Polynomials"))
("totalfourier" . ("maxima.info-2" 117259 129 "Functions and Variables for Fourier series"))
("totient" . ("maxima.info-2" 142217 131 "Functions and Variables for Number Theory"))
("tpartpol" . ("maxima.info-2" 189874 214 "Functions and Variables for Symmetries"))
("tr" . ("maxima.info-2" 60394 101 "Functions and Variables for ctensor"))
("tr_array_as_ref" . ("maxima.info-2" 406956 427 "Functions and Variables for Function Definition"))
("tr_bound_function_applyp" . ("maxima.info-2" 407384 1051 "Functions and Variables for Function Definition"))
("tr_file_tty_messagesp" . ("maxima.info-2" 408436 363 "Functions and Variables for Function Definition"))
("tr_float_can_branch_complex" . ("maxima.info-2" 408800 446 "Functions and Variables for Function Definition"))
("tr_function_call_default" . ("maxima.info-2" 409247 697 "Functions and Variables for Function Definition"))
("tr_numer" . ("maxima.info-2" 409945 164 "Functions and Variables for Function Definition"))
("tr_optimize_max_loop" . ("maxima.info-2" 410110 321 "Functions and Variables for Function Definition"))
("tr_state_vars" . ("maxima.info-2" 410432 651 "Functions and Variables for Function Definition"))
("tr_warn_bad_function_calls" . ("maxima.info-2" 411227 237 "Functions and Variables for Function Definition"))
("tr_warn_fexpr" . ("maxima.info-2" 411465 242 "Functions and Variables for Function Definition"))
("tr_warn_meval" . ("maxima.info-2" 411708 198 "Functions and Variables for Function Definition"))
("tr_warn_mode" . ("maxima.info-2" 411907 154 "Functions and Variables for Function Definition"))
("tr_warn_undeclared" . ("maxima.info-2" 412062 155 "Functions and Variables for Function Definition"))
("tr_warn_undefined_variable" . ("maxima.info-2" 412218 140 "Functions and Variables for Function Definition"))
("tr_warnings_get" . ("maxima.info-2" 411084 142 "Functions and Variables for Function Definition"))
("trace" . ("maxima.info-2" 464416 1102 "Functions and Variables for Debugging"))
("trace_options" . ("maxima.info-2" 465519 2178 "Functions and Variables for Debugging"))
("tracematrix" . ("maxima.info-3" 229588 156 "Package functs"))
("track" . ("maxima.info-2" 886990 982 "Visualization with VTK"))
("transform" . ("maxima.info-2" 778195 1411 "Functions and Variables for draw"))
("transform_sample" . ("maxima.info-2" 558067 1589 "Functions and Variables for data manipulation"))
("transform_xy" . ("maxima.info-1" 517584 317 "Plotting Options"))
("translate" . ("maxima.info-2" 401887 2377 "Functions and Variables for Function Definition"))
("translate_fast_arrays" . ("maxima.info-1" 182871 441 "Functions and Variables for Arrays"))
("translate_file" . ("maxima.info-2" 404265 2458 "Functions and Variables for Function Definition"))
("transparent" . ("maxima.info-2" 779607 521 "Functions and Variables for draw"))
("transpose" . ("maxima.info-1" 930253 389 "Functions and Variables for Matrices and Linear Algebra"))
("transrun" . ("maxima.info-2" 406724 231 "Functions and Variables for Function Definition"))
("tree_reduce" . ("maxima.info-1" 156617 1329 "Functions and Variables for Lists"))
("treefale" . ("maxima.info-2" 945579 289 "Definitions for IFS fractals"))
("treillis" . ("maxima.info-2" 198847 226 "Functions and Variables for Symmetries"))
("treinat" . ("maxima.info-2" 199074 551 "Functions and Variables for Symmetries"))
("triangle" . ("maxima.info-2" 835656 902 "Functions and Variables for draw"))
("triangularize" . ("maxima.info-1" 930643 1049 "Functions and Variables for Matrices and Linear Algebra"))
("trigexpand" . ("maxima.info-1" 417540 1399 "Functions and Variables for Trigonometric"))
("trigexpandplus" . ("maxima.info-1" 418940 319 "Functions and Variables for Trigonometric"))
("trigexpandtimes" . ("maxima.info-1" 419260 329 "Functions and Variables for Trigonometric"))
("triginverses" . ("maxima.info-1" 419590 486 "Functions and Variables for Trigonometric"))
("trigrat" . ("maxima.info-1" 421322 2867 "Functions and Variables for Trigonometric"))
("trigreduce" . ("maxima.info-1" 420077 625 "Functions and Variables for Trigonometric"))
("trigsign" . ("maxima.info-1" 420703 245 "Functions and Variables for Trigonometric"))
("trigsimp" . ("maxima.info-1" 420949 372 "Functions and Variables for Trigonometric"))
("trivial_solutions" . ("maxima.info-3" 438395 223 "Functions and Variables for zeilberger"))
("true" . ("maxima.info-1" 116737 139 "Functions and Variables for Constants"))
("trunc" . ("maxima.info-2" 112140 572 "Functions and Variables for Series"))
("truncate" . ("maxima.info-1" 377195 311 "Functions for Numbers"))
("truncated_cube_graph" . ("maxima.info-2" 962352 77 "Functions and Variables for graphs"))
("truncated_dodecahedron_graph" . ("maxima.info-2" 962430 93 "Functions and Variables for graphs"))
("truncated_icosahedron_graph" . ("maxima.info-2" 962524 91 "Functions and Variables for graphs"))
("truncated_tetrahedron_graph" . ("maxima.info-2" 962616 91 "Functions and Variables for graphs"))
("tstep" . ("maxima.info-2" 877301 199 "Visualization with VTK"))
("ttyoff" . ("maxima.info-1" 94429 347 "Functions and Variables for Display"))
("tube" . ("maxima.info-2" 836559 766 "Functions and Variables for draw"))
("tutte_graph" . ("maxima.info-2" 962708 59 "Functions and Variables for graphs"))
("ueivects" . ("maxima.info-1" 931694 1281 "Functions and Variables for Matrices and Linear Algebra"))
("ufg" . ("maxima.info-2" 58469 138 "Functions and Variables for ctensor"))
("uforget" . ("maxima.info-3" 408519 1313 "Functions and Variables for Units"))
("ug" . ("maxima.info-2" 59367 81 "Functions and Variables for ctensor"))
("ultraspherical" . ("maxima.info-3" 192027 198 "Functions and Variables for orthogonal polynomials"))
("und" . ("maxima.info-1" 116877 189 "Functions and Variables for Constants"))
("underlying_graph" . ("maxima.info-2" 962768 98 "Functions and Variables for graphs"))
("undiff" . ("maxima.info-1" 985177 490 "Functions and Variables for itensor"))
("unicode" . ("maxima.info-3" 321619 2007 "Characters"))
("unicode_to_utf8" . ("maxima.info-3" 323627 558 "Characters"))
("union" . ("maxima.info-2" 335706 977 "Functions and Variables for Sets"))
("unique" . ("maxima.info-1" 157947 378 "Functions and Variables for Lists"))
("unit_step" . ("maxima.info-3" 191761 265 "Functions and Variables for orthogonal polynomials"))
("unit_vectors" . ("maxima.info-2" 780129 674 "Functions and Variables for draw"))
("uniteigenvectors" . ("maxima.info-1" 931693 1282 "Functions and Variables for Matrices and Linear Algebra"))
("unitp" . ("maxima.info-2" 916358 1190 "Functions and Variables for ezunits"))
("units" . ("maxima.info-2" 912612 1345 "Functions and Variables for ezunits"))
("unitvector" . ("maxima.info-1" 932976 233 "Functions and Variables for Matrices and Linear Algebra"))
("unknown" . ("maxima.info-1" 471442 153 "Functions and Variables for Predicates"))
("unless" . ("maxima.info-2" 421740 9062 "Functions and Variables for Program Flow"))
("unorder" . ("maxima.info-1" 247391 1372 "Functions and Variables for Expressions"))
("unsum" . ("maxima.info-2" 112713 1207 "Functions and Variables for Series"))
("untellrat" . ("maxima.info-1" 637421 105 "Functions and Variables for Polynomials"))
("untimer" . ("maxima.info-2" 462637 595 "Functions and Variables for Debugging"))
("untrace" . ("maxima.info-2" 467698 344 "Functions and Variables for Debugging"))
("uppercasep" . ("maxima.info-3" 324186 139 "Characters"))
("uric" . ("maxima.info-2" 59136 78 "Functions and Variables for ctensor"))
("uricci" . ("maxima.info-2" 14801 532 "Functions and Variables for ctensor"))
("uriem" . ("maxima.info-2" 58975 85 "Functions and Variables for ctensor"))
("uriemann" . ("maxima.info-2" 18216 193 "Functions and Variables for ctensor"))
("us_ascii_only" . ("maxima.info-3" 324326 941 "Characters"))
("use_fast_arrays" . ("maxima.info-1" 182213 657 "Functions and Variables for Arrays"))
("user_preamble" . ("maxima.info-2" 780804 1211 "Functions and Variables for draw"))
("usersetunits" . ("maxima.info-3" 413264 8524 "Functions and Variables for Units"))
("utf8_to_unicode" . ("maxima.info-3" 325268 216 "Characters"))
("uvect" . ("maxima.info-1" 932977 232 "Functions and Variables for Matrices and Linear Algebra"))
("values" . ("maxima.info-1" 62571 1042 "Functions and Variables for Command Line"))
("vandermonde_matrix" . ("maxima.info-3" 103926 155 "Functions and Variables for linearalgebra"))
("var" . ("maxima.info-2" 560852 609 "Functions and Variables for descriptive statistics"))
("var1" . ("maxima.info-2" 561462 850 "Functions and Variables for descriptive statistics"))
("var_bernoulli" . ("maxima.info-2" 693984 319 "Functions and Variables for discrete distributions"))
("var_beta" . ("maxima.info-2" 663952 169 "Functions and Variables for continuous distributions"))
("var_binomial" . ("maxima.info-2" 689021 218 "Functions and Variables for discrete distributions"))
("var_chi2" . ("maxima.info-2" 647169 291 "Functions and Variables for continuous distributions"))
("var_continuous_uniform" . ("maxima.info-2" 666173 201 "Functions and Variables for continuous distributions"))
("var_discrete_uniform" . ("maxima.info-2" 700528 217 "Functions and Variables for discrete distributions"))
("var_exp" . ("maxima.info-2" 655689 427 "Functions and Variables for continuous distributions"))
("var_f" . ("maxima.info-2" 652558 168 "Functions and Variables for continuous distributions"))
("var_gamma" . ("maxima.info-2" 661386 171 "Functions and Variables for continuous distributions"))
("var_general_finite_discrete" . ("maxima.info-2" 686208 212 "Functions and Variables for discrete distributions"))
("var_geometric" . ("maxima.info-2" 697497 336 "Functions and Variables for discrete distributions"))
("var_gumbel" . ("maxima.info-2" 682333 171 "Functions and Variables for continuous distributions"))
("var_hypergeometric" . ("maxima.info-2" 703449 262 "Functions and Variables for discrete distributions"))
("var_laplace" . ("maxima.info-2" 679065 173 "Functions and Variables for continuous distributions"))
("var_logistic" . ("maxima.info-2" 668394 176 "Functions and Variables for continuous distributions"))
("var_lognormal" . ("maxima.info-2" 659039 177 "Functions and Variables for continuous distributions"))
("var_negative_binomial" . ("maxima.info-2" 706438 232 "Functions and Variables for discrete distributions"))
("var_noncentral_chi2" . ("maxima.info-2" 650184 182 "Functions and Variables for continuous distributions"))
("var_noncentral_student_t" . ("maxima.info-2" 643358 268 "Functions and Variables for continuous distributions"))
("var_normal" . ("maxima.info-2" 636373 191 "Functions and Variables for continuous distributions"))
("var_pareto" . ("maxima.info-2" 670446 181 "Functions and Variables for continuous distributions"))
("var_poisson" . ("maxima.info-2" 691507 168 "Functions and Variables for discrete distributions"))
("var_rayleigh" . ("maxima.info-2" 675450 525 "Functions and Variables for continuous distributions"))
("var_student_t" . ("maxima.info-2" 639032 310 "Functions and Variables for continuous distributions"))
("var_weibull" . ("maxima.info-2" 672504 175 "Functions and Variables for continuous distributions"))
("vect_cross" . ("maxima.info-1" 934867 213 "Functions and Variables for Matrices and Linear Algebra"))
("vector" . ("maxima.info-2" 837326 1312 "Functions and Variables for draw"))
("vectorpotential" . ("maxima.info-1" 933210 323 "Functions and Variables for Matrices and Linear Algebra"))
("vectorsimp" . ("maxima.info-1" 933534 1332 "Functions and Variables for Matrices and Linear Algebra"))
("verbify" . ("maxima.info-1" 248764 380 "Functions and Variables for Expressions"))
("verbose" . ("maxima.info-2" 113921 131 "Functions and Variables for Series"))
("vers" . ("maxima.info-3" 234239 124 "Package functs"))
("vertex_color" . ("maxima.info-2" 998510 81 "Functions and Variables for graphs"))
("vertex_coloring" . ("maxima.info-2" 999346 171 "Functions and Variables for graphs"))
("vertex_coloring <1>" . ("maxima.info-2" 989120 485 "Functions and Variables for graphs"))
("vertex_connectivity" . ("maxima.info-2" 987017 128 "Functions and Variables for graphs"))
("vertex_degree" . ("maxima.info-2" 987146 101 "Functions and Variables for graphs"))
("vertex_distance" . ("maxima.info-2" 987248 415 "Functions and Variables for graphs"))
("vertex_eccentricity" . ("maxima.info-2" 987664 283 "Functions and Variables for graphs"))
("vertex_in_degree" . ("maxima.info-2" 987948 562 "Functions and Variables for graphs"))
("vertex_out_degree" . ("maxima.info-2" 988511 382 "Functions and Variables for graphs"))
("vertex_partition" . ("maxima.info-2" 999112 233 "Functions and Variables for graphs"))
("vertex_size" . ("maxima.info-2" 998447 62 "Functions and Variables for graphs"))
("vertex_type" . ("maxima.info-2" 998262 184 "Functions and Variables for graphs"))
("vertices" . ("maxima.info-2" 988894 225 "Functions and Variables for graphs"))
("vertices_to_cycle" . ("maxima.info-2" 1002183 145 "Functions and Variables for graphs"))
("vertices_to_path" . ("maxima.info-2" 1002041 141 "Functions and Variables for graphs"))
("view" . ("maxima.info-2" 782016 907 "Functions and Variables for draw"))
("warning" . ("maxima.info-2" 431954 307 "Functions and Variables for Program Flow"))
("warnings" . ("maxima.info-3" 437968 174 "Functions and Variables for zeilberger"))
("wc_inputvalueranges" . ("maxima.info-3" 425316 802 "Functions and Variables for wrstcse"))
("wc_mintypmax" . ("maxima.info-3" 428482 1217 "Functions and Variables for wrstcse"))
("wc_mintypmax2tol" . ("maxima.info-3" 430955 617 "Functions and Variables for wrstcse"))
("wc_montecarlo" . ("maxima.info-3" 427317 1164 "Functions and Variables for wrstcse"))
("wc_systematic" . ("maxima.info-3" 426119 1197 "Functions and Variables for wrstcse"))
("wc_tolappend" . ("maxima.info-3" 429700 1254 "Functions and Variables for wrstcse"))
("wc_typicalvalues" . ("maxima.info-3" 424317 998 "Functions and Variables for wrstcse"))
("weyl" . ("maxima.info-2" 59449 63 "Functions and Variables for ctensor"))
("weyl <1>" . ("maxima.info-2" 18657 423 "Functions and Variables for ctensor"))
("wheel_graph" . ("maxima.info-2" 962867 81 "Functions and Variables for graphs"))
("while" . ("maxima.info-2" 421715 9087 "Functions and Variables for Program Flow"))
("width" . ("maxima.info-2" 877501 170 "Visualization with VTK"))
("wiener_index" . ("maxima.info-2" 989606 196 "Functions and Variables for graphs"))
("wigner_3j" . ("maxima.info-2" 504004 160 "Functions and Variables for clebsch_gordan"))
("wigner_6j" . ("maxima.info-2" 504165 95 "Functions and Variables for clebsch_gordan"))
("wigner_9j" . ("maxima.info-2" 504261 122 "Functions and Variables for clebsch_gordan"))
("windowname" . ("maxima.info-2" 877672 292 "Visualization with VTK"))
("windowtitle" . ("maxima.info-2" 877965 193 "Visualization with VTK"))
("wired_surface" . ("maxima.info-2" 782924 486 "Functions and Variables for draw"))
("wireframe" . ("maxima.info-2" 888561 205 "Visualization with VTK"))
("with_stdout" . ("maxima.info-1" 552803 1184 "Functions and Variables for File Input and Output"))
("write_binary_data" . ("maxima.info-3" 151941 1051 "Functions and Variables for binary input and output"))
("write_data" . ("maxima.info-3" 147862 1281 "Functions and Variables for plain-text input and output"))
("writebyte" . ("maxima.info-3" 312723 1382 "Input and Output"))
("writefile" . ("maxima.info-1" 553988 1211 "Functions and Variables for File Input and Output"))
("wronskian" . ("maxima.info-3" 228916 671 "Package functs"))
("x" . ("maxima.info-1" 517902 399 "Plotting Options"))
("x_voxel" . ("maxima.info-2" 783411 249 "Functions and Variables for draw"))
("xaxis" . ("maxima.info-2" 783661 446 "Functions and Variables for draw"))
("xaxis_color" . ("maxima.info-2" 784108 479 "Functions and Variables for draw"))
("xaxis_secondary" . ("maxima.info-2" 784588 805 "Functions and Variables for draw"))
("xaxis_type" . ("maxima.info-2" 785394 474 "Functions and Variables for draw"))
("xaxis_width" . ("maxima.info-2" 785869 454 "Functions and Variables for draw"))
("xlabel" . ("maxima.info-1" 518302 484 "Plotting Options"))
("xlabel <1>" . ("maxima.info-2" 786324 518 "Functions and Variables for draw"))
("xlabel_secondary" . ("maxima.info-2" 786843 728 "Functions and Variables for draw"))
("xlength" . ("maxima.info-2" 887973 195 "Visualization with VTK"))
("xrange" . ("maxima.info-2" 787572 511 "Functions and Variables for draw"))
("xrange_secondary" . ("maxima.info-2" 788084 486 "Functions and Variables for draw"))
("xreduce" . ("maxima.info-1" 158326 1674 "Functions and Variables for Lists"))
("xthru" . ("maxima.info-1" 363654 1215 "Functions and Variables for Simplification"))
("xtics" . ("maxima.info-1" 518787 447 "Plotting Options"))
("xtics <1>" . ("maxima.info-2" 788571 1875 "Functions and Variables for draw"))
("xtics_axis" . ("maxima.info-2" 790447 321 "Functions and Variables for draw"))
("xtics_rotate" . ("maxima.info-2" 790769 257 "Functions and Variables for draw"))
("xtics_rotate_secondary" . ("maxima.info-2" 791027 287 "Functions and Variables for draw"))
("xtics_secondary" . ("maxima.info-2" 791315 201 "Functions and Variables for draw"))
("xtics_secondary_axis" . ("maxima.info-2" 791517 351 "Functions and Variables for draw"))
("xu_grid" . ("maxima.info-2" 791869 502 "Functions and Variables for draw"))
("xy_file" . ("maxima.info-2" 792372 360 "Functions and Variables for draw"))
("xy_scale" . ("maxima.info-1" 519235 537 "Plotting Options"))
("xyplane" . ("maxima.info-2" 792733 515 "Functions and Variables for draw"))
("y" . ("maxima.info-1" 519773 290 "Plotting Options"))
("y_voxel" . ("maxima.info-2" 793249 249 "Functions and Variables for draw"))
("yaxis" . ("maxima.info-2" 793499 421 "Functions and Variables for draw"))
("yaxis_color" . ("maxima.info-2" 793921 479 "Functions and Variables for draw"))
("yaxis_secondary" . ("maxima.info-2" 794401 686 "Functions and Variables for draw"))
("yaxis_type" . ("maxima.info-2" 795088 475 "Functions and Variables for draw"))
("yaxis_width" . ("maxima.info-2" 795564 454 "Functions and Variables for draw"))
("ylabel" . ("maxima.info-1" 520064 449 "Plotting Options"))
("ylabel <1>" . ("maxima.info-2" 796019 525 "Functions and Variables for draw"))
("ylabel_secondary" . ("maxima.info-2" 796545 824 "Functions and Variables for draw"))
("ylength" . ("maxima.info-2" 888169 195 "Visualization with VTK"))
("yrange" . ("maxima.info-2" 797370 571 "Functions and Variables for draw"))
("yrange_secondary" . ("maxima.info-2" 797942 811 "Functions and Variables for draw"))
("ytics" . ("maxima.info-1" 520514 446 "Plotting Options"))
("ytics <1>" . ("maxima.info-2" 798754 184 "Functions and Variables for draw"))
("ytics_axis" . ("maxima.info-2" 798939 321 "Functions and Variables for draw"))
("ytics_rotate" . ("maxima.info-2" 799261 257 "Functions and Variables for draw"))
("ytics_rotate_secondary" . ("maxima.info-2" 799519 287 "Functions and Variables for draw"))
("ytics_secondary" . ("maxima.info-2" 799807 201 "Functions and Variables for draw"))
("ytics_secondary_axis" . ("maxima.info-2" 800009 351 "Functions and Variables for draw"))
("yv_grid" . ("maxima.info-2" 800361 529 "Functions and Variables for draw"))
("yx_ratio" . ("maxima.info-1" 520961 184 "Plotting Options"))
("z" . ("maxima.info-1" 521146 139 "Plotting Options"))
("z_voxel" . ("maxima.info-2" 800891 204 "Functions and Variables for draw"))
("zaxis" . ("maxima.info-2" 801096 534 "Functions and Variables for draw"))
("zaxis_color" . ("maxima.info-2" 801631 580 "Functions and Variables for draw"))
("zaxis_type" . ("maxima.info-2" 802212 532 "Functions and Variables for draw"))
("zaxis_width" . ("maxima.info-2" 802745 550 "Functions and Variables for draw"))
("zeroa" . ("maxima.info-1" 117067 452 "Functions and Variables for Constants"))
("zerob" . ("maxima.info-1" 117520 221 "Functions and Variables for Constants"))
("zerobern" . ("maxima.info-2" 142349 227 "Functions and Variables for Number Theory"))
("zeroequiv" . ("maxima.info-1" 471596 1169 "Functions and Variables for Predicates"))
("zerofor" . ("maxima.info-3" 104082 542 "Functions and Variables for linearalgebra"))
("zeromatrix" . ("maxima.info-1" 935081 106 "Functions and Variables for Matrices and Linear Algebra"))
("zeromatrixp" . ("maxima.info-3" 104625 275 "Functions and Variables for linearalgebra"))
("zeta" . ("maxima.info-2" 142577 1385 "Functions and Variables for Number Theory"))
("zeta%pi" . ("maxima.info-2" 143963 602 "Functions and Variables for Number Theory"))
("zgeev" . ("maxima.info-3" 51635 136 "Functions and Variables for lapack"))
("zheev" . ("maxima.info-3" 51772 456 "Functions and Variables for lapack"))
("zlabel" . ("maxima.info-1" 521286 379 "Plotting Options"))
("zlabel <1>" . ("maxima.info-2" 803296 562 "Functions and Variables for draw"))
("zlabel_rotate" . ("maxima.info-2" 803859 590 "Functions and Variables for draw"))
("zlange" . ("maxima.info-3" 45499 761 "Functions and Variables for lapack"))
("zlength" . ("maxima.info-2" 888365 195 "Visualization with VTK"))
("zmin" . ("maxima.info-1" 521666 119 "Plotting Options"))
("zn_add_table" . ("maxima.info-2" 144566 142 "Functions and Variables for Number Theory"))
("zn_carmichael_lambda" . ("maxima.info-2" 148226 214 "Functions and Variables for Number Theory"))
("zn_characteristic_factors" . ("maxima.info-2" 144709 3516 "Functions and Variables for Number Theory"))
("zn_determinant" . ("maxima.info-2" 148441 1090 "Functions and Variables for Number Theory"))
("zn_factor_generators" . ("maxima.info-2" 149532 227 "Functions and Variables for Number Theory"))
("zn_invert_by_lu" . ("maxima.info-2" 149760 1013 "Functions and Variables for Number Theory"))
("zn_log" . ("maxima.info-2" 150774 3171 "Functions and Variables for Number Theory"))
("zn_mult_table" . ("maxima.info-2" 153946 5396 "Functions and Variables for Number Theory"))
("zn_nth_root" . ("maxima.info-2" 159343 4740 "Functions and Variables for Number Theory"))
("zn_order" . ("maxima.info-2" 164084 2273 "Functions and Variables for Number Theory"))
("zn_power_table" . ("maxima.info-2" 166358 4819 "Functions and Variables for Number Theory"))
("zn_primroot" . ("maxima.info-2" 171178 2459 "Functions and Variables for Number Theory"))
("zn_primroot_limit" . ("maxima.info-2" 173638 309 "Functions and Variables for Number Theory"))
("zn_primroot_p" . ("maxima.info-2" 173948 1810 "Functions and Variables for Number Theory"))
("zn_primroot_pretest" . ("maxima.info-2" 175759 487 "Functions and Variables for Number Theory"))
("zn_primroot_verbose" . ("maxima.info-2" 176247 165 "Functions and Variables for Number Theory"))
("zrange" . ("maxima.info-2" 804450 602 "Functions and Variables for draw"))
("ztics" . ("maxima.info-2" 805053 184 "Functions and Variables for draw"))
("ztics_axis" . ("maxima.info-2" 805238 321 "Functions and Variables for draw"))
("ztics_rotate" . ("maxima.info-2" 805560 258 "Functions and Variables for draw"))
("|" . ("maxima.info-1" 1015750 1386 "Functions and Variables for itensor"))
("~" . ("maxima.info-1" 1014184 1565 "Functions and Variables for itensor"))
))
(section-pairs '(
; CONTENT: (<NODE NAME> . (<FILENAME> <BYTE OFFSET> <LENGTH IN CHARACTERS>))
("Airy Functions" . ("maxima.info-1" 646387 1006))
("Arithmetic operators" . ("maxima.info-1" 253767 8995))
("Arrays" . ("maxima.info-1" 162356 1264))
("Assignment operators" . ("maxima.info-1" 273273 12230))
("Bessel Functions" . ("maxima.info-1" 640220 6036))
("Characters" . ("maxima.info-3" 314217 11267))
("Combinatorial Functions" . ("maxima.info-1" 386436 8317))
("Comments" . ("maxima.info-1" 530743 1151))
("Constants" . ("maxima.info-1" 112927 81))
("Definitions for IFS fractals" . ("maxima.info-2" 944642 1574))
("Definitions for Koch snowflakes" . ("maxima.info-2" 948658 833))
("Definitions for Peano maps" . ("maxima.info-2" 949606 667))
("Definitions for complex fractals" . ("maxima.info-2" 946365 2146))
("Directory operations" . ("maxima.info-3" 162526 517))
("Documentation" . ("maxima.info-1" 29998 893))
("Environment operations" . ("maxima.info-3" 163545 305))
("Error Function" . ("maxima.info-1" 681957 1682))
("Error messages" . ("maxima.info-3" 440021 513))
("Examples for cobyla" . ("maxima.info-2" 509993 643))
("Exponential Integrals" . ("maxima.info-1" 679586 2248))
("Extending pytranslate" . ("maxima.info-3" 197270 4938))
("File operations" . ("maxima.info-3" 163174 269))
("Files" . ("maxima.info-1" 532032 1061))
("Function" . ("maxima.info-2" 337337 6129))
("Functions and Variables for Affine" . ("maxima.info-1" 935729 5363))
("Functions and Variables for Bernstein" . ("maxima.info-2" 483696 4760))
("Functions and Variables for Bug Detection and Reporting" . ("maxima.info-1" 23825 5861))
("Functions and Variables for Combinatorics" . ("maxima.info-2" 512954 11115))
("Functions and Variables for Command Line" . ("maxima.info-1" 38457 25156))
("Functions and Variables for Debugging" . ("maxima.info-2" 458942 9100))
("Functions and Variables for Differential Equations" . ("maxima.info-1" 835156 8016))
("Functions and Variables for Differentiation" . ("maxima.info-1" 708377 30458))
("Functions and Variables for Display" . ("maxima.info-1" 63746 31030))
("Functions and Variables for Elliptic Functions" . ("maxima.info-1" 700211 2469))
("Functions and Variables for Elliptic Integrals" . ("maxima.info-1" 702821 1661))
("Functions and Variables for Equations" . ("maxima.info-1" 792602 41516))
("Functions and Variables for Evaluation" . ("maxima.info-1" 296840 26037))
("Functions and Variables for Expressions" . ("maxima.info-1" 196213 52931))
("Functions and Variables for Facts" . ("maxima.info-1" 448322 16015))
("Functions and Variables for File Input and Output" . ("maxima.info-1" 533261 21938))
("Functions and Variables for Fortran Output" . ("maxima.info-1" 565876 2750))
("Functions and Variables for Fourier series" . ("maxima.info-2" 114733 3061))
("Functions and Variables for Function Definition" . ("maxima.info-2" 352358 61940))
("Functions and Variables for Groups" . ("maxima.info-2" 214295 1866))
("Functions and Variables for Help" . ("maxima.info-1" 30986 6829))
("Functions and Variables for Integration" . ("maxima.info-1" 740255 25400))
("Functions and Variables for Limits" . ("maxima.info-1" 704741 3328))
("Functions and Variables for Matrices and Linear Algebra" . ("maxima.info-1" 882137 53050))
("Functions and Variables for Miscellaneous Options" . ("maxima.info-2" 236042 6173))
("Functions and Variables for Number Theory" . ("maxima.info-2" 121734 54678))
("Functions and Variables for Plotting" . ("maxima.info-1" 478800 22727))
("Functions and Variables for Poisson series" . ("maxima.info-2" 117948 3475))
("Functions and Variables for Polynomials" . ("maxima.info-1" 572065 65461))
("Functions and Variables for Predicates" . ("maxima.info-1" 464471 8294))
("Functions and Variables for Program Flow" . ("maxima.info-2" 419992 32557))
("Functions and Variables for Properties" . ("maxima.info-1" 427611 20530))
("Functions and Variables for QUADPACK" . ("maxima.info-1" 769987 22332))
("Functions and Variables for Rules and Patterns" . ("maxima.info-2" 243640 40514))
("Functions and Variables for Runtime Environment" . ("maxima.info-2" 218805 15715))
("Functions and Variables for Series" . ("maxima.info-2" 86517 27535))
("Functions and Variables for Sets" . ("maxima.info-2" 291631 45052))
("Functions and Variables for Simplification" . ("maxima.info-1" 333193 31676))
("Functions and Variables for Special Functions" . ("maxima.info-1" 687260 8648))
("Functions and Variables for Sums and Products" . ("maxima.info-2" 74613 11164))
("Functions and Variables for Symmetries" . ("maxima.info-2" 178191 35849))
("Functions and Variables for TeX Output" . ("maxima.info-1" 555404 10325))
("Functions and Variables for Units" . ("maxima.info-3" 403531 19387))
("Functions and Variables for alt-display" . ("maxima.info-2" 471235 7136))
("Functions and Variables for atensor" . ("maxima.info-2" 68562 5463))
("Functions and Variables for augmented_lagrangian" . ("maxima.info-2" 479635 3767))
("Functions and Variables for binary input and output" . ("maxima.info-3" 149310 3682))
("Functions and Variables for bitwise" . ("maxima.info-2" 489004 6790))
("Functions and Variables for bode" . ("maxima.info-2" 496039 3133))
("Functions and Variables for clebsch_gordan" . ("maxima.info-2" 503471 912))
("Functions and Variables for cobyla" . ("maxima.info-2" 507201 2683))
("Functions and Variables for continuous distributions" . ("maxima.info-2" 634659 49129))
("Functions and Variables for contrib_ode" . ("maxima.info-2" 530326 5601))
("Functions and Variables for ctensor" . ("maxima.info-2" 4764 59562))
("Functions and Variables for data manipulation" . ("maxima.info-2" 544960 14696))
("Functions and Variables for descriptive statistics" . ("maxima.info-2" 559867 34087))
("Functions and Variables for diag" . ("maxima.info-2" 615752 12311))
("Functions and Variables for discrete distributions" . ("maxima.info-2" 683947 23973))
("Functions and Variables for draw" . ("maxima.info-2" 710464 128174))
("Functions and Variables for drawdf" . ("maxima.info-2" 857546 8312))
("Functions and Variables for engineering-format" . ("maxima.info-2" 889339 1682))
("Functions and Variables for ezunits" . ("maxima.info-2" 900088 27967))
("Functions and Variables for fast Fourier transform" . ("maxima.info-1" 844184 10294))
("Functions and Variables for finance" . ("maxima.info-2" 932869 10715))
("Functions and Variables for ggf" . ("maxima.info-2" 950512 1684))
("Functions and Variables for graphs" . ("maxima.info-2" 953576 48752))
("Functions and Variables for grobner" . ("maxima.info-3" 2109 13996))
("Functions and Variables for impdiff" . ("maxima.info-3" 16373 538))
("Functions and Variables for inference_result" . ("maxima.info-3" 252638 4633))
("Functions and Variables for interpol" . ("maxima.info-3" 17635 14113))
("Functions and Variables for itensor" . ("maxima.info-1" 954102 71056))
("Functions and Variables for lapack" . ("maxima.info-3" 32366 19862))
("Functions and Variables for lbfgs" . ("maxima.info-3" 53528 15158))
("Functions and Variables for lindstedt" . ("maxima.info-3" 68971 1419))
("Functions and Variables for linearalgebra" . ("maxima.info-3" 75281 29619))
("Functions and Variables for lsquares" . ("maxima.info-3" 105559 24595))
("Functions and Variables for makeOrders" . ("maxima.info-3" 135035 897))
("Functions and Variables for minpack" . ("maxima.info-3" 130769 3978))
("Functions and Variables for mnewton" . ("maxima.info-3" 136549 2172))
("Functions and Variables for odepack" . ("maxima.info-3" 158007 3802))
("Functions and Variables for opsubst" . ("maxima.info-3" 164127 2365))
("Functions and Variables for orthogonal polynomials" . ("maxima.info-3" 184648 7577))
("Functions and Variables for pictures" . ("maxima.info-2" 838805 4000))
("Functions and Variables for plain-text input and output" . ("maxima.info-3" 143273 5870))
("Functions and Variables for ratpow" . ("maxima.info-3" 202891 2054))
("Functions and Variables for romberg" . ("maxima.info-3" 205195 6676))
("Functions and Variables for simplex" . ("maxima.info-3" 214307 6386))
("Functions and Variables for solve_rec" . ("maxima.info-3" 242824 8249))
("Functions and Variables for special distributions" . ("maxima.info-3" 292166 1077))
("Functions and Variables for statistical graphs" . ("maxima.info-2" 594111 21391))
("Functions and Variables for stats" . ("maxima.info-3" 257455 34580))
("Functions and Variables for stirling" . ("maxima.info-3" 293518 2573))
("Functions and Variables for to_poly_solve" . ("maxima.info-3" 349909 49624))
("Functions and Variables for worldmap" . ("maxima.info-2" 842931 12433))
("Functions and Variables for wrstcse" . ("maxima.info-3" 424235 7337))
("Functions and Variables for zeilberger" . ("maxima.info-3" 433871 5693))
("Functions and variables for asympa" . ("maxima.info-2" 479195 81))
("Functions for Complex Numbers" . ("maxima.info-1" 377656 8609))
("Functions for Numbers" . ("maxima.info-1" 365374 12132))
("Functions for numerical solution of differential equations" . ("maxima.info-1" 862749 13726))
("Functions for numerical solution of equations" . ("maxima.info-1" 854697 6562))
("Functions in pytranslate" . ("maxima.info-3" 195075 2101))
("Gamma and factorial Functions" . ("maxima.info-1" 647529 31921))
("Garbage Collection" . ("maxima.info-2" 418758 791))
("Gnuplot Options" . ("maxima.info-1" 521909 7334))
("Gnuplot_pipes Format Functions" . ("maxima.info-1" 529342 965))
("Graphical analysis of discrete dynamical systems" . ("maxima.info-2" 866931 6337))
("Hypergeometric Functions" . ("maxima.info-1" 684278 2252))
("Identifiers" . ("maxima.info-1" 193772 2042))
("Inequality" . ("maxima.info-1" 195940 167))
("Input and Output" . ("maxima.info-3" 299911 14194))
("Interrupts" . ("maxima.info-2" 217735 948))
("Introduction for Runtime Environment" . ("maxima.info-2" 216591 977))
("Introduction to Affine" . ("maxima.info-1" 935505 116))
("Introduction to Command Line" . ("maxima.info-1" 38220 67))
("Introduction to Differential Equations" . ("maxima.info-1" 834568 432))
("Introduction to Elliptic Functions and Integrals" . ("maxima.info-1" 696360 3653))
("Introduction to Expressions" . ("maxima.info-1" 189827 1472))
("Introduction to Fourier series" . ("maxima.info-2" 114237 303))
("Introduction to Function Definition" . ("maxima.info-2" 337131 83))
("Introduction to Integration" . ("maxima.info-1" 739258 841))
("Introduction to Matrices and Linear Algebra" . ("maxima.info-1" 876967 223))
("Introduction to Maxima's Database" . ("maxima.info-1" 427356 79))
("Introduction to Miscellaneous Options" . ("maxima.info-2" 234969 272))
("Introduction to ODEPACK" . ("maxima.info-3" 153368 1107))
("Introduction to Plotting" . ("maxima.info-1" 473182 2382))
("Introduction to Polynomials" . ("maxima.info-1" 568997 2945))
("Introduction to Program Flow" . ("maxima.info-2" 419702 164))
("Introduction to QUADPACK" . ("maxima.info-1" 765820 4050))
("Introduction to Rules and Patterns" . ("maxima.info-2" 242636 860))
("Introduction to Series" . ("maxima.info-2" 85957 395))
("Introduction to Sets" . ("maxima.info-2" 284471 7058))
("Introduction to Simplification" . ("maxima.info-1" 323242 9819))
("Introduction to Special Functions" . ("maxima.info-1" 638113 1972))
("Introduction to String Processing" . ("maxima.info-3" 296501 3282))
("Introduction to Symmetries" . ("maxima.info-2" 176751 1320))
("Introduction to Units" . ("maxima.info-3" 399843 3580))
("Introduction to alt-display" . ("maxima.info-2" 468402 2706))
("Introduction to asympa" . ("maxima.info-2" 478706 377))
("Introduction to atensor" . ("maxima.info-2" 64650 3801))
("Introduction to celine" . ("maxima.info-2" 499393 3764))
("Introduction to cobyla" . ("maxima.info-2" 504740 2321))
("Introduction to contrib_ode" . ("maxima.info-2" 524545 5609))
("Introduction to ctensor" . ("maxima.info-2" 380 4273))
("Introduction to descriptive" . ("maxima.info-2" 539828 4940))
("Introduction to distrib" . ("maxima.info-2" 628473 5995))
("Introduction to draw" . ("maxima.info-2" 708301 2012))
("Introduction to drawdf" . ("maxima.info-2" 855680 1754))
("Introduction to ezunits" . ("maxima.info-2" 891745 3499))
("Introduction to fast Fourier transform" . ("maxima.info-1" 843783 204))
("Introduction to finance" . ("maxima.info-2" 932290 464))
("Introduction to fractals" . ("maxima.info-2" 944004 487))
("Introduction to graphs" . ("maxima.info-2" 952510 954))
("Introduction to grobner" . ("maxima.info-3" 385 1617))
("Introduction to interpol" . ("maxima.info-3" 17246 271))
("Introduction to itensor" . ("maxima.info-1" 941398 12593))
("Introduction to lapack" . ("maxima.info-3" 32065 189))
("Introduction to lbfgs" . ("maxima.info-3" 52526 899))
("Introduction to linearalgebra" . ("maxima.info-3" 70774 4374))
("Introduction to lsquares" . ("maxima.info-3" 105242 199))
("Introduction to minpack" . ("maxima.info-3" 130485 169))
("Introduction to mnewton" . ("maxima.info-3" 136266 168))
("Introduction to numerical solution of differential equations" . ("maxima.info-1" 861486 1090))
("Introduction to numericalio" . ("maxima.info-3" 139168 3902))
("Introduction to operatingsystem" . ("maxima.info-3" 162209 177))
("Introduction to operators" . ("maxima.info-1" 249573 4065))
("Introduction to orthogonal polynomials" . ("maxima.info-3" 166889 17612))
("Introduction to physical_constants" . ("maxima.info-2" 895402 4560))
("Introduction to pytranslate" . ("maxima.info-3" 192557 2388))
("Introduction to simplex" . ("maxima.info-3" 212205 1987))
("Introduction to simplification" . ("maxima.info-3" 221122 250))
("Introduction to solve_rec" . ("maxima.info-3" 242120 583))
("Introduction to stats" . ("maxima.info-3" 251487 995))
("Introduction to wrstcse" . ("maxima.info-3" 423245 875))
("Introduction to zeilberger" . ("maxima.info-3" 431941 1806))
("Keyword Commands" . ("maxima.info-2" 456777 2057))
("Known Bugs" . ("maxima.info-2" 891167 206))
("Lisp and Maxima" . ("maxima.info-2" 414672 3958))
("Lists" . ("maxima.info-1" 117841 136))
("Logical operators" . ("maxima.info-1" 265576 2580))
("Macros" . ("maxima.info-2" 343601 8639))
("Nouns and Verbs" . ("maxima.info-1" 191418 2252))
("Numbers" . ("maxima.info-1" 95142 103))
("Octets and Utilities for Cryptography" . ("maxima.info-3" 338402 11198))
("Operators for Equations" . ("maxima.info-1" 268280 4864))
("Package absimp" . ("maxima.info-3" 221503 894))
("Package combinatorics" . ("maxima.info-2" 511011 1818))
("Package f90" . ("maxima.info-2" 928254 3712))
("Package facexp" . ("maxima.info-3" 222512 6019))
("Package functs" . ("maxima.info-3" 228644 6465))
("Package ineq" . ("maxima.info-3" 235222 3913))
("Package rducon" . ("maxima.info-3" 239248 1414))
("Package scifac" . ("maxima.info-3" 240754 1016))
("Parabolic Cylinder Functions" . ("maxima.info-1" 686699 425))
("Plotting Formats" . ("maxima.info-1" 475703 2966))
("Plotting Options" . ("maxima.info-1" 501657 20128))
("Possible improvements to contrib_ode" . ("maxima.info-2" 536098 938))
("Random Numbers" . ("maxima.info-1" 424294 2582))
("References for contrib_ode" . ("maxima.info-2" 537916 1430))
("Relational operators" . ("maxima.info-1" 262883 2569))
("Root, Exponential and Logarithmic Functions" . ("maxima.info-1" 394918 14090))
("Share" . ("maxima.info-2" 235408 513))
("Source Level Debugging" . ("maxima.info-2" 452866 3772))
("String Processing" . ("maxima.info-3" 325617 12671))
("Strings" . ("maxima.info-1" 107348 103))
("Structures" . ("maxima.info-1" 183399 129))
("Struve Functions" . ("maxima.info-1" 683765 373))
("Test cases for contrib_ode" . ("maxima.info-2" 537194 609))
("The dynamics package" . ("maxima.info-2" 866247 527))
("Trigonometric Functions" . ("maxima.info-1" 409164 149))
("User defined operators" . ("maxima.info-1" 285600 10965))
("Visualization with VTK" . ("maxima.info-2" 873396 15370))
("Warning messages" . ("maxima.info-3" 449247 117))
)))
(load-info-hashtables (maxima::maxima-load-pathname-directory) deffn-defvr-pairs section-pairs))
